@@ -1,4 +1,4 @@
-<?php # $Id: comments.inc.php 1458 2006-10-26 09:46:53Z garvinhicking $
+<?php # $Id: comments.inc.php 1939 2007-09-18 16:05:31Z donchambers $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -28,11 +28,12 @@ if (isset($serendipity['GET']['adminAction']) && $serendipity['GET']['adminActio
                         author    = '" . serendipity_db_escape_string($serendipity['POST']['name'])    . "',
                         email     = '" . serendipity_db_escape_string($serendipity['POST']['email'])   . "',
                         url       = '" . serendipity_db_escape_string($serendipity['POST']['url'])     . "',
-                        parent_id = '" . serendipity_db_escape_string($serendipity['POST']['replyTo']) . "',
+                        " . ($serendipity['POST']['replyTo'] != $serendipity['GET']['id'] ? "parent_id = '" . serendipity_db_escape_string($serendipity['POST']['replyTo']) . "'," : '') . "
                         body      = '" . serendipity_db_escape_string($serendipity['POST']['comment']) . "'
             WHERE id = " . (int)$serendipity['GET']['id'] . " AND
                   entry_id = " . (int)$serendipity['POST']['entry_id'];
     serendipity_db_query($sql);
+    serendipity_plugin_api::hook_event('backend_updatecomment', $serendipity['POST'], $serendipity['GET']['id']);
     echo COMMENT_EDITED;
 }
 
@@ -186,6 +187,9 @@ if ($serendipity['GET']['filter']['show'] == 'approved') {
 if ($serendipity['GET']['filter']['type'] == 'TRACKBACK') {
     $c_type = 'TRACKBACK';
     $searchString .= "&amp;serendipity[filter][type]=TRACKBACK";
+} elseif ($serendipity['GET']['filter']['type'] == 'PINGBACK') {
+    $c_type = 'PINGBACK';
+    $searchString .= "&amp;serendipity[filter][type]=PINGBACK";
 } elseif ($serendipity['GET']['filter']['type'] == 'NORMAL') {
     $c_type = 'NORMAL';
     $searchString .= "&amp;serendipity[filter][type]=NORMAL";
@@ -196,6 +200,9 @@ if ($serendipity['GET']['filter']['type'] == 'TRACKBACK') {
 if ($serendipity['GET']['filter']['type'] == 'TRACKBACK') {
     $c_type = 'TRACKBACK';
     $searchString .= "&amp;serendipity[filter][type]=TRACKBACK";
+} elseif ($serendipity['GET']['filter']['type'] == 'PINGBACK') {
+    $c_type = 'PINGBACK';
+    $searchString .= "&amp;serendipity[filter][type]=PINGBACK";
 } elseif ($serendipity['GET']['filter']['type'] == 'NORMAL') {
     $c_type = 'NORMAL';
     $searchString .= "&amp;serendipity[filter][type]=NORMAL";
@@ -277,19 +284,19 @@ function highlightComment(id, checkvalue) {
     </tr>
     <tr>
         <td><?php echo AUTHOR ?>:</td>
-        <td><input type="text" name="serendipity[filter][author]" size="15" value="<?php echo htmlspecialchars($serendipity['GET']['filter']['author']) ?>" /></td>
+        <td><input class="input_textbox" type="text" name="serendipity[filter][author]" size="15" value="<?php echo htmlspecialchars($serendipity['GET']['filter']['author']) ?>" /></td>
         <td><?php echo EMAIL ?>:</td>
-        <td><input type="text" name="serendipity[filter][email]" size="15" value="<?php echo htmlspecialchars($serendipity['GET']['filter']['email']) ?>" /></td>
+        <td><input class="input_textbox" type="text" name="serendipity[filter][email]" size="15" value="<?php echo htmlspecialchars($serendipity['GET']['filter']['email']) ?>" /></td>
         <td><?php echo URL ?>:</td>
-        <td><input type="text" name="serendipity[filter][url]" size="15" value="<?php echo htmlspecialchars($serendipity['GET']['filter']['url']) ?>" /></td>
+        <td><input class="input_textbox" type="text" name="serendipity[filter][url]" size="15" value="<?php echo htmlspecialchars($serendipity['GET']['filter']['url']) ?>" /></td>
     </tr>
     <tr>
         <td>IP:</td>
-        <td><input type="text" name="serendipity[filter][ip]" size="15" value="<?php echo htmlspecialchars($serendipity['GET']['filter']['ip']) ?>" /></td>
+        <td><input class="input_textbox" type="text" name="serendipity[filter][ip]" size="15" value="<?php echo htmlspecialchars($serendipity['GET']['filter']['ip']) ?>" /></td>
         <td><?php echo CONTENT ?>:</td>
-        <td><input type="text" name="serendipity[filter][body]" size="15" value="<?php echo htmlspecialchars($serendipity['GET']['filter']['body']) ?>" /></td>
+        <td><input class="input_textbox" type="text" name="serendipity[filter][body]" size="15" value="<?php echo htmlspecialchars($serendipity['GET']['filter']['body']) ?>" /></td>
         <td><?php echo REFERER ?>:</td>
-        <td><input type="text" name="serendipity[filter][referer]" size="15" value="<?php echo htmlspecialchars($serendipity['GET']['filter']['referer']) ?>" /></td>
+        <td><input class="input_textbox" type="text" name="serendipity[filter][referer]" size="15" value="<?php echo htmlspecialchars($serendipity['GET']['filter']['referer']) ?>" /></td>
     </tr>
     <tr>
         <td><?php echo COMMENTS; ?>:</td>
@@ -313,10 +320,11 @@ function highlightComment(id, checkvalue) {
                 <option value=""><?php echo COMMENTS_FILTER_ALL ?></option>
                 <option value="NORMAL"<?php if ($c_type == 'NORMAL') echo ' selected="selected"' ?>><?php echo COMMENTS; ?></option>
                 <option value="TRACKBACK"<?php if ($c_type == 'TRACKBACK') echo ' selected="selected"' ?>><?php echo TRACKBACKS; ?></option>
+                <option value="PINGBACK"<?php if ($c_type == 'PINGBACK') echo ' selected="selected"' ?>><?php echo PINGBACKS; ?></option>
             </select></td>
     </tr>
     <tr>
-        <td colspan="6" align="right"><input type="submit" name="submit" value=" - <?php echo GO ?> - " class="serendipityPrettyButton" /> <?php serendipity_plugin_api::hook_event('backend_comments_top', $sql); ?></td>
+        <td colspan="6" align="right"><input type="submit" name="submit" value=" - <?php echo GO ?> - " class="serendipityPrettyButton input_button" /> <?php serendipity_plugin_api::hook_event('backend_comments_top', $sql); ?></td>
     </tr>
 </table>
 </form>
@@ -387,26 +395,33 @@ foreach ($sql as $rs) {
 
     serendipity_plugin_api::hook_event('backend_view_comment', $comment, '&amp;serendipity[page]='. $page . $searchString);
     $class = 'serendipity_admin_list_item_' . (($i % 2 == 0 ) ? 'even' : 'uneven');
-    $header_class = ($comment['status'] == 'pending' ? 'serendipityAdminMsgNote' : '');
+    if ($comment['status'] == 'pending') {
+        $class .= ' serendipity_admin_comment_pending'; 
+    }
+    $header_class = ($comment['status'] == 'pending' ? 'serendipityAdminMsgNote serendipity_admin_comment_pending_header' : '');
 ?>
 <tr>
-    <td class="<?php echo $header_class; ?>"><a name="c<?php echo $comment['id'] ?>"></a>
-        <?php echo ($comment['type'] == 'NORMAL' ? COMMENT : TRACKBACK) . ' #'. $comment['id'] .', '. IN_REPLY_TO .' <strong><a href="' . $comment['entry_url'] . '">'. $comment['title'] .'</a></strong>, '. ON . ' ' . serendipity_mb('ucfirst', serendipity_strftime('%b %e %Y, %H:%M', $comment['timestamp']))?>
+    <td class="<?php echo $header_class; ?>">
+<?php   if ($header_class=='serendipityAdminMsgNote serendipity_admin_comment_pending_header') { ?>
+            <img style="width: 22px; height: 22px; border: 0px; padding-right: 4px; vertical-align: middle" src="<?php echo serendipity_getTemplateFile('admin/img/admin_msg_note.png'); ?>" alt="" />
+<?php   }?>
+        <a name="c<?php echo $comment['id'] ?>"></a>
+        <?php echo ($comment['type'] == 'NORMAL' ? COMMENT : ($comment['type'] == 'TRACKBACK' ? TRACKBACK : PINGBACK )) . ' #'. $comment['id'] .', '. IN_REPLY_TO .' <strong><a href="' . $comment['entry_url'] . '">'. $comment['title'] .'</a></strong>, '. ON . ' ' . serendipity_mb('ucfirst', serendipity_strftime('%b %e %Y, %H:%M', $comment['timestamp']))?>
     </td>
 </tr>
 <tr>
     <td class="serendipity_admin_list_item <?php echo $class ?>" id="comment_<?php echo $comment['id'] ?>">
         <table width="100%" cellspacing="0" cellpadding="3" border="0">
             <tr>
-                <td rowspan="3" width="20" align="center"><input type="checkbox" name="serendipity[delete][<?php echo $comment['id'] ?>]" value="<?php echo $comment['entry_id'] ?>" onclick="highlightComment('comment_<?php echo $comment['id'] ?>', this.checked)" tabindex="<?php echo $i ?>" /></td>
-                <td width="40%"><strong><?php echo AUTHOR ?></strong>: <?php echo htmlspecialchars($comment['author']) . $comment['action_author']; ?></td>
+                <td rowspan="3" width="20" align="center"><input class="input_checkbox" type="checkbox" name="serendipity[delete][<?php echo $comment['id'] ?>]" value="<?php echo $comment['entry_id'] ?>" onclick="highlightComment('comment_<?php echo $comment['id'] ?>', this.checked)" tabindex="<?php echo $i ?>" /></td>
+                <td width="40%"><strong><?php echo AUTHOR ?></strong>: <?php echo htmlspecialchars(serendipity_truncateString($comment['author'],30)) . $comment['action_author']; ?></td>
                 <td><strong><?php echo EMAIL ?></strong>:
                     <?php
                         if ( empty($comment['email']) ) {
                             echo 'N/A';
                         } else {
                     ?>
-                            <a href="mailto:<?php echo htmlspecialchars($comment['email']) ?>"><?php echo htmlspecialchars($comment['email']) ?></a>
+                            <a href="mailto:<?php echo htmlspecialchars($comment['email']) ?>" title="<?php echo htmlspecialchars($comment['email']) ?>"><?php echo htmlspecialchars(serendipity_truncateString($comment['email'],30)) ?></a>
                     <?php } ?>
                 <?php echo $comment['action_email']; ?>
                 </td>
@@ -428,7 +443,7 @@ foreach ($sql as $rs) {
                             echo 'N/A';
                         } else {
                     ?>
-                            <a href="<?php echo htmlspecialchars($comment['url']) ?>" target="_blank"><?php echo htmlspecialchars($comment['url']) ?></a>
+                            <a href="<?php echo htmlspecialchars($comment['url']) ?>" title="<?php echo htmlspecialchars($comment['url']) ?>" target="_blank"><?php echo htmlspecialchars(serendipity_truncateString($comment['url'],30)) ?></a>
                     <?php } ?>
                     <?php echo $comment['action_url']; ?>
                     </td>
@@ -441,7 +456,7 @@ foreach ($sql as $rs) {
                             echo 'N/A';
                         } else {
                     ?>
-                          <a href="<?php echo htmlspecialchars($comment['referer']) ?>" title="<?php echo htmlspecialchars($comment['referer']) ?>"><?php echo htmlspecialchars(serendipity_truncateString($comment['referer'],30)) ?></a>
+                          <a href="<?php echo htmlspecialchars($comment['referer']) ?>" title="<?php echo htmlspecialchars($comment['referer']) ?>" target="_blank"><?php echo htmlspecialchars(serendipity_truncateString($comment['referer'],30)) ?></a>
                     <?php } ?>
                     <?php echo $comment['action_referer']; ?>
                     </td>
@@ -470,7 +485,7 @@ foreach ($sql as $rs) {
 </tr>
 <?php } ?>
 <tr>
-    <td><input type="button" name="toggle" value="<?php echo INVERT_SELECTIONS ?>" onclick="invertSelection()" class="serendipityPrettyButton" /> <input type="submit" name="toggle" value="<?php echo DELETE_SELECTED_COMMENTS ?>" onclick="return confirm('<?php echo COMMENTS_DELETE_CONFIRM ?>')" tabindex="<?php echo ($i+1) ?>" class="serendipityPrettyButton" /></td>
+    <td><input type="button" name="toggle" value="<?php echo INVERT_SELECTIONS ?>" onclick="invertSelection()" class="serendipityPrettyButton input_button" /> <input type="submit" name="toggle" value="<?php echo DELETE_SELECTED_COMMENTS ?>" onclick="return confirm('<?php echo COMMENTS_DELETE_CONFIRM ?>')" tabindex="<?php echo ($i+1) ?>" class="serendipityPrettyButton input_button" /></td>
 </tr>
 </table>
 </form>
