@@ -1,4 +1,4 @@
-<?php # $Id: entries.inc.php 1545 2006-12-11 11:52:43Z garvinhicking $
+<?php # $Id: entries.inc.php 1910 2007-09-11 12:47:46Z donchambers $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -138,7 +138,7 @@ function serendipity_drawList() {
 ?>              </select>
             </td>
             <td valign="top" width="80"><?php echo CONTENT ?></td>
-            <td valign="top"><input size="10" type="text" name="serendipity[filter][body]" value="<?php echo (isset($serendipity['GET']['filter']['body']) ? htmlspecialchars($serendipity['GET']['filter']['body']) : '') ?>" /></td>
+            <td valign="top"><input class="input_textbox" size="10" type="text" name="serendipity[filter][body]" value="<?php echo (isset($serendipity['GET']['filter']['body']) ? htmlspecialchars($serendipity['GET']['filter']['body']) : '') ?>" /></td>
         </tr>
         <tr>
             <td class="serendipity_admin_filters_headline" colspan="6"><strong><?php echo SORT_ORDER ?></strong></td>
@@ -175,7 +175,7 @@ function serendipity_drawList() {
             </td>
         </tr>
         <tr>
-            <td align="right" colspan="6"><input type="submit" name="go" value="<?php echo GO ?>" class="serendipityPrettyButton" /></td>
+            <td align="right" colspan="6"><input type="submit" name="go" value="<?php echo GO ?>" class="serendipityPrettyButton input_button" /></td>
         </tr>
     </table>
     </form>
@@ -251,7 +251,9 @@ function serendipity_drawList() {
                 $entry_pre .= ' ' . DRAFT . ': ';
             }
 ?>
-            <div class="serendipity_admin_list_item serendipity_admin_list_item_<?php echo ($rows % 2 ? 'even' : 'uneven'); ?>">
+<!--            <div class="serendipity_admin_list_item serendipity_admin_list_item_<?php echo ($rows % 2 ? 'even' : 'uneven'); ?>"> -->
+            <div class="serendipity_admin_list_item serendipity_admin_list_item_<?php echo ($rows % 2) ? 'even' : 'uneven'; ?>">
+
                 <table width="100%" cellspacing="0" cellpadding="3">
                     <tr>
                         <td>
@@ -274,15 +276,20 @@ function serendipity_drawList() {
                     }
                     echo implode(', ', $cats);
                 }
-                $entry['link']      = serendipity_archiveURL($entry['id'], $entry['title'], 'serendipityHTTPPath', true, array('timestamp' => $entry['timestamp']));
+                $entry['link']         = serendipity_archiveURL($entry['id'], $entry['title'], 'serendipityHTTPPath', true, array('timestamp' => $entry['timestamp']));
+                $entry['preview_link'] = '?serendipity[noBanner]=true&amp;serendipity[noSidebar]=true&amp;serendipity[action]=admin&amp;serendipity[adminModule]=entries&amp;serendipity[adminAction]=preview&amp;serendipity[id]=' . $entry['id'];
                 ?>
 
                         </td>
                         <td align="right">
+                            <?php if (serendipity_db_bool($entry['isdraft'])) { ?>
+                            <a target="_blank" href="<?php echo $entry['preview_link']; ?>" title="<?php echo PREVIEW . ' #' . $entry['id']; ?>" class="serendipityIconLink"><img src="<?php echo serendipity_getTemplateFile('admin/img/zoom.png'); ?>" alt="<?php echo PREVIEW; ?>" /><?php echo PREVIEW ?></a>
+                            <?php } else { ?>
                             <a target="_blank" href="<?php echo $entry['link']; ?>" title="<?php echo VIEW . ' #' . $entry['id']; ?>" class="serendipityIconLink"><img src="<?php echo serendipity_getTemplateFile('admin/img/zoom.png'); ?>" alt="<?php echo VIEW; ?>" /><?php echo VIEW ?></a>
+                            <?php } ?>
                             <a href="?serendipity[action]=admin&amp;serendipity[adminModule]=entries&amp;serendipity[adminAction]=edit&amp;serendipity[id]=<?php echo $entry['id']; ?>" title="<?php echo EDIT . ' #' . $entry['id']; ?>" class="serendipityIconLink"><img src="<?php echo serendipity_getTemplateFile('admin/img/edit.png'); ?>" alt="<?php echo EDIT; ?>" /><?php echo EDIT ?></a>
                             <a href="?<?php echo serendipity_setFormToken('url'); ?>&amp;serendipity[action]=admin&amp;serendipity[adminModule]=entries&amp;serendipity[adminAction]=delete&amp;serendipity[id]=<?php echo $entry['id']; ?>" title="<?php echo DELETE . ' #' . $entry['id']; ?>" class="serendipityIconLink"><img src="<?php echo serendipity_getTemplateFile('admin/img/delete.png'); ?>" alt="<?php echo DELETE; ?>" /><?php echo DELETE ?></a>
-                            <input type="checkbox" name="serendipity[multiDelete][]" value="<?php echo $entry['id']; ?>" />
+                            <input class="input_checkbox" type="checkbox" name="serendipity[multiDelete][]" value="<?php echo $entry['id']; ?>" />
                         </td>
                     </tr>
                 </table>
@@ -308,8 +315,8 @@ function serendipity_drawList() {
         <table class="serendipity_admin_list" cellpadding="0" width="100%">
             <tr>
                 <td align="right">
-                    <input type="button" name="toggle" value="<?php echo INVERT_SELECTIONS ?>" onclick="invertSelection()" class="serendipityPrettyButton" />
-                    <input type="submit" name="toggle" value="<?php echo DELETE_SELECTED_ENTRIES ?>" class="serendipityPrettyButton" />
+                    <input type="button" name="toggle" value="<?php echo INVERT_SELECTIONS ?>" onclick="invertSelection()" class="serendipityPrettyButton input_button" />
+                    <input type="submit" name="toggle" value="<?php echo DELETE_SELECTED_ENTRIES ?>" class="serendipityPrettyButton input_button" />
                 </td>
             </tr>
         </table>
@@ -323,7 +330,7 @@ function serendipity_drawList() {
                                 <input type="hidden" name="serendipity[action]"      value="admin"      />
                                 <input type="hidden" name="serendipity[adminModule]" value="entries"    />
                                 <input type="hidden" name="serendipity[adminAction]" value="editSelect" />
-                            <?php echo EDIT_ENTRY ?>: #<input type="text" size="3" name="serendipity[id]" /> <input type="submit" name="serendipity[editSubmit]" value="<?php echo GO ?>" class="serendipityPrettyButton" />
+                            <?php echo EDIT_ENTRY ?>: #<input class="input_textbox" type="text" size="3" name="serendipity[id]" /> <input type="submit" name="serendipity[editSubmit]" value="<?php echo GO ?>" class="serendipityPrettyButton input_button" />
                             </form>
                         </td>
                     </tr>
@@ -333,7 +340,13 @@ function serendipity_drawList() {
     } else {
         // We've got nothing
 ?>
-        <div align="center">- <?php echo NO_ENTRIES_TO_PRINT ?> -</div>
+        <tr>
+            <td align="center" class="serendipityAdminMsgNote">
+                <img style="width: 22px; height: 22px; border: 0px; padding-right: 4px; vertical-align: middle" src="<?php echo serendipity_getTemplateFile('admin/img/admin_msg_note.png'); ?>" alt="" />
+                <?php echo NO_ENTRIES_TO_PRINT ?>
+            </td>
+        </tr>
+    </table>
 <?php
     }
 ?>
@@ -345,20 +358,29 @@ if (!empty($serendipity['GET']['editSubmit'])) {
     $serendipity['GET']['adminAction'] = 'edit';
 }
 
+$preview_only = false;
+
 switch($serendipity['GET']['adminAction']) {
+    case 'preview':
+        $entry        = serendipity_fetchEntry('id', $serendipity['GET']['id'], 1, 1);
+        $serendipity['POST']['preview'] = true;
+        $preview_only = true;
+
     case 'save':
-        $entry = array(
-                   'id'                 => $serendipity['POST']['id'],
-                   'title'              => $serendipity['POST']['title'],
-                   'timestamp'          => $serendipity['POST']['timestamp'],
-                   'body'               => $serendipity['POST']['body'],
-                   'extended'           => $serendipity['POST']['extended'],
-                   'categories'         => $serendipity['POST']['categories'],
-                   'isdraft'            => $serendipity['POST']['isdraft'],
-                   'allow_comments'     => $serendipity['POST']['allow_comments'],
-                   'moderate_comments'  => $serendipity['POST']['moderate_comments'],
-                   'exflag'             => (!empty($serendipity['POST']['extended']) ? true : false)
-        );
+        if (!$preview_only) {
+            $entry = array(
+                       'id'                 => $serendipity['POST']['id'],
+                       'title'              => $serendipity['POST']['title'],
+                       'timestamp'          => $serendipity['POST']['timestamp'],
+                       'body'               => $serendipity['POST']['body'],
+                       'extended'           => $serendipity['POST']['extended'],
+                       'categories'         => $serendipity['POST']['categories'],
+                       'isdraft'            => $serendipity['POST']['isdraft'],
+                       'allow_comments'     => $serendipity['POST']['allow_comments'],
+                       'moderate_comments'  => $serendipity['POST']['moderate_comments'],
+                       'exflag'             => (!empty($serendipity['POST']['extended']) ? true : false)
+            );
+        }
 
         if ($entry['allow_comments'] != 'true' && $entry['allow_comments'] !== true) {
             $entry['allow_comments'] = 'false';
@@ -393,11 +415,11 @@ switch($serendipity['GET']['adminAction']) {
             if ($serendipity['POST']['preview'] != 'true') {
                 /* We don't need an iframe to save a draft */
                 if ( $serendipity['POST']['isdraft'] == 'true' ) {
-                    echo '<div class="serendipityAdminMsgSuccess">' . IFRAME_SAVE_DRAFT . '</div><br />';
+                    echo '<div class="serendipityAdminMsgSuccess"><img style="height: 22px; width: 22px; border: 0px; padding-right: 4px; vertical-align: middle" src="' . serendipity_getTemplateFile('admin/img/admin_msg_success.png') . '" alt="" />' . IFRAME_SAVE_DRAFT . '</div><br />';
                     serendipity_updertEntry($entry);
                 } else {
                     if ($serendipity['use_iframe']) {
-                        echo '<div class="serendipityAdminMsgSuccess">' . IFRAME_SAVE . '</div><br />';
+                        echo '<div class="serendipityAdminMsgSuccess"><img style="height: 22px; width: 22px; border: 0px; padding-right: 4px; vertical-align: middle" src="' . serendipity_getTemplateFile('admin/img/admin_msg_success.png') . '" alt="" />' . IFRAME_SAVE . '</div><br />';
                         serendipity_iframe_create('save', $entry);
                     } else {
                         serendipity_iframe($entry, 'save');
@@ -449,7 +471,7 @@ switch($serendipity['GET']['adminAction']) {
                 }
 
                 if ($serendipity['use_iframe']) {
-                    echo '<div class="serendipityAdminMsgSuccess">' . IFRAME_PREVIEW . '</div><br />';
+                    echo '<div class="serendipityAdminMsgSuccess"><img style="height: 22px; width: 22px; border: 0px; padding-right: 4px; vertical-align: middle" src="' . serendipity_getTemplateFile('admin/img/admin_msg_success.png') . '" alt="" />' . IFRAME_PREVIEW . '</div><br />';
                     serendipity_iframe_create('preview', $entry);
                 } else {
                     serendipity_iframe($entry, 'preview');
@@ -464,18 +486,20 @@ switch($serendipity['GET']['adminAction']) {
             $entry['id'] = $serendipity['lastSavedEntry'];
         }
 
-        include_once S9Y_INCLUDE_PATH . 'include/functions_entries_admin.inc.php';
-        serendipity_printEntryForm(
-            '?',
-            array(
-              'serendipity[action]'      => 'admin',
-              'serendipity[adminModule]' => 'entries',
-              'serendipity[adminAction]' => 'save',
-              'serendipity[timestamp]'   => $entry['timestamp']
-            ),
+        if (!$preview_only) {
+            include_once S9Y_INCLUDE_PATH . 'include/functions_entries_admin.inc.php';
+            serendipity_printEntryForm(
+                '?',
+                array(
+                  'serendipity[action]'      => 'admin',
+                  'serendipity[adminModule]' => 'entries',
+                  'serendipity[adminAction]' => 'save',
+                  'serendipity[timestamp]'   => $entry['timestamp']
+                ),
 
-            $entry
-        );
+                $entry
+            );
+        }
 
         break;
 
@@ -524,9 +548,9 @@ switch($serendipity['GET']['adminAction']) {
 <br />
 <br />
 <div>
-    <a href="<?php echo htmlspecialchars($_SERVER["HTTP_REFERER"]); ?>" class="serendipityPrettyButton"><?php echo NOT_REALLY; ?></a>
+    <a href="<?php echo htmlspecialchars($_SERVER["HTTP_REFERER"]); ?>" class="serendipityPrettyButton input_button"><?php echo NOT_REALLY; ?></a>
     <?php echo str_repeat('&nbsp;', 10); ?>
-    <a href="<?php echo $newLoc; ?>" class="serendipityPrettyButton"><?php echo DUMP_IT; ?></a>
+    <a href="<?php echo $newLoc; ?>" class="serendipityPrettyButton input_button"><?php echo DUMP_IT; ?></a>
 </div>
 <?php
         break;
@@ -548,9 +572,9 @@ switch($serendipity['GET']['adminAction']) {
 <br />
 <br />
 <div>
-    <a href="<?php echo htmlspecialchars($_SERVER["HTTP_REFERER"]); ?>" class="serendipityPrettyButton"><?php echo NOT_REALLY; ?></a>
+    <a href="<?php echo htmlspecialchars($_SERVER["HTTP_REFERER"]); ?>" class="serendipityPrettyButton input_button "><?php echo NOT_REALLY; ?></a>
     <?php echo str_repeat('&nbsp;', 10); ?>
-    <a href="<?php echo $newLoc; ?>" class="serendipityPrettyButton"><?php echo DUMP_IT; ?></a>
+    <a href="<?php echo $newLoc; ?>" class="serendipityPrettyButton input_button"><?php echo DUMP_IT; ?></a>
 </div>
 <?php
         break;
