@@ -1,4 +1,4 @@
-<?php # $Id: export.inc.php 7 2005-04-16 06:39:31Z s_bergmann $
+<?php # $Id: export.inc.php 1767 2007-07-12 09:36:32Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -8,7 +8,7 @@ if (IN_serendipity !== true) {
 
 ?>
   <div>
-    <a href="<?php echo $serendipity['baseURL'] ?>rss.php?version=2.0&all=1" class="serendipityPrettyButton"><?php echo EXPORT_FEED; ?></a>
+    <a href="<?php echo $serendipity['baseURL'] ?>rss.php?version=2.0&all=1" class="serendipityPrettyButton input_button"><?php echo EXPORT_FEED; ?></a>
   </div>
 <?php
 /* vim: set sts=4 ts=4 expandtab : */
