@@ -1,4 +1,4 @@
-<?php # $Id: import.inc.php 1462 2006-10-27 09:18:19Z garvinhicking $
+<?php # $Id: import.inc.php 2062 2007-12-06 11:13:42Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -167,8 +167,31 @@ class Serendipity_Import {
         global $serendipity;
 
         mysql_select_db($this->data['name'], $db);
+        $dbn = false;
+
+        $target = $this->data['charset'];
+
+        switch($target) {
+            case 'native':
+                $dbn = SQL_CHARSET;
+                break;
+
+            case 'ISO-8859-1':
+                $dbn = 'latin1';
+                break;
+            
+            case 'UTF-8':
+                $dbn = 'utf8';
+                break;
+        }
+        
+        if ($dbn && $serendipity['dbNames']) {
+            mysql_query("SET NAMES " . $dbn, $db);
+        }
+       
         $return = &mysql_query($query, $db);
-        mysql_select_db($serendipity['dbName'], $serendipity['dbConn']);        $return = &mysql_query($query, $db);
+        mysql_select_db($serendipity['dbName'], $serendipity['dbConn']);
+        serendipity_db_reconnect();
         return $return;
     }
 }
@@ -220,7 +243,7 @@ if (isset($serendipity['GET']['importFrom']) && serendipity_checkFormToken()) {
     </tr>
     <?php } ?>
     <tr>
-      <td colspan="2" align="right"><input type="submit" value="<?php echo IMPORT_NOW ?>" class="serendipityPrettyButton"></td>
+      <td colspan="2" align="right"><input type="submit" value="<?php echo IMPORT_NOW ?>" class="serendipityPrettyButton input_button"></td>
     </tr>
   </table>
 </form>
@@ -261,7 +284,7 @@ if (isset($serendipity['GET']['importFrom']) && serendipity_checkFormToken()) {
     <option value="<?php echo $v ?>"><?php echo $k ?></option>
     <?php } ?>
   </select>
-  <input type="submit" value="<?php echo GO ?>" class="serendipityPrettyButton">
+  <input type="submit" value="<?php echo GO ?>" class="serendipityPrettyButton input_button">
 </form>
 <?php
 }
