@@ -1,4 +1,4 @@
-<?php # $Id: movabletype.inc.php 1028 2006-03-27 11:17:11Z garvinhicking $
+<?php # $Id: movabletype.inc.php 1816 2007-08-06 10:18:39Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -446,7 +446,7 @@ class Serendipity_Import_MovableType extends Serendipity_Import {
                 unset($entry['s9y_comments']);
 
                 if ( !is_int($r = serendipity_updertEntry($entry)) ) {
-                    echo '<div class="serendipityAdminMsgError">' . $r . '</div>';
+                    echo '<div class="serendipityAdminMsgError"><img style="width: 22px; height: 22px; border: 0px; padding-right: 4px; vertical-align: middle" src="' . serendipity_getTemplateFile('admin/img/admin_msg_error.png') . '" alt="" />' . $r . '</div>';
                 } else {
                     $this->debug('Saved entry ' . $r . ' (' . $entry['title'] . ')');
                     $entry['id'] = $r;
@@ -456,7 +456,7 @@ class Serendipity_Import_MovableType extends Serendipity_Import {
                             $cid = serendipity_db_insert_id('comments', 'id');
                             serendipity_approveComment($cid, $entry['id'], true);
                         } else {
-                            echo '<div class="serendipityAdminMsgError">' . $rc . '</div>';
+                            echo '<div class="serendipityAdminMsgError"><img style="width: 22px; height: 22px; border: 0px; padding-right: 4px; vertical-align: middle" src="' . serendipity_getTemplateFile('admin/img/admin_msg_error.png') . '" alt="" />' . $rc . '</div>';
                         }
                     }
                     // Let the plugins do some additional stuff. Here it's used with
