@@ -1,4 +1,4 @@
-<?php # $Id: personal.inc.php 1003 2006-03-09 10:25:58Z garvinhicking $
+<?php # $Id: personal.inc.php 1861 2007-08-21 15:54:13Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -16,11 +16,11 @@ if ($serendipity['GET']['adminAction'] == 'save' && serendipity_checkFormToken()
     $config = serendipity_parseTemplate(S9Y_CONFIG_USERTEMPLATE);
     if ( (!serendipity_checkPermission('adminUsersEditUserlevel') || !serendipity_checkPermission('adminUsersMaintainOthers') )
           && (int)$_POST['userlevel'] > $serendipity['serendipityUserlevel']) {
-        echo '<div class="serendipityAdminMsgError">' . CREATE_NOT_AUTHORIZED_USERLEVEL . '</div>';
+        echo '<div class="serendipityAdminMsgError"><img style="width: 22px; height: 22px; border: 0px; padding-right: 4px; vertical-align: middle" src="' . serendipity_getTemplateFile('admin/img/admin_msg_error.png') . '" alt="" />' . CREATE_NOT_AUTHORIZED_USERLEVEL . '</div>';
     } elseif (empty($_POST['username'])) {
-        echo '<div class="serendipityAdminMsgError">' . USERCONF_CHECK_USERNAME_ERROR . '</div>';
+        echo '<div class="serendipityAdminMsgError"><img style="width: 22px; height: 22px; border: 0px; padding-right: 4px; vertical-align: middle" src="' . serendipity_getTemplateFile('admin/img/admin_msg_error.png') . '" alt="" />' . USERCONF_CHECK_USERNAME_ERROR . '</div>';
     } elseif (!empty($_POST['password']) && $_POST['check_password'] != $_SESSION['serendipityPassword'] && md5($_POST['check_password']) != $_SESSION['serendipityPassword']) {
-        echo '<div class="serendipityAdminMsgError">' . USERCONF_CHECK_PASSWORD_ERROR . '</div>';
+        echo '<div class="serendipityAdminMsgError"><img style="width: 22px; height: 22px; border: 0px; padding-right: 4px; vertical-align: middle" src="' . serendipity_getTemplateFile('admin/img/admin_msg_error.png') . '" alt="" />' . USERCONF_CHECK_PASSWORD_ERROR . '</div>';
     } else {
         $valid_groups = serendipity_getGroups($serendipity['authorid'], true);
 
@@ -32,7 +32,9 @@ if ($serendipity['GET']['adminAction'] == 'save' && serendipity_checkFormToken()
                         // Void, no fixing neccessarry
 
                     } elseif (serendipity_checkPermission('adminUsersMaintainSame')) {
-
+                        if (!is_array($_POST[$item['var']])) {
+                            continue;
+                        }
                         // Check that no user may assign groups he's not allowed to.
                         foreach($_POST[$item['var']] AS $groupkey => $groupval) {
                             if (in_array($groupval, $valid_groups)) {
@@ -51,15 +53,20 @@ if ($serendipity['GET']['adminAction'] == 'save' && serendipity_checkFormToken()
                     } else {
                         continue;
                     }
-
+/*
                     if (count($_POST[$item['var']]) < 1) {
-                        echo '<div class="serendipityAdminMsgError">' . WARNING_NO_GROUPS_SELECTED . '</div>';
+                        echo '<div class="serendipityAdminMsgError"><img style="width: 22px; height: 22px; border: 0px; padding-right: 4px; vertical-align: middle" src="' . serendipity_getTemplateFile('admin/img/admin_msg_error.png') . '" alt="" />' . WARNING_NO_GROUPS_SELECTED . '</div>';
                     } else {
                         serendipity_updateGroups($_POST[$item['var']], $serendipity['authorid'], false);
                     }
+*/
                     continue;
                 }
 
+                // Moved to group administration:
+                if ($item['var'] == 'userlevel') continue;
+                if ($item['view'] == 'dangerous') continue;
+
                 if (serendipity_checkConfigItemFlags($item, 'local')) {
                     serendipity_set_user_var($item['var'], $_POST[$item['var']], $serendipity['authorid'], true);
                 }
@@ -79,9 +86,14 @@ if ($serendipity['GET']['adminAction'] == 'save' && serendipity_checkFormToken()
             serendipity_updatePermalink($pl_data, 'author');
             serendipity_plugin_api::hook_event('backend_users_edit', $pl_data);
         }
+        if ($serendipity['authorid'] === $_SESSION['serendipityAuthorid']) {
+            if (is_null($serendipity['detected_lang'])) {
+                $_SESSION['serendipityLanguage'] = $serendipity['lang'];
+            }
+        }
         $from = $_POST;
 ?>
-    <div class="serendipityAdminMsgSuccess"><?php echo sprintf(MODIFIED_USER, $_POST['realname']) ?></div>
+    <div class="serendipityAdminMsgSuccess"><img width="22px" height="22px" style="border: 0px; padding-right: 4px; vertical-align: middle" src="<?php echo serendipity_getTemplateFile('admin/img/admin_msg_success.png'); ?>" alt="" /><?php echo sprintf(MODIFIED_USER, $_POST['realname']) ?></div>
 <?php }
 } ?>
 
@@ -95,7 +107,7 @@ $from['groups'] = serendipity_getGroups($serendipity['authorid']);
 unset($from['password']);
 serendipity_printConfigTemplate($template, $from, true, false);
 ?>
-    <div align="right"><input type="submit" name="SAVE"   value="<?php echo SAVE; ?>" /></div>
+    <div align="right"><input class="serendipityPrettyButton input_button" type="submit" name="SAVE"   value="<?php echo SAVE; ?>" /></div>
 </form>
 
 <?php
