@@ -1,4 +1,4 @@
-<?php # $Id: plugins.inc.php 1438 2006-10-09 09:19:39Z garvinhicking $
+<?php # $Id: plugins.inc.php 1823 2007-08-07 13:59:43Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -102,6 +102,7 @@ if (isset($_GET['serendipity']['plugin_to_conf'])) {
 
 <?php if ( isset($save_errors) && is_array($save_errors) && count($save_errors) > 0 ) { ?>
     <div class="serendipityAdminMsgError">
+    <img style="width: 22px; height: 22px; border: 0px; padding-right: 4px; vertical-align: middle" src="<?php echo serendipity_getTemplateFile('admin/img/admin_msg_error.png'); ?>" alt="" />
     <?php
     echo ERROR . ":<br />\n";
     echo "<ul>\n";
@@ -112,7 +113,7 @@ if (isset($_GET['serendipity']['plugin_to_conf'])) {
     ?>
     </div>
 <?php } elseif ( isset($_POST['SAVECONF'])) { ?>
-    <div class="serendipityAdminMsgSuccess"><?php echo DONE .': '. sprintf(SETTINGS_SAVED_AT, serendipity_strftime('%H:%M:%S')); ?></div>
+    <div class="serendipityAdminMsgSuccess"><img style="width: 22px; height: 22px; border: 0px; padding-right: 4px; vertical-align: middle" src="<?php echo serendipity_getTemplateFile('admin/img/admin_msg_success.png'); ?>" alt="" /><?php echo DONE .': '. sprintf(SETTINGS_SAVED_AT, serendipity_strftime('%H:%M:%S')); ?></div>
 <?php } ?>
 
 <form method="post" name="serendipityPluginConfigure">
@@ -239,7 +240,7 @@ if (isset($_GET['serendipity']['plugin_to_conf'])) {
                     <option value="ALL" <?php echo ($serendipity['GET']['only_group'] == 'ALL' ? 'selected="selected"' : ''); ?>><?php echo ALL_CATEGORIES; ?>
                     <option value="UPGRADE" <?php echo ($serendipity['GET']['only_group'] == 'UPGRADE' ? 'selected="selected"' : ''); ?>><?php echo WORD_NEW; ?>
                 </select>
-                <input type="submit" value="<?php echo GO; ?>" />
+                <input class="serendipityPrettyButton input_button" type="submit" value="<?php echo GO; ?>" />
             </form>
         </td>
     </tr>
@@ -264,7 +265,7 @@ if (isset($_GET['serendipity']['plugin_to_conf'])) {
 <?php
         foreach ($groupstack as $plug) {
             $jsLine = " onmouseout=\"document.getElementById('serendipity_plugin_". $plug['class_name'] ."').className='';\"";
-            $jsLine .= " onmouseover=\"document.getElementById('serendipity_plugin_". $plug['class_name'] ."').className='serendipity_admin_list_item_uneven';\"";
+            $jsLine .= " onmouseover=\"document.getElementById('serendipity_plugin_". $plug['class_name'] ."').className='serendipity_PluginAdminHighlight';\"";
 
             $pluginInfo = $notice = array();
             if (!empty($plug['author'])) {
@@ -466,13 +467,13 @@ if (isset($_GET['serendipity']['plugin_to_conf'])) {
 ?>
 
 <?php if (isset($_POST['SAVE'])) { ?>
-    <div class="serendipityAdminMsgSuccess"><?php echo DONE .': '. sprintf(SETTINGS_SAVED_AT, serendipity_strftime('%H:%M:%S')); ?></div>
+    <div class="serendipityAdminMsgSuccess"><img style="width: 22px; height: 22px; border: 0px; padding-right: 4px; vertical-align: middle" src="<?php echo serendipity_getTemplateFile('admin/img/admin_msg_success.png'); ?>" alt="" /><?php echo DONE .': '. sprintf(SETTINGS_SAVED_AT, serendipity_strftime('%H:%M:%S')); ?></div>
 <?php } ?>
 
     <div><?php echo BELOW_IS_A_LIST_OF_INSTALLED_PLUGINS ?></div>
 <?php
     if (!isset($serendipity['eyecandy']) || serendipity_db_bool($serendipity['eyecandy'])) {
-        echo '<script src="bundled-libs/dragdrop.js" type="text/javascript"></script>';
+        echo '<script src="' . serendipity_getTemplateFile('dragdrop.js') . '" type="text/javascript"></script>';
         echo '<div class="warning js_warning"><em>' . PREFERENCE_USE_JS_WARNING . '</em></div>';
     }
 
@@ -493,6 +494,12 @@ if (isset($_GET['serendipity']['plugin_to_conf'])) {
     <?php serendipity_plugin_api::hook_event('backend_plugins_event_header', $serendipity); ?>
     <?php show_plugins(true); ?>
 
+    <?php if (count($serendipity['memSnaps']) > 0) { ?>
+    <h3>Memory Usage</h3>
+    <div>
+        <pre><?php print_r($serendipity['memSnaps']); ?></pre>
+    </div>
+    <?php } ?>
 <?php
 }
 /* vim: set sts=4 ts=4 expandtab : */
