@@ -1,4 +1,4 @@
-<?php # $Id: templates.inc.php 1431 2006-10-04 08:16:42Z garvinhicking $
+<?php # $Id: templates.inc.php 1816 2007-08-06 10:18:39Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -46,18 +46,18 @@ class template_option {
 if ($serendipity['GET']['adminAction'] == 'install' ) {
     serendipity_plugin_api::hook_event('backend_templates_fetchtemplate', $serendipity);
 
-    $themeInfo = serendipity_fetchTemplateInfo($serendipity['GET']['theme']);
+    $themeInfo = serendipity_fetchTemplateInfo(htmlspecialchars($serendipity['GET']['theme']));
 
-    serendipity_set_config_var('template', $serendipity['GET']['theme']);
+    serendipity_set_config_var('template', htmlspecialchars($serendipity['GET']['theme']));
     serendipity_set_config_var('template_engine', isset($themeInfo['engine']) ? $themeInfo['engine'] : 'default');
 
-    echo '<div class="serendipityAdminMsgSuccess">'. sprintf(TEMPLATE_SET, $serendipity['GET']['theme']) .'</div>';
+    echo '<div class="serendipityAdminMsgSuccess"><img style="height: 22px; width: 22px; border: 0px; padding-right: 4px; vertical-align: middle" src="' . serendipity_getTemplateFile('admin/img/admin_msg_success.png') . '" alt="" />' . sprintf(TEMPLATE_SET, htmlspecialchars($serendipity['GET']['theme'])) .'</div>';
 }
 ?>
 
 <?php
 if ( @file_exists($serendipity['serendipityPath'] . $serendipity['templatePath'] . $serendipity['template'] .'/layout.php') ) {
-    echo '<div class="serendipityAdminMsgNote">'. WARNING_TEMPLATE_DEPRECATED .'</div>';
+    echo '<div class="serendipityAdminMsgNote"><img style="width: 22px; height: 22px; border: 0px; padding-right: 4px; vertical-align: middle" src="' . serendipity_getTemplateFile('admin/img/admin_msg_note.png') . '" alt="" />'. WARNING_TEMPLATE_DEPRECATED .'</div>';
 }
 
 echo '<h3>' . STYLE_OPTIONS . '</h3>';
@@ -73,7 +73,7 @@ if (is_array($template_config)) {
         foreach($serendipity['POST']['template'] AS $option => $value) {
             template_option::set_config($option, $value);
         }
-        echo '<div class="serendipityAdminMsgSuccess">' . DONE .': '. sprintf(SETTINGS_SAVED_AT, serendipity_strftime('%H:%M:%S')) . '</div>';
+        echo '<div class="serendipityAdminMsgSuccess"><img style="height: 22px; width: 22px; border: 0px; padding-right: 4px; vertical-align: middle" src="' . serendipity_getTemplateFile('admin/img/admin_msg_success.png') . '" alt="" />' . DONE .': '. sprintf(SETTINGS_SAVED_AT, serendipity_strftime('%H:%M:%S')) . '</div>';
     }
 
     echo '<form method="post" action="serendipity_admin.php">';
@@ -108,7 +108,7 @@ if (is_array($template_config)) {
 
 echo '<h3>' . SELECT_TEMPLATE . '</h3>';
 ?>
-<br /><br />
+<br />
 <?php
     $i = 0;
     $stack = array();
@@ -127,13 +127,29 @@ echo '<h3>' . SELECT_TEMPLATE . '</h3>';
             continue;
         }
 
+        $preview = '';
+        $preview_link = false;
+        if (file_exists($serendipity['serendipityPath'] . $serendipity['templatePath'] . $theme . '/preview_fullsize.jpg')) {
+            $preview .= '<a href="' . $serendipity['baseURL'] . $serendipity['templatePath'] . $theme . '/preview_fullsize.jpg" target="_blank">';
+            $preview_link = true;
+        } elseif (!empty($info['preview_fullsizeURL'])) {
+            $preview .= '<a href="' . $info['preview_fullsizeURL'] . '" target="_blank">';
+            $preview_link = true;
+
+#        } else {
+#            echo "No large preview";
+        }
 
         if (file_exists($serendipity['serendipityPath'] . $serendipity['templatePath'] . $theme . '/preview.png')) {
-            $preview = '<img src="' . $serendipity['templatePath'] . $theme . '/preview.png" width="100" style="border: 1px #000000 solid" />';
+            $preview .= '<img src="' . $serendipity['templatePath'] . $theme . '/preview.png" width="100" style="border: 1px #000000 solid" />';
         } elseif (!empty($info['previewURL'])) {
-            $preview = '<img src="' . $info['previewURL'] . '" width="100" style="border: 1px #000000 solid" />';
+            $preview .= '<img src="' . $info['previewURL'] . '" width="100" style="border: 1px #000000 solid" />';
         } else {
-            $preview = '&nbsp;';
+            $preview .= '&nbsp;';
+        }
+        
+        if ($preview_link) {
+            $preview .= '</a>';
         }
 
         if (empty($info['customURI'])) {
@@ -147,13 +163,13 @@ echo '<h3>' . SELECT_TEMPLATE . '</h3>';
 
         /* TODO: Smarty versioncheck */
 
-        $class = (($i % 2) ? 'even' : 'uneven');
+        $class = (($i % 2 == 0) ? 'even' : 'uneven');
 
 ?>
 <div class="serendipity_admin_list_item serendipity_admin_list_item_<?php echo $class ?>">
     <table width="100%" id="serendipity_theme_<?php echo $theme; ?>">
         <tr>
-            <td colspan="2"><strong><?php echo $info['name']; ?></strong></td>
+            <td colspan="2"><span class="serendipityTemplateSelectName"><strong><?php echo $info['name']; ?></strong></span></td>
             <td valign="middle" align="center" width="70" rowspan="2">
 <?php
     if ( $serendipity['template'] != $theme ) {
@@ -161,7 +177,7 @@ echo '<h3>' . SELECT_TEMPLATE . '</h3>';
 ?>
             <a href="?serendipity[adminModule]=templates&amp;serendipity[adminAction]=install&amp;serendipity[theme]=<?php echo $theme . $info['customURI']; ?>"><img src="<?php echo serendipity_getTemplateFile('admin/img/install_now' . $info['customIcon'] . '.png') ?>" alt="<?php echo SET_AS_TEMPLATE ?>" title="<?php echo SET_AS_TEMPLATE ?>" border="0" /></a>
 <?php   } else { ?>
-        <span style="color: #cccccc"><?php echo sprintf(UNMET_REQUIREMENTS, implode(', ', $unmetRequirements)); ?></span>
+        <span class="serendipityTemplateSelectUnmetRequirements">style="color: #cccccc"><?php echo sprintf(UNMET_REQUIREMENTS, implode(', ', $unmetRequirements)); ?></span>
 <?php
         }
     } ?>
@@ -171,9 +187,9 @@ echo '<h3>' . SELECT_TEMPLATE . '</h3>';
         <tr>
             <td width="100" style="padding-left: 10px"><?php echo $preview; ?></td>
             <td valign="top">
-                <?php echo AUTHOR;       ?>: <?php echo $info['author'];?><br />
-                <?php echo LAST_UPDATED; ?>: <?php echo $info['date'];  ?><br />
-                <?php echo CUSTOM_ADMIN_INTERFACE; ?>: <?php echo $info['custom_admin_interface']; ?><br />
+                <span class="serendipityTemplateSelectDetails"><?php echo AUTHOR;       ?>: <?php echo $info['author'];?></span><br />
+                <span class="serendipityTemplateSelectDetails"><?php echo LAST_UPDATED; ?>: <?php echo $info['date'];  ?></span><br />
+                <span class="serendipityTemplateSelectDetails"><?php echo CUSTOM_ADMIN_INTERFACE; ?>: <?php echo $info['custom_admin_interface']; ?></span><br />
             </td>
         </tr>
     </table>
