@@ -1,4 +1,4 @@
-<?php # $Id: db.inc.php 1191 2006-05-11 08:17:22Z garvinhicking $
+<?php # $Id: db.inc.php 1770 2007-07-12 11:23:20Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -123,10 +123,12 @@ function serendipity_db_get_interval($val, $ival = 900) {
 
     switch($serendipity['dbType']) {
         case 'sqlite':
+        case 'sqlite3':
             $interval = $ival;
             $ts       = time();
             break;
 
+        case 'pdo-postgres':
         case 'postgres':
             $interval = "interval '$ival'";
             $ts       = 'NOW()';
@@ -150,4 +152,31 @@ function serendipity_db_get_interval($val, $ival = 900) {
     }
 }
 
+/**
+ * Operates on an array to prepare it for SQL usage.
+ *
+ * @access public
+ * @param   string Concatenation character
+ * @param   array  Input array
+ * @param   string How to convert (int: Only numbers, string: serendipity_db_escape_String)
+ * @return  string Imploded string
+ */
+function serendipity_db_implode($string, &$array, $type = 'int') {
+    $new_array = array();
+    if (!is_array($array)) {
+        return '';
+    }
+    
+    foreach($array AS $idx => $key) {
+        if ($type == 'int') {
+            $new_array[$idx] = (int)$key;
+        } else {
+            $new_array[$idx] = serendipity_db_escape_string($key);
+        }
+    }
+
+    $string = implode($string, $new_array);
+    return $string;
+}
+
 /* vim: set sts=4 ts=4 expandtab : */
