@@ -1,4 +1,4 @@
-<?php # $Id: mysql.inc.php 1409 2006-08-23 13:51:56Z garvinhicking $
+<?php # $Id: mysql.inc.php 1636 2007-02-27 12:15:00Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -85,7 +85,14 @@ function &serendipity_db_query($sql, $single = false, $result_type = "both", $re
     }
     if ($benchmark) {
         $end = microtime_float();
-        echo "[bench: " . ($end-$start) . "s] $sql<br />\n";
+        mysql_query("INSERT INTO BLOGLOG (request, timestamp, sql, exec_time, ip) VALUES ('" . serendipity_db_escape_string($_SERVER['REQUEST_URI']) . "', NOW(), '" . serendipity_db_escape_string($sql) . "', '" . (number_format($end-$start, 10)) . "', '" . serendipity_db_escape_string($_SERVER['REMOTE_ADDR']) . "')");
+        
+        $psql = $sql;
+        $psql = preg_replace('@[0-9]{10}@', 'TIMESTAMP', $psql);
+        mysql_query("UPDATE BLOGLOG_TOTAL SET counter = counter + 1 WHERE sql = '" . serendipity_db_escape_string($psql) . "'");
+        if (mysql_affected_rows() < 1) {
+            mysql_query("INSERT INTO BLOGLOG_TOTAL (sql, counter) VALUES ('" . serendipity_db_escape_string($psql) . "', 1)");
+        }
     }
 
     if (!$expectError && mysql_error($serendipity['dbConn']) != '') {
