@@ -1,4 +1,4 @@
-<?php # $Id: sqlite.inc.php 1178 2006-05-01 13:53:40Z garvinhicking $
+<?php # $Id: sqlite.inc.php 1670 2007-04-10 13:23:34Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -318,7 +318,7 @@ function serendipity_db_probe($hash, &$errs)
         return true;
     }
 
-    $errs[] = "Unable to open \"{$serendipity['serendipityPath']}$dbName.db\" - check permissions (directory needs to be writeable for webserver)!";
+    $errs[] = "Unable to open \"$dbfile\" - check permissions (directory needs to be writeable for webserver)!";
     return false;
 }
 
