@@ -1,4 +1,4 @@
-<?php # $Id: functions.inc.php 1520 2006-11-30 21:34:29Z garvinhicking $
+<?php # $Id: functions.inc.php 1721 2007-06-11 14:32:32Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -132,9 +132,10 @@ function &serendipity_convertToTimestamp($in) {
  * @param   string      Output format for the timestamp
  * @param   int         Timestamp to use for displaying
  * @param   boolean     Indicates, if timezone calculations shall be used.
+ * @param   boolean     Whether to use strftime or simply date
  * @return  string      The formatted timestamp
  */
-function serendipity_strftime($format, $timestamp = null, $useOffset = true) {
+function serendipity_strftime($format, $timestamp = null, $useOffset = true, $useDate = false) {
     global $serendipity;
     static $is_win_utf = null;
 
@@ -143,27 +144,31 @@ function serendipity_strftime($format, $timestamp = null, $useOffset = true) {
         $is_win_utf = (LANG_CHARSET == 'UTF-8' && strtoupper(substr(PHP_OS, 0, 3)) === 'WIN' ? true : false);
     }
 
-    switch($serendipity['calendar']) {
-        default:
-        case 'gregorian':
-            if ($timestamp == null) {
-                $timestamp = serendipity_serverOffsetHour();
-            } elseif ($useOffset) {
-                $timestamp = serendipity_serverOffsetHour($timestamp);
-            }
-            $out = strftime($format, $timestamp);
-            break;
-
-        case 'persian-utf8':
-            if ($timestamp == null) {
-                $timestamp = serendipity_serverOffsetHour();
-            } elseif ($useOffset) {
-                $timestamp = serendipity_serverOffsetHour($timestamp);
-            }
-
-            require_once S9Y_INCLUDE_PATH . 'include/functions_calendars.inc.php';
-            $out = persian_strftime_utf($format, $timestamp);
-            break;
+    if ($useDate) {
+        $out = date($format, $timestamp);
+    } else {
+        switch($serendipity['calendar']) {
+            default:
+            case 'gregorian':
+                if ($timestamp == null) {
+                    $timestamp = serendipity_serverOffsetHour();
+                } elseif ($useOffset) {
+                    $timestamp = serendipity_serverOffsetHour($timestamp);
+                }
+                $out = strftime($format, $timestamp);
+                break;
+    
+            case 'persian-utf8':
+                if ($timestamp == null) {
+                    $timestamp = serendipity_serverOffsetHour();
+                } elseif ($useOffset) {
+                    $timestamp = serendipity_serverOffsetHour($timestamp);
+                }
+    
+                require_once S9Y_INCLUDE_PATH . 'include/functions_calendars.inc.php';
+                $out = persian_strftime_utf($format, $timestamp);
+                break;
+        }
     }
 
     if ($is_win_utf && (empty($serendipity['calendar']) || $serendipity['calendar'] == 'gregorian')) {
@@ -182,9 +187,10 @@ function serendipity_strftime($format, $timestamp = null, $useOffset = true) {
  * @param   string      Output format for the timestamp
  * @param   int         Timestamp to use for displaying
  * @param   boolean     Indicates, if timezone calculations shall be used.
+ * @param   boolean     Whether to use strftime or simply date
  * @return  string      The formatted timestamp
  */
-function serendipity_formatTime($format, $time, $useOffset = true) {
+function serendipity_formatTime($format, $time, $useOffset = true, $useDate = false) {
     static $cache;
     if (!isset($cache)) {
         $cache = array();
@@ -196,7 +202,8 @@ function serendipity_formatTime($format, $time, $useOffset = true) {
             $cache[$format] = str_replace('%e', '%d', $cache[$format]);
         }
     }
-    return serendipity_mb('ucfirst', serendipity_strftime($cache[$format], (int)$time, $useOffset));
+    
+    return serendipity_mb('ucfirst', serendipity_strftime($cache[$format], (int)$time, $useOffset, $useDate));
 }
 
 /**
@@ -367,7 +374,8 @@ function serendipity_fetchUsers($user = '', $group = null, $is_count = false) {
     }
 
     if ($is_count || $group != null) {
-        if ($serendipity['dbType'] == 'postgres') {
+        if ($serendipity['dbType'] == 'postgres' ||
+            $serendipity['dbType'] == 'pdo-postgres') {
             // Why does PostgreSQL keep doing this to us? :-)
             $query_group    = 'GROUP BY a.authorid, a.realname, a.username, a.password, a.mail_comments, a.mail_trackbacks, a.email, a.userlevel, a.right_publish';
             $query_distinct = 'DISTINCT';
@@ -1034,9 +1042,11 @@ function serendipity_addCategory($name, $desc, $authorid, $icon, $parentid) {
  * @param   int     The new category owner
  * @param   string  The new category icon
  * @param   int     The new category parent ID
+ * @param   int     The new category sort order
+ * @param   int     The new category subcat hiding
  * @return null
  */
-function serendipity_updateCategory($cid, $name, $desc, $authorid, $icon, $parentid) {
+function serendipity_updateCategory($cid, $name, $desc, $authorid, $icon, $parentid, $sort_order = 0, $hide_sub = 0) {
     global $serendipity;
 
     $query = "UPDATE {$serendipity['dbPrefix']}category
@@ -1044,7 +1054,9 @@ function serendipity_updateCategory($cid, $name, $desc, $authorid, $icon, $paren
                         category_description = '". serendipity_db_escape_string($desc) ."',
                         authorid = ". (int)$authorid .",
                         category_icon = '". serendipity_db_escape_string($icon) ."',
-                        parentid = ". (int)$parentid ."
+                        parentid = ". (int)$parentid .",
+                        sort_order = ". (int)$sort_order . ",
+                        hide_sub = ". (int)$hide_sub . "
                     WHERE categoryid = ". (int)$cid ."
                         $admin_category";
     serendipity_db_query($query);
@@ -1058,7 +1070,6 @@ function serendipity_updateCategory($cid, $name, $desc, $authorid, $icon, $paren
     );
 
     serendipity_updatePermalink($data, 'category');
-
 }
 
 /**
