@@ -1,4 +1,4 @@
-<?php # $Id: functions_comments.inc.php 1730 2007-06-17 10:46:06Z garvinhicking $
+<?php # $Id: functions_comments.inc.php 1779 2007-07-15 15:14:06Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -149,7 +149,8 @@ function serendipity_fetchComments($id, $limit = null, $order = '', $showAll = f
 
     $and .= $where;
 
-    if ($serendipity['dbType'] == 'postgres') {
+    if ($serendipity['dbType'] == 'postgres' ||
+        $serendipity['dbType'] == 'pdo-postgres') {
         $group    = '';
         $distinct = 'DISTINCT';
     } else {
@@ -168,8 +169,8 @@ function serendipity_fetchComments($id, $limit = null, $order = '', $showAll = f
                     co.id AS commentid,
                     co.parent_id AS parent_id
               FROM
-                    {$serendipity['dbPrefix']}comments co
-                    LEFT JOIN {$serendipity['dbPrefix']}entries e ON (co.entry_id = e.id)
+                    {$serendipity['dbPrefix']}comments AS co
+                    LEFT JOIN {$serendipity['dbPrefix']}entries AS e ON (co.entry_id = e.id)
               WHERE co.type LIKE '" . $type . "' AND co.entry_id > 0 $and
               $group
               ORDER BY
@@ -273,7 +274,8 @@ function serendipity_printComments($comments, $parentid = 0, $depth = 0, $trace
                 $comment['url'] = htmlspecialchars($comment['url'], ENT_QUOTES);
             }
 
-            serendipity_plugin_api::hook_event('frontend_display', $comment);
+            $addData = array('from' => 'functions_entries:printComments');
+            serendipity_plugin_api::hook_event('frontend_display', $comment, $addData);
 
             if (isset($comment['no_email']) && $comment['no_email']) {
                 $comment['email'] = false;
@@ -322,7 +324,13 @@ function serendipity_printCommentsByAuthor() {
         $type = '%';
     }
 
-    $sql_where = " AND co.author = '" . serendipity_db_escape_string($serendipity['GET']['viewCommentAuthor']) . "'";
+    if (!empty($serendipity['GET']['viewCommentAuthor'])) {
+        $sql_where = " AND co.author = '" . serendipity_db_escape_string($serendipity['GET']['viewCommentAuthor']) . "'";
+        $group_by  = "GROUP BY co.author";
+    } else {
+        $sql_where = " AND 1"; // Required fake 'where' condition
+        $group_by  = "";
+    }
 
     if (!empty($serendipity['GET']['commentStartTime'])) {
         $sql_where .= " AND co.timestamp >= " . (int)$serendipity['GET']['commentStartTime'];
@@ -361,12 +369,13 @@ function serendipity_printCommentsByAuthor() {
         $and .= ' AND co.status = \'approved\'';
     }
 
-    $cc = serendipity_db_query("SELECT count(co.id) AS counter
+    $fc = "SELECT count(co.id) AS counter
                                   FROM {$serendipity['dbPrefix']}comments AS co
                                  WHERE co.entry_id > 0
                                    AND co.type LIKE '" . $type . "'
-                                   AND co.status = 'approved' " . $sql_where . "
-                              GROUP BY co.author", true, 'assoc');
+                                   AND co.status = 'approved' " . $sql_where . " "
+                                   .  $group_by;
+    $cc = serendipity_db_query($fc, true, 'assoc');
     if (!isset($cc['counter'])) {
         $totalComments = 0;
     } else {
@@ -400,7 +409,7 @@ function serendipity_deleteComment($id, $entry_id, $type='comments') {
     if ($_SESSION['serendipityAuthedUser'] === true) {
         $admin = '';
         if (!serendipity_checkPermission('adminEntriesMaintainOthers')) {
-            $admin = " AND authorid = " . (int)$_SESSION['serendipityAuthorid'] ."'";
+            $admin = " AND authorid = " . (int)$_SESSION['serendipityAuthorid'];
         }
 
         /* We have to figure out if the comment we are about to delete, is awaiting approval,
@@ -440,6 +449,10 @@ function serendipity_deleteComment($id, $entry_id, $type='comments') {
 
             serendipity_db_query("UPDATE {$serendipity['dbPrefix']}comments SET parent_id = " . (int)$sql['parent_id'] . " WHERE parent_id = " . $id);
         }
+
+        $addData = array('cid' => $id, 'entry_id' => $entry_id);
+        serendipity_plugin_api::hook_event('backend_deletecomment', $sql, $addData);
+
         return true;
     } else {
         return false;
@@ -460,7 +473,7 @@ function serendipity_allowCommentsToggle($entry_id, $switch = 'disable') {
     if ($_SESSION['serendipityAuthedUser'] === true) {
         $admin = '';
         if (!serendipity_checkPermission('adminEntriesMaintainOthers')) {
-            $admin = " AND authorid = '" . (int)$_SESSION['serendipityAuthorid'] ."'";
+            $admin = " AND authorid = " . (int)$_SESSION['serendipityAuthorid'];
         }
 
         $query = "UPDATE {$serendipity['dbPrefix']}entries SET allow_comments = '" . ($switch == 'disable' ? 'false' : 'true') . "' WHERE id = '". (int)$entry_id ."' $admin";
@@ -522,6 +535,8 @@ function serendipity_approveComment($cid, $entry_id, $force = false) {
     if ($serendipity['allowSubscriptions']) {
         serendipity_mailSubscribers($entry_id, $rs['author'], $rs['email'], $rs['title'], $rs['authoremail'], $cid);
     }
+
+    serendipity_plugin_api::hook_event('backend_approvecomment', $rs);
     return true;
 }
 
@@ -555,12 +570,14 @@ function serendipity_saveComment($id, $commentInfo, $type = 'NORMAL', $source =
         $parentid      = (isset($commentInfo['parent_id']) && is_numeric($commentInfo['parent_id'])) ? $commentInfo['parent_id'] : 0;
         $status        = serendipity_db_escape_string(isset($commentInfo['status']) ? $commentInfo['status'] : (serendipity_db_bool($ca['moderate_comments']) ? 'pending' : 'approved'));
         $t             = serendipity_db_escape_string(isset($commentInfo['time']) ? $commentInfo['time'] : time());
-        $referer       = (isset($_SESSION['HTTP_REFERER']) ? serendipity_db_escape_string($_SESSION['HTTP_REFERER']) : '');
+        $referer       = substr((isset($_SESSION['HTTP_REFERER']) ? serendipity_db_escape_string($_SESSION['HTTP_REFERER']) : ''), 0, 200);
 
         $query = "SELECT a.email, e.title, a.mail_comments, a.mail_trackbacks
                  FROM {$serendipity['dbPrefix']}entries e, {$serendipity['dbPrefix']}authors a
                  WHERE e.id  = '". (int)$id ."'
-                 AND e.authorid = a.authorid";
+                   AND e.isdraft = 'false'
+                   AND e.timestamp <= " . time() . "
+                   AND e.authorid = a.authorid";
         $row = serendipity_db_query($query, true); // Get info on author/entry
         if (!is_array($row) || empty($id)) {
             // No associated entry found.
@@ -617,7 +634,8 @@ function serendipity_mailSubscribers($entry_id, $poster, $posterMail, $title, $f
 
     $pgsql_insert = '';
     $mysql_insert = '';
-    if ($serendipity['dbType'] == 'postgres') {
+    if ($serendipity['dbType'] == 'postgres' ||
+        $serendipity['dbType'] == 'pdo-postgres') {
         $pgsql_insert = 'DISTINCT ON (email)';
     } else {
         $mysql_insert = 'GROUP BY email';
