@@ -1,4 +1,4 @@
-<?php # $Id: functions_config.inc.php 1618 2007-02-13 08:35:56Z garvinhicking $
+<?php # $Id: functions_config.inc.php 1860 2007-08-21 10:26:07Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -97,6 +97,11 @@ function serendipity_set_config_var($name, $val, $authorid = 0) {
     global $serendipity;
 
     serendipity_db_query("DELETE FROM {$serendipity['dbPrefix']}config where name='" . serendipity_db_escape_string($name) . "' AND authorid = " . (int)$authorid);
+
+    if ($name == 'password' || $name == 'check_password') {
+        return;
+    }
+
     $r = serendipity_db_insert('config', array('name' => $name, 'value' => $val, 'authorid' => $authorid));
 
     if ($authorid === 0 || $authorid === $serendipity['authorid']) {
@@ -318,6 +323,9 @@ function serendipity_load_configuration($author = null) {
         }
     }
     $config_loaded[$author] = true;
+
+    // Store default language
+    $serendipity['default_lang'] = $serendipity['lang'];
 }
 
 /**
@@ -328,8 +336,24 @@ function serendipity_load_configuration($author = null) {
  */
 function serendipity_logout() {
     $_SESSION['serendipityAuthedUser'] = false;
-    @session_destroy();
+    serendipity_session_destroy();
     serendipity_deleteCookie('author_information');
+    serendipity_deleteCookie('author_token');
+}
+
+/**
+ * Destroys a session, keeps important stuff intact.
+ * @access public
+ * @return null
+ */
+function serendipity_session_destroy() {
+    $no_smarty = $_SESSION['no_smarty'];
+    @session_destroy();
+    session_regenerate_id();
+    session_start();
+
+    $_SESSION['SERVER_GENERATED_SID'] = true;
+    $_SESSION['no_smarty']            = $no_smarty;
 }
 
 /**
@@ -396,13 +420,15 @@ function serendipity_issueAutologin($array) {
     }
     $package = base64_encode($package);
 
-    $rnd = md5(time() . $_SERVER['REMOTE_ADDR']);
+    $rnd = md5(uniqid(time(), true) . $_SERVER['REMOTE_ADDR']);
 
-    // Delete possible current cookie
-    serendipity_db_query("DELETE FROM {$serendipity['dbPrefix']}options WHERE okey = '" . serendipity_db_escape_string($serendipity['COOKIE']['author_information']) . "'");
+    // Delete possible current cookie. Also delete any autologin keys that smell like 3-week-old, dead fish.
+    serendipity_db_query("DELETE FROM {$serendipity['dbPrefix']}options 
+                                WHERE okey = 'l_" . serendipity_db_escape_string($serendipity['COOKIE']['author_information']) . "'
+                                   OR (okey LIKE 'l_%' AND name < " . (time() - 1814400) . ")");
 
     // Issue new autologin cookie
-    serendipity_db_query("INSERT INTO {$serendipity['dbPrefix']}options (name, value, okey) VALUES ('" . time() . "', '" . serendipity_db_escape_string($package) . "', '" . $rnd . "')");
+    serendipity_db_query("INSERT INTO {$serendipity['dbPrefix']}options (name, value, okey) VALUES ('" . time() . "', '" . serendipity_db_escape_string($package) . "', 'l_" . $rnd . "')");
     serendipity_setCookie('author_information', $rnd);
 }
 
@@ -414,7 +440,7 @@ function serendipity_checkAutologin($ident, $iv) {
     global $serendipity;
 
     // Fetch login data from DB
-    $autologin =& serendipity_db_query("SELECT * FROM {$serendipity['dbPrefix']}options WHERE okey = '" . serendipity_db_escape_string($ident) . "' LIMIT 1", true, 'assoc');
+    $autologin =& serendipity_db_query("SELECT * FROM {$serendipity['dbPrefix']}options WHERE okey = 'l_" . serendipity_db_escape_string($ident) . "' LIMIT 1", true, 'assoc');
     if (!is_array($autologin)) {
         return false;
     }
@@ -429,13 +455,22 @@ function serendipity_checkAutologin($ident, $iv) {
 
     if ($autologin['name'] < (time()-86400)) {
         // Issued autologin cookie has been issued more than 1 day ago. Re-Issue new cookie, invalidate old one to prevent abuse
-        serendipity_header('X-ReIssue-Cookie: +' . (time() - $autologin['name']) . 's');
+        if ($serendipity['expose_s9y']) serendipity_header('X-ReIssue-Cookie: +' . (time() - $autologin['name']) . 's');
         serendipity_issueAutologin($cookie);
     }
 
     return $cookie;
 }
 
+/**
+ * Set a session cookie which can identify a user accross http/https boundaries
+ */
+function serendipity_setAuthorToken() {
+    $hash = sha1(uniqid(rand(), true));
+    serendipity_setCookie('author_token', $hash);
+    $_SESSION['author_token'] = $hash;
+}
+
 /**
  * Perform user authentication routine
  *
@@ -460,6 +495,12 @@ function serendipity_authenticate_author($username = '', $password = '', $is_md5
         $is_md5 = true;
     }
 
+    $is_authenticated = false;
+    serendipity_plugin_api::hook_event('backend_login', $is_authenticated, NULL);
+    if ($is_authenticated) {
+        return true;
+    }
+
     if ($username != '') {
         if ($use_external) {
             serendipity_plugin_api::hook_event('backend_auth', $is_md5, array('username' => $username, 'password' => $password));
@@ -479,7 +520,10 @@ function serendipity_authenticate_author($username = '', $password = '', $is_md5
         $row =& serendipity_db_query($query, true, 'assoc');
 
         if (is_array($row)) {
-            serendipity_setCookie('old_session', session_id());
+            serendipity_setCookie('old_session', session_id(), false);
+            if (!$is_md5) {
+                serendipity_setAuthorToken();
+            }
             $_SESSION['serendipityUser']        = $serendipity['serendipityUser']         = $username;
             $_SESSION['serendipityRealname']    = $serendipity['serendipityRealname']     = $row['realname'];
             $_SESSION['serendipityPassword']    = $serendipity['serendipityPassword']     = $password;
@@ -489,10 +533,11 @@ function serendipity_authenticate_author($username = '', $password = '', $is_md5
             $_SESSION['serendipityAuthedUser']  = $serendipity['serendipityAuthedUser']   = true;
             $_SESSION['serendipityRightPublish']= $serendipity['serendipityRightPublish'] = $row['right_publish'];
             serendipity_load_configuration($serendipity['authorid']);
+            serendipity_setCookie('userDefLang', $serendipity['lang'], false);
             return true;
         } else {
             $_SESSION['serendipityAuthedUser'] = false;
-            @session_destroy();
+            serendipity_session_destroy();
         }
     }
 
@@ -560,11 +605,26 @@ function serendipity_JSsetCookie($name, $value) {
  * @param   string      The contents of the cookie variable
  * @return null
  */
-function serendipity_setCookie($name,$value) {
+function serendipity_setCookie($name, $value, $securebyprot = true) {
     global $serendipity;
 
-    $secure = (strtolower($_SERVER['HTTPS']) == 'on') ? true : false;
-    setcookie("serendipity[$name]", $value, time()+60*60*24*30, $serendipity['serendipityHTTPPath'], $_SERVER['HTTP_HOST'], $secure);
+    $host = $_SERVER['HTTP_HOST'];
+    if ($securebyprot) {
+        $secure = (strtolower($_SERVER['HTTPS']) == 'on') ? true : false;
+        if ($pos = strpos($host, ":")) {
+            $host = substr($host, 0, $pos);
+        }
+    } else {
+        $secure = false;
+    }
+    
+    // If HTTP-Hosts like "localhost" are used, current browsers reject cookies.
+    // In this case, we disregard the HTTP host to be able to set that cookie.
+    if (substr_count($host, '.') < 2) {
+        $host = '';
+    }
+
+    setcookie("serendipity[$name]", $value, time()+60*60*24*30, $serendipity['serendipityHTTPPath'], $host, $secure);
     $_COOKIE[$name] = $value;
     $serendipity['COOKIE'][$name] = $value;
 }
@@ -581,7 +641,12 @@ function serendipity_setCookie($name,$value) {
 function serendipity_deleteCookie($name) {
     global $serendipity;
 
-    setcookie("serendipity[$name]", '', time()-4000);
+    $host = $_SERVER['HTTP_HOST'];
+    if ($pos = strpos($host, ":")) {
+        $host = substr($host, 0, $pos);
+    }
+
+    setcookie("serendipity[$name]", '', time()-4000, $serendipity['serendipityHTTPPath'], $host);
     unset($_COOKIE[$name]);
     unset($serendipity['COOKIE'][$name]);
 }
@@ -659,7 +724,7 @@ function serendipity_iframe(&$entry, $mode = null, $use_smarty = true) {
                     echo '<script type="text/javascript">parent.document.forms[\'serendipityEntry\'][\'serendipity[id]\'].value = "' . $serendipity['lastSavedEntry'] . '";</script>';
                 }
                 $entrylink = serendipity_archiveURL($res, $entry['title'], 'serendipityHTTPPath', true, array('timestamp' => $entry['timestamp']));
-                echo '<div class="serendipityAdminMsgSuccess">' . ENTRY_SAVED . ' (<a href="' . $entrylink . '" target="_blank">' . VIEW . '</a>)</div>';
+                echo '<div class="serendipityAdminMsgSuccess"><img style="height: 22px; width: 22px; border: 0px; padding-right: 4px; vertical-align: middle" src="' . serendipity_getTemplateFile('admin/img/admin_msg_success.png') . '" alt="" />' . ENTRY_SAVED . ' (<a href="' . $entrylink . '" target="_blank">' . VIEW . '</a>)</div>';
             }
             echo '<br style="clear: both" />';
 
@@ -705,7 +770,7 @@ function serendipity_iframe_create($mode, &$entry) {
 
     $_SESSION['save_entry']      = $entry;
     $_SESSION['save_entry_POST'] = $serendipity['POST'];
-
+    
     $attr = '';
     switch($mode) {
         case 'save':
@@ -739,6 +804,10 @@ function serendipity_probeInstallation($item) {
             if (extension_loaded('mysql')) {
                 $res['mysql'] = 'MySQL';
             }
+            if (extension_loaded('PDO') &&
+                in_array('pgsql', PDO::getAvailableDrivers())) {
+                $res['pdo-postgres'] = 'PDO::PostgreSQL';
+            }
             if (extension_loaded('pgsql')) {
                 $res['postgres'] = 'PostgreSQL';
             }
@@ -748,6 +817,9 @@ function serendipity_probeInstallation($item) {
             if (extension_loaded('sqlite')) {
                 $res['sqlite'] = 'SQLite';
             }
+            if (extension_loaded('SQLITE3')) {
+                $res['sqlite3'] = 'SQLite3';
+            }
             break;
 
         case 'rewrite' :
@@ -792,9 +864,6 @@ function serendipity_header($header) {
 function serendipity_getSessionLanguage() {
     global $serendipity;
 
-    // Store default language
-    $serendipity['default_lang'] = $serendipity['lang'];
-
     // DISABLE THIS!
 /*
     if ($_SESSION['serendipityAuthedUser']) {
@@ -804,7 +873,7 @@ function serendipity_getSessionLanguage() {
 */
 
     if (isset($_REQUEST['user_language']) && (!empty($serendipity['languages'][$_REQUEST['user_language']])) && !headers_sent()) {
-        serendipity_setCookie('serendipityLanguage', $_REQUEST['user_language']);
+        serendipity_setCookie('serendipityLanguage', $_REQUEST['user_language'], false);
     }
 
     if (isset($serendipity['COOKIE']['serendipityLanguage'])) {
@@ -816,14 +885,63 @@ function serendipity_getSessionLanguage() {
     } elseif (serendipity_db_bool($serendipity['lang_content_negotiation'])) {
         if ($serendipity['expose_s9y']) serendipity_header('X-Serendipity-InterfaceLangSource: Content-Negotiation');
         $lang = serendipity_detectLang();
-    } elseif ($_SESSION['serendipityAuthedUser']) {
+    }
+
+    if (isset($lang)) {
+        $serendipity['detected_lang'] = $lang;
+    } else {
+        if (! empty($_SESSION['serendipityLanguage'])) {
+            $lang = $_SESSION['serendipityLanguage'];
+        } else {
+            if (isset($serendipity['COOKIE']['userDefLang']) && ! empty($serendipity['COOKIE']['userDefLang'])) {
+                $lang = $serendipity['COOKIE']['userDefLang'];
+            } else {
+                $lang = $serendipity['lang'];
+          	}
+        }
+        $serendipity['detected_lang'] = null;
+    }
+
+    if (!isset($serendipity['languages'][$lang])) {
+        $serendipity['detected_lang'] = null;
+        return $serendipity['lang'];
+    } else {
+        $_SESSION['serendipityLanguage'] = $lang;
+        if (!is_null($serendipity['detected_lang'])) {
+            if ($serendipity['expose_s9y']) serendipity_header('X-Serendipity-InterfaceLang: ' . $lang);
+        }
+    }
+
+    return $lang;
+}
+
+/**
+ * Gets the selected language from personal configuration if needed
+ *
+ * This function also sets HTTP Headers and cookies to contain the language for follow-up requests
+ *
+ * @access public
+ * @return  string      Returns the name of the selected language.
+ */
+function serendipity_getPostAuthSessionLanguage() {
+    global $serendipity;
+
+    if (! is_null($serendipity['detected_lang'])) {
+        return $serendipity['detected_lang'];
+    }
+
+    if ($_SESSION['serendipityAuthedUser']) {
         if ($serendipity['expose_s9y']) serendipity_header('X-Serendipity-InterfaceLangSource: Database');
         $lang = $serendipity['lang'];
+    } else {
+        $lang = (isset($_SESSION['serendipityLanguage']))?$_SESSION['serendipityLanguage']:$serendipity['lang'];
+    }
+
+    if (!isset($serendipity['languages'][$lang])) {
+        $lang = $serendipity['lang'];
     }
 
-    if (!isset($lang) || !isset($serendipity['languages'][$lang])) {
-        $lang = $serendipity['lang'];
-    }
+    $_SESSION['serendipityLanguage'] = $lang;
 
     if ($serendipity['expose_s9y']) serendipity_header('X-Serendipity-InterfaceLang: ' . $lang);
 
@@ -1160,14 +1278,15 @@ function &serendipity_getGroups($authorid, $sequence = false) {
     }
 
     if ($sequence) {
-        $_groups = $groups;
-        $groups  = array();
-        foreach($_groups AS $grouprow) {
-            $groups[] = $grouprow['confkey'];
+        $rgroups  = array();
+        foreach($groups AS $grouprow) {
+            $rgroups[] = $grouprow['confkey'];
         }
+    } else {
+        $rgroups =& $groups;
     }
 
-    return $groups;
+    return $rgroups;
 }
 
 /**
@@ -1766,7 +1885,7 @@ function serendipity_reportXSRF($type = 0, $reset = true, $use_config = false) {
     // Set this in your serendipity_config_local.inc.php if you want HTTP Referrer blocking:
     // $serendipity['referrerXSRF'] = true;
 
-    $string = '<div class="serendipityAdminMsgError XSRF_' . $type . '">' . ERROR_XSRF . '</div>';
+    $string = '<div class="serendipityAdminMsgError XSRF_' . $type . '"><img style="width: 22px; height: 22px; border: 0px; padding-right: 4px; vertical-align: middle" src="' . serendipity_getTemplateFile('admin/img/admin_msg_error.png') . '" alt="" />' . ERROR_XSRF . '</div>';
     if ($reset) {
         // Config key "referrerXSRF" can be set to enable blocking based on HTTP Referrer. Recommended for Paranoia.
         if (($use_config && isset($serendipity['referrerXSRF']) && $serendipity['referrerXSRF']) || $use_config === false) {
@@ -1843,10 +1962,22 @@ function serendipity_setFormToken($type = 'form') {
     }
 }
 
-function &serendipity_loadThemeOptions(&$template_config) {
+/**
+ * Load available/configured options for a specific theme (through config.inc.php of a template directory)
+ * into an array.
+ *
+ * @param   array   Referenced variable coming from the config.inc.php file, where the config values will be stored in
+ * @return  array   Final return array with default values
+ */
+function &serendipity_loadThemeOptions(&$template_config, $okey = '') {
     global $serendipity;
+    
+    if (empty($okey)) {
+        $okey = $serendipity['template'];
+    }
+
     $_template_vars =& serendipity_db_query("SELECT name, value FROM {$serendipity['dbPrefix']}options
-                                             WHERE okey = 't_" . serendipity_db_escape_string($serendipity['template']) . "'", false, 'assoc', false, 'name', 'value');
+                                             WHERE okey = 't_" . serendipity_db_escape_string($okey) . "'", false, 'assoc', false, 'name', 'value');
     if (!is_array($_template_vars)) {
         $template_vars = array();
     } else {
@@ -1862,6 +1993,13 @@ function &serendipity_loadThemeOptions(&$template_config) {
     return $template_vars;
 }
 
+/**
+ * Check if a member of a group has permissions to execute a plugin
+ *
+ * @param string    Pluginname
+ * @param int       ID of the group of which the members should be checked
+ * @return boolean
+ */
 function serendipity_hasPluginPermissions($plugin, $groupid = null) {
     static $forbidden = null;
     global $serendipity;
