@@ -1,4 +1,4 @@
-<?php # $Id: functions_entries.inc.php 1661 2007-04-01 11:17:35Z garvinhicking $
+<?php # $Id: functions_entries.inc.php 2062 2007-12-06 11:13:42Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -41,12 +41,17 @@ function serendipity_deleteCategory($category_range, $admin_category) {
 function serendipity_fetchCategoryRange($categoryid) {
     global $serendipity;
 
-    $res =& serendipity_db_query("SELECT category_left, category_right FROM {$serendipity['dbPrefix']}category WHERE categoryid='". (int)$categoryid ."'");
+    $res =& serendipity_db_query("SELECT category_left, category_right, hide_sub FROM {$serendipity['dbPrefix']}category WHERE categoryid='". (int)$categoryid ."'");
     if (!is_array($res) || !isset($res[0]['category_left']) || !isset($res[0]['category_right'])) {
         $res = array(array('category_left' => 0, 'category_right' => 0));
     }
 
-    return array('category_left' => $res[0]['category_left'], 'category_right' => $res[0]['category_right']);
+    if ($res[0]['hide_sub'] == 1) {
+        // Set ranges only to own category. Patch by netmorix
+        return array('category_left' => $res[0]['category_left'], 'category_right' => $res[0]['category_left']);
+    } else {
+        return array('category_left' => $res[0]['category_left'], 'category_right' => $res[0]['category_right']);
+    }
 }
 
 /**
@@ -98,7 +103,8 @@ function serendipity_fetchCategoryInfo($categoryid, $categoryname = '') {
                          c.category_name,
                          c.category_description,
                          c.category_icon,
-                         c.parentid
+                         c.parentid,
+                         c.hide_sub
                     FROM {$serendipity['dbPrefix']}category AS c
                    WHERE category_name = '" . serendipity_db_escape_string($categoryname) . "'";
 
@@ -111,7 +117,8 @@ function serendipity_fetchCategoryInfo($categoryid, $categoryname = '') {
                          c.category_name,
                          c.category_description,
                          c.category_icon,
-                         c.parentid
+                         c.parentid,
+                         c.hide_sub
                     FROM {$serendipity['dbPrefix']}category AS c
                    WHERE categoryid = " . (int)$categoryid;
 
@@ -331,7 +338,8 @@ function &serendipity_fetchEntries($range = null, $full = true, $limit = '', $fe
 
     serendipity_plugin_api::hook_event('frontend_fetchentries', $cond, array('noCache' => $noCache, 'noSticky' => $noSticky, 'source' => 'entries'));
 
-    if ($serendipity['dbType'] == 'postgres') {
+    if ($serendipity['dbType'] == 'postgres' ||
+        $serendipity['dbType'] == 'pdo-postgres') {
         $group    = '';
         $distinct = 'DISTINCT';
     } else {
@@ -618,7 +626,8 @@ function &serendipity_fetchCategories($authorid = null, $name = null, $order = n
         $where .= " c.category_name = '" . serendipity_db_escape_string($name) . "'";
     }
 
-    if ($serendipity['dbType'] == 'postgres') {
+    if ($serendipity['dbType'] == 'postgres' ||
+        $serendipity['dbType'] == 'pdo-postgres') {
         $group    = '';
         $distinct = 'DISTINCT';
     } else {
@@ -708,11 +717,12 @@ function &serendipity_searchEntries($term, $limit = '') {
 
     $term = serendipity_db_escape_string($term);
     $cond = array();
-    if ($serendipity['dbType'] == 'postgres') {
+    if ($serendipity['dbType'] == 'postgres' ||
+        $serendipity['dbType'] == 'pdo-postgres') {
         $group     = '';
         $distinct  = 'DISTINCT';
         $cond['find_part'] = "(title ILIKE '%$term%' OR body ILIKE '%$term%' OR extended ILIKE '%$term%')";
-    } elseif ($serendipity['dbType'] == 'sqlite') {
+    } elseif ($serendipity['dbType'] == 'sqlite' || $serendipity['dbType'] == 'sqlite3') {
         // Very extensive SQLite search. There currently seems no other way to perform fulltext search in SQLite
         // But it's better than no search at all :-D
         $group     = 'GROUP BY e.id';
@@ -732,7 +742,6 @@ function &serendipity_searchEntries($term, $limit = '') {
 
     $cond['and'] = " AND isdraft = 'false' " . (!serendipity_db_bool($serendipity['showFutureEntries']) ? " AND timestamp <= " . serendipity_db_time() : '');
     serendipity_plugin_api::hook_event('frontend_fetchentries', $cond, array('source' => 'search', 'term' => $term));
-
     serendipity_ACL_SQL($cond, 'limited');
 
     $serendipity['fullCountQuery'] = "
@@ -837,7 +846,7 @@ function serendipity_getTotalEntries() {
     global $serendipity;
 
     // The unique query condition was built previously in serendipity_fetchEntries()
-    if ($serendipity['dbType'] == 'sqlite') {
+    if ($serendipity['dbType'] == 'sqlite' || $serendipity['dbType'] == 'sqlite3') {
         $querystring  = "SELECT count(e.id) {$serendipity['fullCountQuery']} GROUP BY e.id";
     } else {
         $querystring  = "SELECT count(distinct e.id) {$serendipity['fullCountQuery']}";
@@ -846,7 +855,7 @@ function serendipity_getTotalEntries() {
     $query =& serendipity_db_query($querystring);
 
     if (is_array($query) && isset($query[0])) {
-        if ($serendipity['dbType'] == 'sqlite') {
+        if ($serendipity['dbType'] == 'sqlite' || $serendipity['dbType'] == 'sqlite3') {
             return count($query);
         } else {
             return $query[0][0];
@@ -943,17 +952,15 @@ function serendipity_printEntries($entries, $extended = 0, $preview = false, $sm
                 $entry['is_cached'] = true;
             }
 
-	    //--JAM: Highlight-span search terms
-	    if ($serendipity['action'] == 'search') {
-	        $searchterms = str_replace('"', '', $serendipity['GET']['searchterms']);
-	        $searchterms = explode($searchterms, ' ');
-		foreach($searchterms as $searchdx => $searchterm) {
-		    $searchclass = "foundterm foundterm".$searchdx;
-		    $entry['body'] = preg_replace('/('.$searchterm.')/mi',
-		        '<span class="'.$searchclass.'">\1</span>',
-			$entry['body']);
-		}
-	    }
+            //--JAM: Highlight-span search terms
+            if ($serendipity['action'] == 'search') {
+                $searchterms = str_replace('"', '', $serendipity['GET']['searchterms']);
+                $searchterms = explode($searchterms, ' ');
+                foreach($searchterms as $searchdx => $searchterm) {
+                    $searchclass = "foundterm foundterm".$searchdx;
+                    $entry['body'] = str_replace($searchterm, '<span class="'.$searchclass.'">' . $searchterm . '</span>', $entry['body']);
+                }
+            }
 
             if (!empty($entry['properties']['ep_cache_extended'])) {
                 $entry['extended']  = &$entry['properties']['ep_cache_extended'];
@@ -1460,6 +1467,25 @@ function serendipity_printArchives() {
         $author_get = '';
     }
 
+    $q = "SELECT e.timestamp
+            FROM {$serendipity['dbPrefix']}entries e
+            " . (!empty($cat_sql) ? "
+       LEFT JOIN {$serendipity['dbPrefix']}entrycat ec
+              ON e.id = ec.entryid
+       LEFT JOIN {$serendipity['dbPrefix']}category c
+              ON ec.categoryid = c.categoryid" : "") . "
+           WHERE isdraft = 'false'"
+                . (!serendipity_db_bool($serendipity['showFutureEntries']) ? " AND timestamp <= " . serendipity_db_time() : '')
+                . (!empty($cat_sql) ? ' AND ' . $cat_sql : '')
+                . (!empty($serendipity['GET']['viewAuthor']) ? ' AND e.authorid = ' . (int)$serendipity['GET']['viewAuthor'] : '') 
+                . (!empty($cat_sql) ? " GROUP BY e.id" : '');
+    $entries =& serendipity_db_query($q, false, 'assoc');
+
+    $group = array();
+    foreach($entries AS $entry) {
+        $group[date('Ym', $entry['timestamp'])]++;
+    }
+
     $output = array();
     for ($y = $thisYear; $y >= $lastYear; $y--) {
         $output[$y]['year'] = $y;
@@ -1488,24 +1514,7 @@ function serendipity_printArchives() {
                     break;
             }
 
-            $entries =& serendipity_db_query("SELECT count(id)
-                                               FROM {$serendipity['dbPrefix']}entries e
-                                          LEFT JOIN {$serendipity['dbPrefix']}entrycat ec
-                                                 ON e.id = ec.entryid
-                                          LEFT JOIN {$serendipity['dbPrefix']}category c
-                                                 ON ec.categoryid = c.categoryid
-                                              WHERE isdraft = 'false'
-                                                AND timestamp >= $s
-                                                AND timestamp <= $e "
-                                                    . (!serendipity_db_bool($serendipity['showFutureEntries']) ? " AND timestamp <= " . serendipity_db_time() : '')
-                                                    . (!empty($cat_sql) ? ' AND ' . $cat_sql : '')
-                                                    . (!empty($serendipity['GET']['viewAuthor']) ? ' AND e.authorid = ' . (int)$serendipity['GET']['viewAuthor'] : '') . "
-                                           GROUP BY ec.entryid", false, 'assoc');
-            if (is_array($entries)) {
-                $entry_count = count($entries);
-            } else {
-                $entry_count = 0;
-            }
+            $entry_count = (int)$group[$y . (strlen($m) == 1 ? '0' : '') . $m];
 
             /* A silly hack to get the maximum amount of entries per month */
             if ($entry_count > $max) {
