@@ -1,4 +1,4 @@
-<?php # $Id: functions_installer.inc.php 1520 2006-11-30 21:34:29Z garvinhicking $
+<?php # $Id: functions_installer.inc.php 1767 2007-07-12 09:36:32Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -182,6 +182,10 @@ function serendipity_query_default($optname, $default, $usertemplate = false, $t
             if (extension_loaded('mysqli')) {
                 $type = 'mysqli';
             }
+            if (extension_loaded('PDO') &&
+                in_array('pgsql', PDO::getAvailableDrivers())) {
+                $type = 'pdo-postgres';
+            }
             if (extension_loaded('pgsql')) {
                 $type = 'postgres';
             }
@@ -237,11 +241,11 @@ function serendipity_query_default($optname, $default, $usertemplate = false, $t
             $path[] = '/usr/local/bin';
 
             foreach ($path as $dir) {
-                if (!empty($dir) && (function_exists('is_executable') && @is_executable($dir . '/convert')) || @is_file($dir . '/convert')) {
+                if (!empty($dir) && (function_exists('is_executable') && is_readable($dir) && @is_executable($dir . '/convert')) || @is_file($dir . '/convert')) {
                     return $dir . '/convert';
                 }
 
-                if (!empty($dir) && (function_exists('is_executable') && @is_executable($dir . '/convert.exe')) || @is_file($dir . '/convert.exe')) {
+                if (!empty($dir) && (function_exists('is_executable') && is_readable($dir . '/convert') && @is_executable($dir . '/convert.exe')) || @is_file($dir . '/convert.exe')) {
                     return $dir . '/convert.exe';
                 }
             }
@@ -375,20 +379,21 @@ function serendipity_replaceEmbeddedConfigVars ($s) {
  * @param   string  The default value of the configuration item
  * @return null
  */
+
 function serendipity_guessInput($type, $name, $value='', $default='') {
     global $serendipity;
 
     switch ($type) {
         case 'bool':
             $value = serendipity_get_bool($value);
-            echo '<input id="radio_cfg_' . $name . '_yes" type="radio" name="' . $name . '" value="true" ';
+            echo '<input class="input_radio" id="radio_cfg_' . $name . '_yes" type="radio" name="' . $name . '" value="true" ';
             echo (($value == true) ? 'checked="checked"' : ''). ' /><label for="radio_cfg_' . $name . '_yes"> ' . YES . '</label>&nbsp;';
-            echo '<input id="radio_cfg_' . $name . '_no" type="radio" name="' . $name . '" value="false" ';
+            echo '<input class="input_radio" id="radio_cfg_' . $name . '_no" type="radio" name="' . $name . '" value="false" ';
             echo (($value == true) ? '' : 'checked="checked"'). ' /><label for="radio_cfg_' . $name . '_no"> ' . NO . '</label>';
             break;
 
         case 'protected':
-            echo '<input type="password" size="30" name="' . $name . '" value="' . htmlspecialchars($value) . '" />';
+            echo '<input class="input_textbox" type="password" size="30" name="' . $name . '" value="' . htmlspecialchars($value) . '" />';
             break;
 
         case 'multilist':
@@ -425,7 +430,7 @@ function serendipity_guessInput($type, $name, $value='', $default='') {
             break;
 
         case 'file':
-            echo '<input type="file" size="30" name="' . $name . '" />';
+            echo '<input class="input_file" type="file" size="30" name="' . $name . '" />';
             break;
 
         case 'textarea':
@@ -433,7 +438,7 @@ function serendipity_guessInput($type, $name, $value='', $default='') {
             break;
 
         default:
-            echo '<input type="text" size="30" name="' . $name . '" value="' . htmlspecialchars($value) . '" />';
+            echo '<input class="input_textbox" type="text" size="30" name="' . $name . '" value="' . htmlspecialchars($value) . '" />';
             break;
     }
 }
@@ -447,9 +452,10 @@ function serendipity_guessInput($type, $name, $value='', $default='') {
  * @param   boolean     If true, no HTML FORM container will be emitted
  * @param   boolean     If true, the configuration sections will all be folded
  * @param   boolean     If true, the user can turn config sections on and off
+ * @param   boolean     If true, the user can NOT display possibly dangerous options
  * @return null
  */
-function serendipity_printConfigTemplate($config, $from = false, $noForm = false, $folded = true, $allowToggle = true) {
+function serendipity_printConfigTemplate($config, $from = false, $noForm = false, $folded = true, $allowToggle = true, $showDangerous = false) {
     global $serendipity;
     if ( $allowToggle ) {
 ?>
@@ -514,7 +520,7 @@ function showConfigAll(count) {
 ?>
             <tr>
                 <th align="left" colspan="2" style="padding-left: 15px;">
-<?php if ( $allowToggle ) { ?>
+<?php if ($allowToggle) { ?>
                     <a style="border:0; text-decoration: none;" href="#" onClick="showConfig('el<?php echo $el_count; ?>'); return false" title="<?php echo TOGGLE_OPTION; ?>"><img src="<?php echo serendipity_getTemplateFile('img/'. ($folded === true ? 'plus' : 'minus') .'.png') ?>" id="optionel<?php echo $el_count; ?>" alt="+/-" border="0" />&nbsp;<?php echo $category['title']; ?></a>
 <?php } else { ?>
                     <?php echo $category['title']; ?>
@@ -532,7 +538,7 @@ function showConfigAll(count) {
                         </tr>
 
 <?php
-        foreach ( $category['items'] as $item ) {
+        foreach ($category['items'] as $item) {
 
             $value = $from[$item['var']];
 
@@ -542,13 +548,17 @@ function showConfigAll(count) {
             }
 
             /* Check for installOnly flag */
-            if ( in_array('installOnly', $item['flags']) && IS_installed === true ) {
+            if (in_array('installOnly', $item['flags']) && IS_installed === true) {
                 continue;
             }
 
-            if ( in_array('hideValue', $item['flags']) ) {
+            if (in_array('hideValue', $item['flags'])) {
                 $value = '';
             }
+            
+            if (!$showDangerous && $item['view'] == 'dangerous') {
+                continue;
+            }
 
             if (in_array('config', $item['flags']) && isset($from['authorid'])) {
                 $value = serendipity_get_user_config_var($item['var'], $from['authorid'], $item['default']);
@@ -596,7 +606,7 @@ function showConfigAll(count) {
 
     if (!$noForm) {
 ?>
-        <input type="submit" value="<?php echo CHECK_N_SAVE; ?>" class="serendipityPrettyButton" />
+        <input type="submit" value="<?php echo CHECK_N_SAVE; ?>" class="serendipityPrettyButton input_button" />
     </div>
 </form>
 <?php
@@ -718,7 +728,7 @@ function serendipity_checkInstallation() {
         $errs[] = sprintf(CANT_EXECUTE_BINARY, 'convert imagemagick');
     }
 
-    if ($_POST['dbType'] == 'sqlite') {
+    if ($_POST['dbType'] == 'sqlite' || $_POST['dbType'] == 'sqlite3') {
         // We don't want that our SQLite db file can be guessed from other applications on a server
         // and have access to our's. So we randomize the SQLite dbname.
         $_POST['sqlitedbName'] = $_POST['dbName'] . '_' . md5(time());
@@ -776,6 +786,11 @@ function serendipity_installFiles($serendipity_core = '') {
         $htaccess_cgi = '';
     }
 
+    /* If this file exists, a previous install failed painfully. We must consider the safer alternative now */
+    if (file_exists($serendipity_core . '.installer_detection_failsafe')) {
+        $htaccess_cgi = '_cgi';
+        @unlink($serendipity_core . '.htaccess');
+    }
 
     /* Detect comptability with php_value directives */
     if ($htaccess_cgi == '') {
@@ -788,8 +803,10 @@ function serendipity_installFiles($serendipity_core = '') {
         if ($fp) {
             fwrite($fp, 'php_value register_globals off'. "\n" .'php_value session.use_trans_sid 0');
             fclose($fp);
-
-            $sock = @fsockopen($serendipity_host, $_SERVER['SERVER_PORT'], $errorno, $errorstring, 10);
+            
+            $safeFP = @fopen($serendipity_core . '.installer_detection_failsafe', 'w');
+            fclose($safeFP);
+            $sock = fsockopen($serendipity_host, $_SERVER['SERVER_PORT'], $errorno, $errorstring, 10);
             if ($sock) {
                 fputs($sock, "GET {$serendipityHTTPPath} HTTP/1.0\r\n");
                 fputs($sock, "Host: $serendipity_host\r\n");
@@ -802,7 +819,7 @@ function serendipity_installFiles($serendipity_core = '') {
                 fclose($sock);
             }
 
-            /* If we get HTTP 500 Internal Server Error, we have to use the .cgi template */
+            # If we get HTTP 500 Internal Server Error, we have to use the .cgi template
             if (preg_match('@^HTTP/\d\.\d 500@', $response)) {
                 $htaccess_cgi = '_cgi';
             }
@@ -814,6 +831,8 @@ function serendipity_installFiles($serendipity_core = '') {
             } else {
                 @unlink($serendipity_core . '.htaccess');
             }
+
+            @unlink($serendipity_core . '.installer_detection_failsafe');
         }
     }
 
