@@ -22,6 +22,7 @@ if (defined('S9Y_FRAMEWORK_PERMALINKS')) {
 function serendipity_makeFilename($str, $stripDots = false) {
     static $from = array(
                      ' ',
+                     '%',
 
                      '',
                      '',
@@ -65,6 +66,7 @@ function serendipity_makeFilename($str, $stripDots = false) {
 
     static $to   = array(
                      '-',
+                     '%25',
 
                      'AE',
                      'ae',
@@ -280,12 +282,10 @@ function &serendipity_permalinkPatterns($return = false) {
     $PAT['ADMIN']                    = '@/(' . $serendipity['permalinkAdminPath'] . '|entries)(/.+)?@';
     $PAT['ARCHIVE']                  = '@/'  . $serendipity['permalinkArchivePath'] . '/?@';
     $PAT['CATEGORIES']               = '@/'  . $serendipity['permalinkCategoriesPath'].'/([0-9;]+)@';
-    $PAT['PLUGIN']                   = '@/('  . $serendipity['permalinkPluginPath'] . '|plugin)/(.*)@';
+    $PAT['PLUGIN']                   = '@/(' . $serendipity['permalinkPluginPath'] . '|plugin)/(.*)@';
     $PAT['SEARCH']                   = '@/'  . $serendipity['permalinkSearchPath'] . '/(.*)@';
     $PAT['COMMENTS']                 = '@/'  . $serendipity['permalinkCommentsPath'] . '/(.*)@';
-    // PATCH FOR UPCOMING 1.2:
-    // $PAT['PERMALINK']             = '@('   . serendipity_makePermalinkRegex($serendipity['permalinkStructure'], 'entry') . ')/?@i';
-    $PAT['PERMALINK']                = '@'   . serendipity_makePermalinkRegex($serendipity['permalinkStructure'], 'entry') . '@i';
+    $PAT['PERMALINK']                = '@('  . serendipity_makePermalinkRegex($serendipity['permalinkStructure'], 'entry') . ')/?@i';
     $PAT['PERMALINK_CATEGORIES']     = '@'   . serendipity_makePermalinkRegex($serendipity['permalinkCategoryStructure'], 'category') . '@i';
     $PAT['PERMALINK_FEEDCATEGORIES'] = '@'   . serendipity_makePermalinkRegex($serendipity['permalinkFeedCategoryStructure'], 'category') . '@i';
     $PAT['PERMALINK_FEEDAUTHORS']    = '@'   . serendipity_makePermalinkRegex($serendipity['permalinkFeedAuthorStructure'], 'author') . '@i';
@@ -325,11 +325,7 @@ function serendipity_searchPermalink($struct, $url, $default, $type = 'entry') {
         $pq = "SELECT entry_id, data
                  FROM {$serendipity['dbPrefix']}permalinks
                 WHERE (permalink = '" . serendipity_db_escape_string($url) . "'
-                       "
-                       // PATCH FOR 1.2:
-                       // . "OR permalink = '" . serendipity_db_escape_string($default) . "'"
-                       . "
-                      )
+                   OR permalink = '" . serendipity_db_escape_string($default) . "')
                   AND type      = '" . serendipity_db_escape_string($type) . "'
                   AND entry_id  > 0
                 LIMIT 1";
@@ -505,7 +501,7 @@ function serendipity_rewriteURL($path, $key='baseURL', $forceNone = false) {
  */
 function serendipity_makePermalink($format, $data, $type = 'entry') {
     global $serendipity;
-    static $entryKeys    = array('%id%', '%title%', '%day%', '%month%', '%year%');
+    static $entryKeys    = array('%id%', '%lowertitle%', '%title%', '%day%', '%month%', '%year%');
     static $authorKeys   = array('%id%', '%username%', '%realname%', '%email%');
     static $categoryKeys = array('%id%', '%name%', '%description%');
 
@@ -523,10 +519,14 @@ function serendipity_makePermalink($format, $data, $type = 'entry') {
 
             $ts = serendipity_serverOffsetHour($data['entry']['timestamp']);
 
+            $ftitle  = serendipity_makeFilename($data['title']);
+            $fltitle = strtolower($ftitle);
+
             $replacements =
                 array(
                     (int)$data['id'],
-                    serendipity_makeFilename($data['title']),
+                    $fltitle,
+                    $ftitle,
                     date('d', $ts),
                     date('m', $ts),
                     date('Y', $ts)
@@ -568,8 +568,8 @@ function serendipity_makePermalink($format, $data, $type = 'entry') {
  * @return  string      The regular expression to a permalink URL
  */
 function serendipity_makePermalinkRegex($format, $type = 'entry') {
-    static $entryKeys           = array('%id%',     '%title%',              '%day%',      '%month%',    '%year%');
-    static $entryRegexValues    = array('([0-9]+)', PAT_FILENAME_MATCH, '[0-9]{1,2}', '[0-9]{1,2}', '[0-9]{4}');
+    static $entryKeys           = array('%id%',     '%lowertitle%',     '%title%',          '%day%',      '%month%',    '%year%');
+    static $entryRegexValues    = array('([0-9]+)', PAT_FILENAME_MATCH, PAT_FILENAME_MATCH, '[0-9]{1,2}', '[0-9]{1,2}', '[0-9]{4}');
 
     static $authorKeys          = array('%id%',     '%username%',           '%realname%',           '%email%');
     static $authorRegexValues   = array('([0-9]+)', PAT_FILENAME_MATCH, PAT_FILENAME_MATCH, PAT_FILENAME_MATCH);
@@ -755,12 +755,18 @@ function serendipity_currentURL($strict = false) {
  */
 function serendipity_getUriArguments($uri, $wildcard = false) {
 global $serendipity;
+static $indexFile = null;
+
+    if ($indexFile === null) {
+        $_indexFile = explode('.', $serendipity['indexFile']);
+        $indexFile = $_indexFile[0];
+    }
 
     /* Explode the path into sections, to later be able to check for arguments and add our own */
     preg_match('/^'. preg_quote($serendipity['serendipityHTTPPath'], '/') . '(' . preg_quote($serendipity['indexFile'], '/') . '\?\/)?(' . ($wildcard ? '.+' : '[;,_a-z0-9\-*\/%\+]+') . ')/i', $uri, $_res);
     if (strlen($_res[2]) != 0) {
         $args = explode('/', $_res[2]);
-        if ($args[0] == 'index') {
+        if ($args[0] == $indexFile || $args[0] == $serendipity['indexFile']) {
             unset($args[0]);
         }
         return $args;
