@@ -40,15 +40,25 @@ function serendipity_printEntries_rss(&$entries, $version, $comments = false, $f
     if (is_array($entries)) {
         foreach ($entries as $key => $_entry) {
             $entry = &$entries[$key];
+            
+            if (isset($entry['entrytimestamp'])) {
+                $e_ts = $entry['entrytimestamp'];
+            } else {
+                $e_ts = $entry['timestamp'];
+            }
+
             $entry['feed_id']   = (isset($entry['entryid']) && !empty($entry['entryid']) ? $entry['entryid'] : $entry['id']);
             $entry['feed_guid'] = serendipity_rss_getguid($entry, $options['comments']);
-            $entry['feed_entryLink'] = serendipity_archiveURL($entry['feed_id'], $entry['title'], 'baseURL', true, array('timestamp' => $entry['timestamp']));
+            $entry['feed_entryLink'] = serendipity_archiveURL($entry['feed_id'], $entry['title'], 'baseURL', true, array('timestamp' => $e_ts));
             if ($options['comments'] == true) {
                 // Display username as part of the title for easier feed-readability
                 if ($entry['type'] == 'TRACKBACK' && !empty($entry['ctitle'])) {
                     $entry['author'] .= ' - ' . $entry['ctitle'];
                 }
                 $entry['title'] = (!empty($entry['author']) ? $entry['author'] : ANONYMOUS) . ': ' . $entry['title'];
+                
+                // No HTML allowed here:
+                $entry['body'] = strip_tags($entry['body']);
             }
 
             // Embed a link to extended entry, if existing
@@ -61,7 +71,9 @@ function serendipity_printEntries_rss(&$entries, $version, $comments = false, $f
                 $ext = '';
             }
 
-            serendipity_plugin_api::hook_event('frontend_display', $entry);
+            $addData = array('from' => 'functions_entries:printEntries_rss','rss_options' => $options);
+            serendipity_plugin_api::hook_event('frontend_display', $entry, $addData);
+
             // Do some relative -> absolute URI replacing magic. Replaces all HREF/SRC (<a>, <img>, ...) references to only the serendipitypath with the full baseURL URI
             // garvin: Could impose some problems. Closely watch this one.
             $entry['body'] = preg_replace('@(href|src)=("|\')(' . preg_quote($serendipity['serendipityHTTPPath']) . ')(.*)("|\')(.*)>@imsU', '\1=\2' . $serendipity['baseURL'] . '\4\2\6>', $entry['body']);
@@ -131,7 +143,7 @@ function serendipity_printEntries_rss(&$entries, $version, $comments = false, $f
                     break;
 
                 case 'atom1.0':
-                    $entry_hook = 'frontend_display:atom-1.0:per_entry';
+                    $entry_hook     = 'frontend_display:atom-1.0:per_entry';
                     break;
             }
 
@@ -139,4 +151,5 @@ function serendipity_printEntries_rss(&$entries, $version, $comments = false, $f
             $entry['per_entry_display_dat'] = $entry['display_dat'];
         }
     }
+    
 }
