@@ -1,4 +1,4 @@
-<?php # $Id: functions_smarty.inc.php 1520 2006-11-30 21:34:29Z garvinhicking $
+<?php # $Id: functions_smarty.inc.php 1860 2007-08-21 10:26:07Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -496,6 +496,42 @@ function serendipity_smarty_hookPlugin($params, &$smarty) {
     serendipity_plugin_api::hook_event($params['hook'], $params['data'], $params['addData']);
 }
 
+/**
+ * Smarty Modifier: Be able to execute the hook of an event plugin and return its output, uses a REFERENCED variable.
+ *
+ * Listens to specific serendipity global variables:
+ *  $serendipity['skip_smarty_hooks'] - If TRUE, no plugins will be executed at all
+ *  $serendipity['skip_smarty_hook']  - Can be set to an array of plugin hooks to NOT execute
+ *
+ * @access public
+ * @param   mixed       EventData (referenced)
+ * @param   string      Event hook name
+ * @param   mixed       Additional data
+ * @return null
+ */
+function serendipity_smarty_refhookPlugin(&$eventData, $hook, $addData = null) {
+    global $serendipity;
+
+    if (!isset($hook)) {
+        $smarty->trigger_error(__FUNCTION__ .": missing 'hook' parameter");
+        return;
+    }
+
+    // Smarty hooks can be bypassed via an internal variable (temporarily)
+    if (isset($serendipity['skip_smarty_hooks']) && $serendipity['skip_smarty_hooks']) {
+        return;
+    }
+
+    // A specific hook can also be bypassed by creating an associative array like this:
+    // $serendipity['skip_smarty_hook'] = array('entries_header');
+    // That would only skip the entries_header event hook, but allow all others.
+    // Of course it cannot be used in conjunction with the all-blocking skip_smarty_hooks.
+    if (isset($serendipity['skip_smarty_hook']) && is_array($serendipity['skip_smarty_hook']) && isset($serendipity['skip_smarty_hook'][$params['hook']])) {
+        return;
+    }
+
+    serendipity_plugin_api::hook_event($hook, $eventData, $addData);
+}
 
 /**
  * Smarty Function: Prints a list of sidebar plugins
@@ -589,17 +625,18 @@ function serendipity_smarty_rss_getguid($params, &$smarty) {
  * @param   string  The strftime() format options on how to format this string
  * @param   boolean Shall timezone conversions be applied?
  * @param   boolean Try to detect a valid timestamp?
+ * @param   boolean Use strftime or date?
  * @return
  */
-function serendipity_smarty_formatTime($timestamp, $format, $useOffset = true, $detectTimestamp = false) {
+function serendipity_smarty_formatTime($timestamp, $format, $useOffset = true, $detectTimestamp = false, $useDate = false) {
     if ($detectTimestamp !== false && stristr($detectTimestamp, 'date') === false) {
         return $timestamp;
     }
 
     if (defined($format)) {
-        return serendipity_formatTime(constant($format), $timestamp, $useOffset);
+        return serendipity_formatTime(constant($format), $timestamp, $useOffset, $useDate);
     } else {
-        return serendipity_formatTime($format, $timestamp, $useOffset);
+        return serendipity_formatTime($format, $timestamp, $useOffset, $useDate);
     }
 }
 
@@ -695,12 +732,20 @@ function serendipity_smarty_init($vars = array()) {
             // Beware: Smarty is used in the Admin backend, despite of this.
             include $template_dir . '/template.inc.php';
         } else {
-            // Default Smarty Engine will be used
+            // Set a session variable if Smarty fails:
+            $prev_smarty = $_SESSION['no_smarty'];
+            $_SESSION['no_smarty'] = true;
 
+            // Default Smarty Engine will be used
             @define('SMARTY_DIR', S9Y_PEAR_PATH . 'Smarty/libs/');
             if (!class_exists('Smarty')) {
-                require SMARTY_DIR . 'Smarty.class.php';
+                include SMARTY_DIR . 'Smarty.class.php';
             }
+
+            if (!class_exists('Smarty')) {
+                return false;
+            }
+
             $serendipity['smarty'] = new Smarty;
             if ($serendipity['production'] === 'debug') {
                 $serendipity['smarty']->force_compile   = true;
@@ -714,9 +759,13 @@ function serendipity_smarty_init($vars = array()) {
             $serendipity['smarty']->compile_dir   = $serendipity['serendipityPath'] . PATH_SMARTY_COMPILE;
 
             if (!is_dir($serendipity['smarty']->compile_dir) || !is_writable($serendipity['smarty']->compile_dir)) {
-                serendipity_die(sprintf(DIRECTORY_WRITE_ERROR, $serendipity['smarty']->compile_dir));
+                printf(DIRECTORY_WRITE_ERROR, $serendipity['smarty']->compile_dir);
+                return false;
             }
 
+            // Hooray for Smarty:
+            $_SESSION['no_smarty'] = $prev_smarty;
+
             $serendipity['smarty']->config_dir    = $template_dir;
             $serendipity['smarty']->secure_dir    = array($serendipity['serendipityPath'] . $serendipity['templatePath']);
             $serendipity['smarty']->security_settings['MODIFIER_FUNCS']  = array('sprintf', 'sizeof', 'count', 'rand', 'print_r', 'str_repeat');
@@ -732,6 +781,8 @@ function serendipity_smarty_init($vars = array()) {
             $serendipity['smarty']->register_modifier('formatTime', 'serendipity_smarty_formatTime');
             $serendipity['smarty']->register_modifier('serendipity_utf8_encode', 'serendipity_utf8_encode');
             $serendipity['smarty']->register_modifier('ifRemember', 'serendipity_ifRemember');
+            $serendipity['smarty']->register_modifier('checkPermission', 'serendipity_checkPermission');
+            $serendipity['smarty']->register_modifier('serendipity_refhookPlugin', 'serendipity_smarty_refhookPlugin');
 
             $serendipity['smarty']->register_function('serendipity_printSidebar', 'serendipity_smarty_printSidebar');
             $serendipity['smarty']->register_function('serendipity_hookPlugin', 'serendipity_smarty_hookPlugin');
@@ -818,8 +869,11 @@ function serendipity_smarty_init($vars = array()) {
         // setup custom smarty variables, modifiers etc. to use in their templates.
         @include_once $serendipity['smarty']->config_dir . '/config.inc.php';
 
-        if (is_array($template_config)) {
-            $template_vars =& serendipity_loadThemeOptions($template_config);
+        if (is_array($template_loaded_config)) {
+            $template_vars =& $template_loaded_config;
+            $serendipity['smarty']->assign_by_ref('template_option', $template_vars);
+        } elseif (is_array($template_config)) {
+            $template_vars =& serendipity_loadThemeOptions($template_config, $serendipity['smarty_vars']['template_option']);
             $serendipity['smarty']->assign_by_ref('template_option', $template_vars);
         }
     }
