@@ -1,4 +1,4 @@
-<?php # $Id: functions_trackbacks.inc.php 1616 2007-02-12 12:13:58Z garvinhicking $
+<?php # $Id: functions_trackbacks.inc.php 1747 2007-07-03 08:19:07Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -62,6 +62,7 @@ global $serendipity;
       <name>sourceURI</name>
       <value><string>{$serendipity['baseURL']}</string></value>
     </param>
+    <param>
       <name>targetURI</name>
       <value><string>$loc</string></value>
     </param>
@@ -421,20 +422,48 @@ FAILURE;
 function serendipity_handle_references($id, $author, $title, $text, $dry_run = false) {
     global $serendipity;
     static $old_references = array();
+    static $saved_references = array();
+    static $debug = false;
 
     if ($dry_run) {
         // Store the current list of references. We might need to restore them for later user.
-        $old_references = serendipity_db_query("SELECT * FROM {$serendipity['dbPrefix']}references WHERE type = '' AND entry_id = " . (int)$id, false, 'assoc');
-    } else {
-        // A dry-run was called previously and restorable references are found. Restore them now.
-        serendipity_db_query("DELETE FROM {$serendipity['dbPrefix']}references WHERE type = '' AND entry_id = " . (int)$id);
+        $old_references = serendipity_db_query("SELECT * FROM {$serendipity['dbPrefix']}references WHERE (type = '' OR type IS NULL) AND entry_id = " . (int)$id, false, 'assoc');
+        
+        if ($debug && is_string($old_references)) {
+            echo $old_references . "<br />\n";
+        }
 
         if (is_array($old_references) && count($old_references) > 0) {
+            $current_references = array();
             foreach($old_references AS $idx => $old_reference) {
-                $q = serendipity_db_insert('references', $old_reference, 'show');
-                serendipity_db_query($q);
+                // We need the current reference ID to restore it later.
+                $saved_references[$old_reference['link'] . $old_reference['name']] = $current_references[$old_reference['link'] . $old_reference['name']] = $old_reference;
             }
         }
+        if ($debug) echo "Got references in dry run: <pre>" . print_r($current_references, true) . "</pre><br />\n";
+    } else {
+        // A dry-run was called previously and restorable references are found. Restore them now.
+        $del = serendipity_db_query("DELETE FROM {$serendipity['dbPrefix']}references WHERE (type = '' OR type IS NULL) AND entry_id = " . (int)$id);
+        if ($debug && is_string($del)) {
+            echo $del . "<br />\n";
+        }
+
+        if ($debug) echo "Deleted references.<br />\n";
+
+        if (is_array($old_references) && count($old_references) > 0) {
+            $current_references = array();
+            foreach($old_references AS $idx => $old_reference) {
+                // We need the current reference ID to restore it later.
+                $current_references[$old_reference['link'] . $old_reference['name']] = $old_reference;
+                $q = serendipity_db_insert('references', $old_reference, 'show');
+                $cr = serendipity_db_query($q);
+                if ($debug && is_string($cr)) {
+                    echo $cr . "<br />\n";
+                }
+            }
+        }
+
+        if ($debug) echo "Got references in final run: <pre>" . print_r($current_references, true) . "</pre><br />\n";
     }
 
     if (!preg_match_all('@<a[^>]+?href\s*=\s*["\']?([^\'" >]+?)[ \'"][^>]*>(.+?)</a>@i', $text, $matches)) {
@@ -454,11 +483,13 @@ function serendipity_handle_references($id, $author, $title, $text, $dry_run = f
     $checked_locations = array();
     serendipity_plugin_api::hook_event('backend_trackbacks', $locations);
     for ($i = 0, $j = count($locations); $i < $j; ++$i) {
+        if ($debug) echo "Checking {$locations[$i]}...<br />\n";
         if ($locations[$i][0] == '/') {
             $locations[$i] = 'http' . (!empty($_SERVER['HTTPS']) && strtolower($_SERVER['HTTPS']) != 'off' ? 's' : '') . '://' . $_SERVER['HTTP_HOST'] . $locations[$i];
         }
 
         if (isset($checked_locations[$locations[$i]])) {
+            if ($debug) echo "Already checked.<br />\n";
             continue;
         }
 
@@ -475,28 +506,84 @@ function serendipity_handle_references($id, $author, $title, $text, $dry_run = f
         $query = "SELECT COUNT(id) FROM {$serendipity['dbPrefix']}references
                                   WHERE entry_id = ". (int)$id ."
                                     AND link = '" . serendipity_db_escape_string($locations[$i]) . "'
-                                    AND type = ''";
+                                    AND (type = '' OR type IS NULL)";
 
         $row = serendipity_db_query($query, true, 'num');
-        if ($row[0] > 0) {
+        if ($debug && is_string($row)) {
+            echo $row . "<br />\n";
+        }
+
+        if ($row[0] > 0 && isset($saved_references[$locations[$i] . $names[$i]])) {
+            if ($debug) echo "Found references for $id, skipping rest<br />\n";
             continue;
         }
 
         if (!isset($serendipity['noautodiscovery']) || !$serendipity['noautodiscovery']) {
             if (!$dry_run) {
+                if ($debug) echo "Enabling autodiscovery.<br />\n";
                 serendipity_reference_autodiscover($locations[$i], $url, $author, $title, serendipity_trackback_excerpt($text));
+            } elseif ($debug) {
+                echo "Skipping autodiscovery<br />\n";
             }
             $checked_locations[$locations[$i]] = true; // Store trackbacked link so that no further trackbacks will be sent to the same link
+        } elseif ($debug) {
+            echo "Skipping full autodiscovery<br />\n";
         }
     }
-    serendipity_db_query("DELETE FROM {$serendipity['dbPrefix']}references WHERE entry_id=" . (int)$id . " AND type = ''");
+    $del = serendipity_db_query("DELETE FROM {$serendipity['dbPrefix']}references WHERE entry_id=" . (int)$id . " AND (type = '' OR type IS NULL)");
+    if ($debug && is_string($del)) {
+        echo $del . "<br />\n";
+    }
 
+    if ($debug) echo "Deleted references again.<br />\n";
+
+    if (!is_array($old_references)) {
+        $old_references = array();
+    }
+
+    $duplicate_check = array();
     for ($i = 0; $i < $j; ++$i) {
-        $query = "INSERT INTO {$serendipity['dbPrefix']}references (entry_id, name, link) VALUES(";
-        $query .= (int)$id . ", '" . serendipity_db_escape_string(strip_tags($names[$i])) . "', '";
-        $query .= serendipity_db_escape_string($locations[$i]) . "')";
+        $i_link     = serendipity_db_escape_string(strip_tags($names[$i]));
+        $i_location = serendipity_db_escape_string($locations[$i]);
+        
+        // No link with same description AND same text should be inserted.
+        if (isset($duplicate_check[$i_location . $i_link])) {
+            continue;
+        }
 
-        serendipity_db_query($query);
+        if (isset($current_references[$locations[$i] . $names[$i]])) {
+            $query = "INSERT INTO {$serendipity['dbPrefix']}references (id, entry_id, name, link) VALUES(";
+            $query .= (int)$current_references[$locations[$i] . $names[$i]]['id'] . ", " . (int)$id . ", '" . $i_link . "', '" . $i_location . "')";
+            $ins = serendipity_db_query($query);
+            if ($debug && is_string($ins)) {
+                echo $ins . "<br />\n";
+            }
+            $duplicate_check[$locations[$i] . $names[$i]] = true;
+        } else {
+            $query = "INSERT INTO {$serendipity['dbPrefix']}references (entry_id, name, link) VALUES(";
+            $query .= (int)$id . ", '" . $i_link . "', '" . $i_location . "')";
+            $ins = serendipity_db_query($query);
+            if ($debug && is_string($ins)) {
+                echo $ins . "<br />\n";
+            }
+
+            $old_references[] = array(
+                'id'       => serendipity_db_insert_id('references', 'id'),
+                'name'     => $i_link,
+                'link'     => $i_location,
+                'entry_id' => (int)$id
+            );
+            $duplicate_check[$i_location . $i_link] = true;
+        }
+        
+        if ($debug) {
+            echo "Current lookup for {$locations[$i]}{$names[$i]} is <pre>" . print_r($current_references[$locations[$i] . $names[$i]], true) . "</pre><br />\n";
+            echo $query . "<br />\n";
+        }
+    }
+    
+    if ($debug) {
+        echo "Old/Saved locations: <pre>" . print_r($old_references, true) . "</pre><br />\n";
     }
 
     // Add citations
@@ -506,7 +593,10 @@ function serendipity_handle_references($id, $author, $title, $text, $dry_run = f
         $query = "INSERT INTO {$serendipity['dbPrefix']}references (entry_id, name) VALUES(";
         $query .= (int)$id . ", '" . serendipity_db_escape_string($citation) . "')";
 
-        serendipity_db_query($query);
+        $cite = serendipity_db_query($query);
+        if ($debug && is_string($cite)) {
+            echo $cite . "<br />\n";
+        }
     }
 }
 
