@@ -1,4 +1,4 @@
-<?php # $Id: lang.inc.php 1520 2006-11-30 21:34:29Z garvinhicking $
+<?php # $Id: lang.inc.php 2054 2007-12-06 09:26:35Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -11,8 +11,13 @@ if (!defined('serendipity_LANG_LOADED') || serendipity_LANG_LOADED !== true) {
 
     // The following variable can be set in serendipity_config_local.inc.php to force your templates being able to use language override includes
     if ($serendipity['useTemplateLanguage']) {
-        @include (S9Y_INCLUDE_PATH . 'templates/' . $serendipity['template'] . '/' . $charset .  'lang_' . $serendipity['lang'] . '.inc.php');
-        @include (S9Y_INCLUDE_PATH . 'templates/' . $serendipity['template'] . '/lang_en.inc.php');
+        if (defined('S9Y_DATA_PATH')) {
+            @include (S9Y_DATA_PATH . 'templates/' . $serendipity['template'] . '/' . $charset .  'lang_' . $serendipity['lang'] . '.inc.php');
+            @include (S9Y_DATA_PATH . 'templates/' . $serendipity['template'] . '/lang_en.inc.php');
+        } else {
+            @include (S9Y_INCLUDE_PATH . 'templates/' . $serendipity['template'] . '/' . $charset .  'lang_' . $serendipity['lang'] . '.inc.php');
+            @include (S9Y_INCLUDE_PATH . 'templates/' . $serendipity['template'] . '/lang_en.inc.php');
+        }
     }
 
     // Try and include preferred language from the configurated setting
@@ -59,7 +64,7 @@ if (!defined('serendipity_MB_LOADED') && defined('serendipity_LANG_LOADED')) {
         static $mbstring = null;
 
         if (is_null($mbstring)) {
-            $mbstring = (extension_loaded('mbstring') ? 1 : 0);
+            $mbstring = (extension_loaded('mbstring') && @mb_internal_encoding(LANG_CHARSET) ? 1 : 0);
             if ($mbstring === 1) {
                 if (function_exists('mb_strtoupper')) {
                     $mbstring = 2;
