@@ -1,4 +1,4 @@
-<?php # $Id: plugin_api.inc.php 1513 2006-11-17 15:20:04Z garvinhicking $
+<?php # $Id: plugin_api.inc.php 1711 2007-06-05 11:44:34Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -111,6 +111,10 @@ class serendipity_plugin_api {
         // Secure Plugin path. No leading slashes, no backslashes, no "up" directories
         $pluginPath = preg_replace('@^(/)@', '', $pluginPath);
         $pluginPath = str_replace(array('..', "\\"), array('', '/'), serendipity_db_escape_string($pluginPath));
+        
+        if ($pluginPath == 'online_repository') {
+            $pluginPath = $key;
+        }
 
         $rs = serendipity_db_query("SELECT MAX(sort_order) as sort_order_max FROM {$serendipity['dbPrefix']}plugins WHERE placement = '$default_placement'", true, 'num');
 
