@@ -1,4 +1,4 @@
-<?php # $Id: plugin_internal.inc.php 1576 2007-01-14 14:56:22Z garvinhicking $
+<?php # $Id: plugin_internal.inc.php 2047 2007-12-03 20:54:24Z donchambers $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -18,10 +18,10 @@ class serendipity_calendar_plugin extends serendipity_plugin {
     {
         $propbag->add('name',        CALENDAR);
         $propbag->add('description', QUICKJUMP_CALENDAR);
-        $propbag->add('configuration', array('beginningOfWeek', 'enableExtEvents'));
+        $propbag->add('configuration', array('beginningOfWeek', 'enableExtEvents', 'category'));
         $propbag->add('stackable',     false);
         $propbag->add('author',        'Serendipity Team');
-        $propbag->add('version',       '1.0');
+        $propbag->add('version',       '1.1');
         $propbag->add('groups',        array('FRONTEND_VIEWS'));
     }
 
@@ -48,6 +48,25 @@ class serendipity_calendar_plugin extends serendipity_plugin {
                 $propbag->add('default',     false);
                 break;
 
+            // Event Calendar: Support category!
+            case 'category':
+                $categories = array('all' => ALL_CATEGORIES);
+                $cats       = serendipity_fetchCategories();
+
+                if (is_array($cats)) {
+                    $cats = serendipity_walkRecursive($cats, 'categoryid', 'parentid', VIEWMODE_THREADED);
+                    foreach($cats as $cat) {
+                        $categories[$cat['categoryid']] = str_repeat(' . ', $cat['depth']) . $cat['category_name'];
+                    }
+                }
+
+                $propbag->add('type',         'select');
+                $propbag->add('name',         CATEGORIES_PARENT_BASE);
+                $propbag->add('description',  CATEGORIES_PARENT_BASE_DESC);
+                $propbag->add('select_values', $categories);
+                $propbag->add('default',      'all');
+                break;
+
             default:
                 return false;
         }
@@ -190,8 +209,18 @@ class serendipity_calendar_plugin extends serendipity_plugin {
 
         serendipity_plugin_api::hook_event('frontend_fetchentries', $cond, array('noCache' => false, 'noSticky' => false, 'source' => 'calendar'));
 
-        if (isset($serendipity['GET']['category'])) {
-            $base_query   = 'C' . (int)$serendipity['GET']['category'];
+        // Event Calendar
+        $cat = $this->get_config('category', 'all');
+        if ($cat != 'all') {
+            $catid = (int)$cat;
+        } elseif (isset($serendipity['GET']['category'])) {
+            $catid = (int)$serendipity['GET']['category'];
+        } else {
+            $catid = false;
+        }
+        
+        if ($catid) {
+            $base_query   = 'C' . $catid;
             $add_query    = '/' . $base_query;
             $querystring = "SELECT timestamp
                               FROM {$serendipity['dbPrefix']}category c,
@@ -201,7 +230,7 @@ class serendipity_calendar_plugin extends serendipity_plugin {
                                    {$cond['and']}
                                AND e.id          = ec.entryid
                                AND c.categoryid  = ec.categoryid
-                               AND (" . serendipity_getMultiCategoriesSQL($serendipity['GET']['category']) . ")";
+                               AND (" . serendipity_getMultiCategoriesSQL($catid) . ")";
         }
 
         if (!isset($querystring)) {
@@ -672,7 +701,7 @@ class serendipity_syndication_plugin extends serendipity_plugin {
         $propbag->add('description',   SHOWS_RSS_BLAHBLAH);
         $propbag->add('stackable',     true);
         $propbag->add('author',        'Serendipity Team');
-        $propbag->add('version',       '1.3');
+        $propbag->add('version',       '1.4');
         $propbag->add('configuration', array(
                                         'title',
                                         'fullfeed',
@@ -691,6 +720,7 @@ class serendipity_syndication_plugin extends serendipity_plugin {
                                         'field_ttl',
                                         'field_pubDate',
                                         'seperator',
+                                        'iconURL',
                                         'bannerURL',
                                         'bannerWidth',
                                         'bannerHeight',
@@ -839,6 +869,13 @@ class serendipity_syndication_plugin extends serendipity_plugin {
                 $propbag->add('default',     true);
                 break;
 
+            case 'iconURL':
+                $propbag->add('type',        'string');
+                $propbag->add('name',        XML_IMAGE_TO_DISPLAY);
+                $propbag->add('description', '');
+                $propbag->add('default',     'img/xml.gif');
+                break;
+
             case 'bannerURL':
                 $propbag->add('type',        'string');
                 $propbag->add('name',        SYNDICATION_PLUGIN_BANNERURL);
@@ -900,11 +937,12 @@ class serendipity_syndication_plugin extends serendipity_plugin {
         global $serendipity;
 
         $title = $this->get_config('title');
+        $icon  = serendipity_getTemplateFile($this->get_config('iconURL', 'img/xml.gif'));
 
         if (serendipity_db_bool($this->get_config('show_0.91', true))) {
 ?>
         <div style="padding-bottom: 2px;">
-            <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/index.rss', 'serendipityHTTPPath') ?>"><img src="<?php echo serendipity_getTemplateFile('img/xml.gif'); ?>" alt="XML" style="border: 0px" /></a>
+            <a class="serendipity_xml_icon" href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/index.rss', 'serendipityHTTPPath') ?>"><img src="<?php echo $icon; ?>" alt="XML" style="border: 0px" /></a>
             <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/index.rss', 'serendipityHTTPPath') ?>">RSS 0.91 feed</a>
         </div>
 <?php
@@ -913,7 +951,7 @@ class serendipity_syndication_plugin extends serendipity_plugin {
         if (serendipity_db_bool($this->get_config('show_1.0', true))) {
 ?>
         <div style="padding-bottom: 2px;">
-            <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/index.rss1', 'serendipityHTTPPath') ?>"><img src="<?php echo serendipity_getTemplateFile('img/xml.gif'); ?>" alt="XML" style="border: 0px" /></a>
+            <a class="serendipity_xml_icon" href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/index.rss1', 'serendipityHTTPPath') ?>"><img src="<?php echo $icon; ?>" alt="XML" style="border: 0px" /></a>
             <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/index.rss1', 'serendipityHTTPPath') ?>">RSS 1.0 feed</a>
         </div>
 <?php
@@ -922,7 +960,7 @@ class serendipity_syndication_plugin extends serendipity_plugin {
         if (serendipity_db_bool($this->get_config('show_2.0', true))) {
 ?>
         <div style="padding-bottom: 2px;">
-            <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/index.rss2', 'serendipityHTTPPath') ?>"><img src="<?php echo serendipity_getTemplateFile('img/xml.gif'); ?>" alt="XML" style="border: 0px" /></a>
+            <a class="serendipity_xml_icon" href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/index.rss2', 'serendipityHTTPPath') ?>"><img src="<?php echo $icon; ?>" alt="XML" style="border: 0px" /></a>
             <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/index.rss2', 'serendipityHTTPPath') ?>">RSS 2.0 feed</a>
         </div>
 <?php
@@ -931,7 +969,7 @@ class serendipity_syndication_plugin extends serendipity_plugin {
         if (serendipity_db_bool($this->get_config('show_atom0.3', true))) {
 ?>
         <div style="padding-bottom: 2px;">
-            <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/atom03.xml', 'serendipityHTTPPath') ?>"><img src="<?php echo serendipity_getTemplateFile('img/xml.gif'); ?>" alt="ATOM/XML" style="border: 0px" /></a>
+            <a class="serendipity_xml_icon" href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/atom03.xml', 'serendipityHTTPPath') ?>"><img src="<?php echo $icon; ?>" alt="ATOM/XML" style="border: 0px" /></a>
             <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/atom03.xml', 'serendipityHTTPPath') ?>">ATOM 0.3 feed</a>
         </div>
 <?php
@@ -940,7 +978,7 @@ class serendipity_syndication_plugin extends serendipity_plugin {
         if (serendipity_db_bool($this->get_config('show_atom1.0', true))) {
 ?>
         <div style="padding-bottom: 2px;">
-            <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/atom10.xml', 'serendipityHTTPPath') ?>"><img src="<?php echo serendipity_getTemplateFile('img/xml.gif'); ?>" alt="ATOM/XML" style="border: 0px" /></a>
+            <a class="serendipity_xml_icon" href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/atom10.xml', 'serendipityHTTPPath') ?>"><img src="<?php echo $icon; ?>" alt="ATOM/XML" style="border: 0px" /></a>
             <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/atom10.xml', 'serendipityHTTPPath') ?>">ATOM 1.0 feed</a>
         </div>
 <?php
@@ -949,7 +987,7 @@ class serendipity_syndication_plugin extends serendipity_plugin {
         if (serendipity_db_bool($this->get_config('show_2.0c', true))) {
 ?>
         <div style="padding-bottom: 2px;">
-            <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/comments.rss2', 'serendipityHTTPPath') ?>"><img src="<?php echo serendipity_getTemplateFile('img/xml.gif'); ?>" alt="XML" style="border: 0px" /></a>
+            <a class="serendipity_xml_icon" href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/comments.rss2', 'serendipityHTTPPath') ?>"><img src="<?php echo $icon; ?>" alt="XML" style="border: 0px" /></a>
             <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/comments.rss2', 'serendipityHTTPPath') ?>"><span style="white-space: nowrap">RSS 2.0 <?php echo COMMENTS; ?></span></a>
         </div>
 <?php
@@ -958,7 +996,7 @@ class serendipity_syndication_plugin extends serendipity_plugin {
         if (serendipity_db_bool($this->get_config('show_opml1.0', false))) {
 ?>
         <div style="padding-bottom: 2px;">
-            <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/opml.xml', 'serendipityHTTPPath') ?>"><img src="<?php echo serendipity_getTemplateFile('img/xml.gif'); ?>" alt="XML" style="border: 0px" /></a>
+            <a class="serendipity_xml_icon" href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/opml.xml', 'serendipityHTTPPath') ?>"><img src="<?php echo $icon; ?>" alt="XML" style="border: 0px" /></a>
             <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/opml.xml', 'serendipityHTTPPath') ?>">OPML 1.0 feed</a>
         </div>
 <?php
@@ -1094,7 +1132,7 @@ class serendipity_superuser_plugin extends serendipity_plugin {
 
         $link = $base . ($serendipity['rewrite'] == 'none' ? $serendipity['indexFile'] .'?/' : '') . PATH_ADMIN;
         $text = (($_SESSION['serendipityAuthedUser'] === true) ? SUPERUSER_OPEN_ADMIN : SUPERUSER_OPEN_LOGIN);
-        echo '<a href="' . $link . '" title="'. $text .'">'. $text .'</a>';
+        echo '<a rel="nofollow" href="' . $link . '" title="'. $text .'">'. $text .'</a>';
     }
 
     function introspect_config_item($name, &$propbag)
@@ -1522,6 +1560,7 @@ class serendipity_categories_plugin extends serendipity_plugin {
                 $categories[$cid]['feedCategoryURL'] = serendipity_feedCategoryURL($cat, 'serendipityHTTPPath');
                 $categories[$cid]['categoryURL']     = serendipity_categoryURL($cat, 'serendipityHTTPPath');
                 $categories[$cid]['paddingPx']       = $cat['depth']*6;
+                $categories[$cid]['catdepth']       = $cat['depth'];
 
                 if (!empty($cat_count[$cat['categoryid']])) {
                     $categories[$cid]['true_category_name'] = $cat['category_name'];
@@ -1529,7 +1568,7 @@ class serendipity_categories_plugin extends serendipity_plugin {
                 }
 
                 if (!$smarty) {
-                    $html .= '<li style="display: block;">';
+                    $html .= '<li class="category_depth'. $cat['depth']. ' category_' . $cat['categoryid'] .'" style="display: block;">';
 
                     if ($is_form) {
                         $html .= '<input style="width: 15px" type="checkbox" name="serendipity[multiCat][]" value="' . $cat['categoryid'] . '" />';
@@ -1684,7 +1723,7 @@ class serendipity_authors_plugin extends serendipity_plugin {
                 }
 
                 if ( !empty($image) ) {
-                    $html .= '<a href="'. serendipity_feedAuthorURL($auth, 'serendipityHTTPPath') .'"><img src="'. $image .'" alt="XML" style="border: 0px" /></a> ';
+                    $html .= '<a class="serendipity_xml_icon" href="'. serendipity_feedAuthorURL($auth, 'serendipityHTTPPath') .'"><img src="'. $image .'" alt="XML" style="border: 0px" /></a> ';
                 }
                 $html .= '<a href="'. serendipity_authorURL($auth, 'serendipityHTTPPath') .'" title="'. htmlspecialchars($auth['realname']) .'">'. htmlspecialchars($auth['realname']) . $entrycount . '</a>';
                 $html .= '</div>' . "\n";
