@@ -1,8 +1,9 @@
-<?php # $Id: index.php 1519 2006-11-28 14:48:59Z garvinhicking $
+<?php # $Id: index.php 1732 2007-06-18 11:57:15Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
 $global_debug = false;
+
 if ($global_debug) {
     #apd_set_pprof_trace();
 
@@ -107,8 +108,11 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
                 unset($_args[$k]);
             }
         } elseif ($v{0} == 'A') { /* Author */
-            $serendipity['GET']['viewAuthor'] = $_GET['viewAuthor'] = (int)substr($v, 1);
-            unset($_args[$k]);
+            $url_author = substr($v, 1);
+            if (is_numeric($url_author)) {
+                $serendipity['GET']['viewAuthor'] = $_GET['viewAuthor'] = (int)$url_author;
+                unset($_args[$k]);
+            }
         } elseif ($v{0} == 'W') { /* Week */
             $week = substr($v, 1);
             if (is_numeric($week)) {
@@ -133,7 +137,7 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
     $serendipity['GET']['action']     = 'read';
     $serendipity['GET']['hidefooter'] = true;
 
-    if ( !isset($year) ) {
+    if (!isset($year)) {
         $year = date('Y');
         $month = date('m');
         $day = date('j');
@@ -141,6 +145,18 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
         $serendipity['GET']['hidefooter'] = null;
     }
 
+    if (isset($year) && !is_numeric($year)) {
+        $year = date('Y');
+    }
+
+    if (isset($month) && !is_numeric($month)) {
+        $month = date('m');
+    }
+
+    if (isset($day) && !is_numeric($day)) {
+        $day = date('d');
+    }                
+
     switch($serendipity['calendar']) {
         case 'gregorian':
         default:
@@ -237,7 +253,7 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
             preg_match(PAT_PERMALINK, $uri, $matches) ) {
     $serendipity['view'] = 'entry';
 
-    $matches[1] = serendipity_searchPermalink($serendipity['permalinkStructure'], $uri, $matches[1], 'entry');
+    $matches[1] = serendipity_searchPermalink($serendipity['permalinkStructure'], $uri, (!empty($matches[2]) ? $matches[2] : $matches[1]), 'entry');
     serendipity_rememberComment();
 
     if (!empty($serendipity['POST']['submit']) && !isset($_REQUEST['serendipity']['csuccess'])) {
@@ -274,6 +290,9 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
     if (is_array($title)) {
         $serendipity['head_title']    = htmlspecialchars($title[0]);
         $serendipity['head_subtitle'] = htmlspecialchars($serendipity['blogTitle']);
+    } else {
+        $serendipity['view'] = '404';
+        header('HTTP/1.0 404 Not found');
     }
 
     ob_start();
@@ -351,8 +370,11 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
                 unset($_args[$k]);
             }
         } elseif ($v{0} == 'A') { /* Author */
-            $serendipity['GET']['viewAuthor'] = $_GET['viewAuthor'] = (int)substr($v, 1);
-            unset($_args[$k]);
+            $url_author = substr($v, 1);
+            if (is_numeric($url_author)) {
+                $serendipity['GET']['viewAuthor'] = $_GET['viewAuthor'] = (int)$url_author;
+                unset($_args[$k]);
+            }
         }
     }
 
@@ -392,8 +414,11 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
                 unset($serendipity['uriArguments'][$k]);
             }
         } elseif ($v{0} == 'A') { /* Author */
-            $serendipity['GET']['viewAuthor'] = $_GET['viewAuthor'] = (int)substr($v, 1);
-            unset($_args[$k]);
+            $url_author = substr($v, 1);
+            if (is_numeric($url_author)) {
+                $serendipity['GET']['viewAuthor'] = $_GET['viewAuthor'] = (int)$url_author;
+                unset($_args[$k]);
+            }
         }
     }
 
@@ -403,8 +428,14 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
     }
 
     $cInfo = serendipity_fetchCategoryInfo($serendipity['GET']['category']);
-    $serendipity['head_title']    = $cInfo['category_name'];
-    $serendipity['head_subtitle'] = $serendipity['blogTitle'];
+
+    if (!is_array($cInfo)) {
+        $serendipity['view'] = '404';
+        header('HTTP/1.0 404 Not found');
+    } else {
+        $serendipity['head_title']    = $cInfo['category_name'];
+        $serendipity['head_subtitle'] = $serendipity['blogTitle'];
+    }
 
     include(S9Y_INCLUDE_PATH . 'include/genpage.inc.php');
 } else if ($is_multiauth || preg_match(PAT_PERMALINK_AUTHORS, $uri, $matches)) {
@@ -442,8 +473,14 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
     }
 
     $uInfo = serendipity_fetchUsers($serendipity['GET']['viewAuthor']);
-    $serendipity['head_title']    = sprintf(ENTRIES_BY, $uInfo[0]['realname']);
-    $serendipity['head_subtitle'] = $serendipity['blogTitle'];
+    
+    if (!is_array($uInfo)) {
+        $serendipity['view'] = '404';
+        header('HTTP/1.0 404 Not found');
+    } else {
+        $serendipity['head_title']    = sprintf(ENTRIES_BY, $uInfo[0]['realname']);
+        $serendipity['head_subtitle'] = $serendipity['blogTitle'];
+    }
 
     include(S9Y_INCLUDE_PATH . 'include/genpage.inc.php');
 } else if (preg_match(PAT_SEARCH, $uri, $matches)) {
@@ -463,6 +500,8 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
                 $serendipity['GET']['page'] = $page;
                 unset($_args[$k]);
                 unset($serendipity['uriArguments'][$k]);
+            } else {
+                $search[] = $v;
             }
         } else {
             $search[] = $v;
