@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_cz.inc.php 1408 2006-08-23 13:47:50Z garvinhicking $
+<?php # $Id: serendipity_lang_cz.inc.php 1815 2007-08-06 10:18:26Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation (c) 2004 Josef Klimosz <ok2wo@centrum.cz>
@@ -703,8 +703,6 @@ $i18n_filename_to = array (
 @define('INSTALL_PERMALINK_PLUGINPATH', 'Cesta k jednotlivému pluginu');
 @define('INSTALL_PERMALINK_ADMINPATH', 'Cesta k adminu');
 @define('INSTALL_PERMALINK_SEARCHPATH', 'Cesta k vyhledávání');
-@define('USERCONF_CREATE', 'Zakázat vytváření záznamů?');
-@define('USERCONF_CREATE_DESC', 'Pokud bude vybráno, uživatel nemůže vytvářet nové záznamy');
 @define('INSTALL_CAL', 'Typ kalendáře');
 @define('INSTALL_CAL_DESC', 'Vyberte formát kalendáře');
 @define('REPLY', 'Odpověď');
@@ -858,7 +856,7 @@ $i18n_filename_to = array (
 @define('PLUGIN_AVAILABLE_COUNT', 'Celkem: %d pluginů.');
 
 @define('SYNDICATION_RFC2616', 'Aktivovat strict RFC2616 RSS-Feed compliance');
-@define('SYNDICATION_RFC2616_DESC', 'Když neaktivujete  RFC2616, znamená to, že všechny podmíněné GETy na Serendipity vrátí příspěvky, které byly modifikovány od času posledního požadavku. Když tohle nastavíte na  "false", vaši návštěvníci dostanou všechny články od svého posledního požadavku, což se považuje za dobrou věc. Avšak někteří agenti jako  Planet fungují divně, když tohle nastane a taky to porušuje  RFC2616. Takže když nastavíte tuto volbu na  "TRUE", budete vyhovovat RFC ale návštěvníkům   mohou ve  čtečkách  během prázdnin zmizet příspěvky. V každém případě, buď to vadí agregátorům jako je  Planet, nebo to vadí návštěvníkům blogu. Když se vyskytnou stížnosti z kterékoli strany, můžete tuhle volbu přepnout.  Reference: https://sourceforge.net/tracker/index.php?func=detail&aid=1461728&group_id=75065&atid=542822');
+@define('SYNDICATION_RFC2616_DESC', 'Když neaktivujete  RFC2616, znamená to, že všechny podmíněné GETy na Serendipity vrátí příspěvky, které byly modifikovány od času posledního požadavku. Když tohle nastavíte na  "false", vaši návštěvníci dostanou všechny články od svého posledního požadavku, což se považuje za dobrou věc. Avšak někteří agenti jako  Planet fungují divně, když tohle nastane a taky to porušuje  RFC2616. Takže když nastavíte tuto volbu na  "TRUE", budete vyhovovat RFC ale návštěvníkům   mohou ve  čtečkách  během prázdnin zmizet příspěvky. V každém případě, buď to vadí agregátorům jako je  Planet, nebo to vadí návštěvníkům blogu. Když se vyskytnou stížnosti z kterékoli strany, můžete tuhle volbu přepnout.  Reference: <a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
 @define('MEDIA_PROPERTY_DATE', 'Asociované datum');
 @define('MEDIA_PROPERTY_RUN_LENGTH', 'Run-Length');
 @define('FILENAME_REASSIGNED', 'Automaticky přidělené nové jméno souboru: %s');
@@ -897,3 +895,14 @@ $i18n_filename_to = array (
 @define('PERMISSION_FORBIDDEN_HOOKS', 'Zakázané události');
 @define('PERMISSION_FORBIDDEN_ENABLE', 'Povolit Plugin ACL pro uživatelské skupiny?');
 @define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'Jestliže je volba "Plugin ACL pro uživatelské skupiny" v konfiguraci povolena, můžete určit, které skupiny uživatelů mohou provádět určité pluginy/události.');
+@define('IMPORT_WP_PAGES', 'Also fetch attachments and staticpages as normal blog entries?');
+@define('USERCONF_CREATE', 'Disable user / forbid activity?');
+@define('USERCONF_CREATE_DESC', 'If selected, the user will not have any editing or creation possibilities on the blog anymore. When logging in to the backend, he cannot do anything else apart from logging out and viewing his personal configuration.');
+@define('CATEGORY_HIDE_SUB', 'Hide postings made to sub-categories?');
+@define('CATEGORY_HIDE_SUB_DESC', 'By default, when you browse a category also entries of any subcategory are displayed. If this option is turned on, only postings of the currently selected category are displayed.');
+@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
+@define('PINGBACK_SENT', 'Pingback successful');
+@define('PINGBACK_FAILED', 'Pingback failed: %s');
+@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
+@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
+@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
