@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_da.inc.php 1515 2006-11-22 10:30:13Z garvinhicking $
+<?php # $Id: serendipity_lang_da.inc.php 1815 2007-08-06 10:18:26Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation (c) by Tom Sommer, <ts@dreamcoder.dk>
@@ -691,8 +691,6 @@
 @define('INSTALL_PERMALINK_PLUGINPATH', 'Sti til et plugin');
 @define('INSTALL_PERMALINK_ADMINPATH', 'Sti til admin');
 @define('INSTALL_PERMALINK_SEARCHPATH', 'Sti til søgning');
-@define('USERCONF_CREATE', 'Forbyd oprettelse af artikler?');
-@define('USERCONF_CREATE_DESC', 'Hvis valgt, kan denne bruger ikke oprette nye artikler');
 @define('INSTALL_CAL', 'Kalendar type');
 @define('INSTALL_CAL_DESC', 'Vælg dit kalenderformat');
 @define('REPLY', 'Svar');
@@ -846,7 +844,7 @@
 @define('PLUGIN_AVAILABLE_COUNT', 'Total: %d plugins.');
 
 @define('SYNDICATION_RFC2616', 'Aktiver RSS-feeds der overholder RFC2616');
-@define('SYNDICATION_RFC2616_DESC', 'Hvis IKKE RFC2616 overholdes vil alle forespørgsler til Serendipity returnere artikler ændret siden  tidspunktet for sidste forespørgsel. Dvs \'nej\' medfører at dine besøgende får alle artikler siden sidst. På den anden side, nogle RSS aggregatorer som f.eks. \'Planet\' opfører sig underligt med denne indstilling da den jo ikke overholder RFC2616. Læs eventuelt mere om problemet her <a href="https://sourceforge.net/tracker/index.php?func=detail&aid=1461728&group_id=75065&atid=542822">https://sourceforge.net/tracker/index.php?func=detail&aid=1461728&group_id=75065&atid=542822</a>');
+@define('SYNDICATION_RFC2616_DESC', 'Hvis IKKE RFC2616 overholdes vil alle forespørgsler til Serendipity returnere artikler ændret siden  tidspunktet for sidste forespørgsel. Dvs \'nej\' medfører at dine besøgende får alle artikler siden sidst. På den anden side, nogle RSS aggregatorer som f.eks. \'Planet\' opfører sig underligt med denne indstilling da den jo ikke overholder RFC2616. Læs eventuelt mere om problemet her <a href="<a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>"><a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a></a>');
 @define('MEDIA_PROPERTY_DATE', 'Tilhørende dato');
 @define('MEDIA_PROPERTY_RUN_LENGTH', 'Spilletid');
 @define('FILENAME_REASSIGNED', 'Nyt filnavn automagisk tildelt: %s');
@@ -886,3 +884,14 @@
 @define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'Mulighed for at bestemme hvilke grupper der må anvende hvilke plugins.');
 @define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
 @define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
+@define('IMPORT_WP_PAGES', 'Also fetch attachments and staticpages as normal blog entries?');
+@define('USERCONF_CREATE', 'Disable user / forbid activity?');
+@define('USERCONF_CREATE_DESC', 'If selected, the user will not have any editing or creation possibilities on the blog anymore. When logging in to the backend, he cannot do anything else apart from logging out and viewing his personal configuration.');
+@define('CATEGORY_HIDE_SUB', 'Hide postings made to sub-categories?');
+@define('CATEGORY_HIDE_SUB_DESC', 'By default, when you browse a category also entries of any subcategory are displayed. If this option is turned on, only postings of the currently selected category are displayed.');
+@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
+@define('PINGBACK_SENT', 'Pingback successful');
+@define('PINGBACK_FAILED', 'Pingback failed: %s');
+@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
+@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
+@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
