@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_fi.inc.php 1251 2006-06-09 20:16:09Z garvinhicking $
+<?php # $Id: serendipity_lang_fi.inc.php 1815 2007-08-06 10:18:26Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation by Mauri Sahlberg <mos@iki.fi>
@@ -689,8 +689,6 @@
 @define('INSTALL_PERMALINK_PLUGINPATH', 'Yksittäisen laajennuksen polku');
 @define('INSTALL_PERMALINK_ADMINPATH', 'Ylläpitopolku');
 @define('INSTALL_PERMALINK_SEARCHPATH', 'Hakupolku');
-@define('USERCONF_CREATE', 'Kiellä kirjoittaminen blogiin?');
-@define('USERCONF_CREATE_DESC', 'Jos "Kyllä", niin käyttäjä ei saa kirjoittaa blogiin.');
 @define('INSTALL_CAL', 'Kalenterin tyyppi');
 @define('INSTALL_CAL_DESC', 'Valitse käytettävä kalenterimuoto');
 @define('REPLY', 'Reply');
@@ -803,3 +801,98 @@
 @define('CATEGORIES_HIDE_PARENT', 'Piilota valittu kategoriavanhempi?');
 @define('CATEGORIES_HIDE_PARENT_DESC', 'Jos rajaat valinnan kategoriavanhempaan vain tämän vanhemman lapset näytetään, jos et, näytetään vain kategoriavanhemmat.');
 @define('WARNING_NO_GROUPS_SELECTED', 'Varoitus: Et valinnut yhtään ryhmää. Tämä poistaisi sinulta kaikki oikeudet, joten valintaasi ei toteutettu.');
+@define('INSTALL_RSSFETCHLIMIT', 'Entries to display in Feeds');
+@define('INSTALL_RSSFETCHLIMIT_DESC', 'Number of entries to display for each page on the RSS Feed.');
+@define('INSTAL_DB_UTF8', 'Enable DB-charset conversion');
+@define('INSTAL_DB_UTF8_DESC', 'Issues a MySQL "SET NAMES" query to indicate the required charset for the database. Turn this on or off, if you see weird characters in your blog.');
+@define('ONTHEFLYSYNCH', 'Enable on-the-fly media synchronization');
+@define('ONTHEFLYSYNCH_DESC', 'If enabled, Serendipity will compare the media database with the files stored on your server and synchronize the database and directory contents.');
+@define('USERCONF_CHECK_USERNAME_ERROR', 'The username cannot be left blank.');
+@define('FURTHER_LINKS', 'Further Links');
+@define('FURTHER_LINKS_S9Y', 'Serendipity Homepage');
+@define('FURTHER_LINKS_S9Y_DOCS', 'Serendipity Documentation');
+@define('FURTHER_LINKS_S9Y_BLOG', 'Official Blog');
+@define('FURTHER_LINKS_S9Y_FORUMS', 'Forums');
+@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
+@define('COMMENT_IS_DELETED', '(Comment removed)');
+
+@define('CURRENT_AUTHOR', 'Current author');
+
+@define('WORD_NEW', 'New');
+@define('SHOW_MEDIA_TOOLBAR', 'Show toolbar within media selector popup?');
+@define('MEDIA_KEYWORDS', 'Media keywords');
+@define('MEDIA_KEYWORDS_DESC', 'Enter a list of ";" separated words that you want to use as pre-defined keywords for media items.');
+@define('MEDIA_EXIF', 'Import EXIF/JPEG image data');
+@define('MEDIA_EXIF_DESC', 'If enabled, existing EXIF/JPEG metadata of images will be parsed and stored in the database for display in the media gallery.');
+@define('MEDIA_PROP', 'Media properties');
+
+
+@define('GO_ADD_PROPERTIES', 'Go & enter properties');
+@define('MEDIA_PROPERTY_DPI', 'DPI');
+@define('MEDIA_PROPERTY_COPYRIGHT', 'Copyright');
+@define('MEDIA_PROPERTY_COMMENT1', 'Short Comment');
+@define('MEDIA_PROPERTY_COMMENT2', 'Long Comment');
+@define('MEDIA_PROPERTY_TITLE', 'Title');
+@define('MEDIA_PROP_DESC', 'Enter a list of ";" separated property fields you want to define for each media file');
+@define('MEDIA_PROP_MULTIDESC', '(You can append ":MULTI" after any item to indicate that this item will contain long text instead of just some characters)');
+
+@define('STYLE_OPTIONS_NONE', 'This theme/style has no specific options. To see how your template can specify options, read the Technical Documentation on www.s9y.org about "Configuration of Theme options".');
+@define('STYLE_OPTIONS', 'Theme/Style options');
+
+@define('PLUGIN_AVAILABLE_COUNT', 'Total: %d plugins.');
+
+@define('SYNDICATION_RFC2616', 'Activate strict RFC2616 RSS-Feed compliance');
+@define('SYNDICATION_RFC2616_DESC', 'NOT Enforcing RFC2616 means that all Conditional GETs to Serendipity will return entries last modified since the time of the last request. With that setting to "false", your visitors will get all articles since their last request, which is considered a good thing. However, some Agents like Planet act weird, if that happens, at it also violates RFC2616. So if you set this option to "TRUE" you will comply with that RFC, but readers of your RSS feed might miss items in their holidays. So either way, either it hearts Aggregators like Planet, or it hurts actual readers of your blog. If you are facing complaints from either side, you can toggle this option. Reference: <a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
+@define('MEDIA_PROPERTY_DATE', 'Associated Date');
+@define('MEDIA_PROPERTY_RUN_LENGTH', 'Run-Length');
+@define('FILENAME_REASSIGNED', 'Automagically assigned new file name: %s');
+@define('MEDIA_UPLOAD_SIZE', 'Max. file upload size');
+@define('MEDIA_UPLOAD_SIZE_DESC', 'Enter the maximum filesize for uploaded files in bytes. This setting can be overruled by server-side settings in PHP.ini: upload_max_filesize, post_max_size, max_input_time all take precedence over this option. An empty string means to only use the server-side limits.');
+@define('MEDIA_UPLOAD_SIZEERROR', 'Error: You cannot upload files larger than %s bytes!');
+@define('MEDIA_UPLOAD_MAXWIDTH', 'Max. width of image files for upload');
+@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'Enter the maximum image width in pixels for uploaded images.');
+@define('MEDIA_UPLOAD_MAXHEIGHT', 'Max. height of image files for upload');
+@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'Enter the maximum image height in pixels for uploaded images.');
+@define('MEDIA_UPLOAD_DIMERROR', 'Error: You cannot upload image files larger than %s x %s pixels!');
+
+@define('MEDIA_TARGET', 'Target for this link');
+@define('MEDIA_TARGET_JS', 'Popup window (via JavaScript, adaptive size)');
+@define('MEDIA_ENTRY', 'Isolated Entry');
+@define('MEDIA_TARGET_BLANK', 'Popup window (via target=_blank)');
+
+@define('MEDIA_DYN_RESIZE', 'Allow dynamic image resizing?');
+@define('MEDIA_DYN_RESIZE_DESC', 'If enabled, the media selector can return images in any requested size via a GET variable. The results are cached, and thus can create a large filebase if you make intensive use of it.');
+
+@define('MEDIA_DIRECTORY_MOVED', 'Directory and files were successfully moved to %s');
+@define('MEDIA_DIRECTORY_MOVE_ERROR', 'Directory and files could not be moved to %s!');
+@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'On Non-MySQL databases, iterating through every article to replace the old directory URLs with new directory URLs is not possible. You will need to manually edit your entries to fix new URLs. You can still move your old directory back to where it was, if that is too cumbersome for you.');
+@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Moved the URL of the moved directory in %s entries.');
+@define('PLUGIN_ACTIVE', 'Active');
+@define('PLUGIN_INACTIVE', 'Inactive');
+@define('PREFERENCE_USE_JS', 'Enable advanced JS usage?');
+@define('PREFERENCE_USE_JS_DESC', 'If enabled, advanced JavaScript sections will be enabled for better usability, like in the Plugin Configuration section you can use drag and drop for re-ordering plugins.');
+
+@define('PREFERENCE_USE_JS_WARNING', '(This page uses advanced JavaScripting. If you are having functionality issues, please disable the use of advanced JS usage in your personal preferences or disable your browser\'s JavaScript)');
+
+
+@define('INSTALL_PERMALINK_COMMENTSPATH', 'Path to comments');
+@define('PERM_SET_CHILD', 'Set the same permissions on all child directories');
+@define('PERMISSION_FORBIDDEN_PLUGINS', 'Forbidden plugins');
+@define('PERMISSION_FORBIDDEN_HOOKS', 'Forbidden events');
+@define('PERMISSION_FORBIDDEN_ENABLE', 'Enable Plugin ACL for usergroups?');
+@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'If the option "Plugin ACL for usergroups" is enabled in the configuration, you can specify which usergroups are allowed to execute certain plugins/events.');
+@define('DELETE_SELECTED_ENTRIES', 'Delete selected entries');
+@define('PLUGIN_AUTHORS_MINCOUNT', 'Show only authors with at least X articles');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
+@define('IMPORT_WP_PAGES', 'Also fetch attachments and staticpages as normal blog entries?');
+@define('USERCONF_CREATE', 'Disable user / forbid activity?');
+@define('USERCONF_CREATE_DESC', 'If selected, the user will not have any editing or creation possibilities on the blog anymore. When logging in to the backend, he cannot do anything else apart from logging out and viewing his personal configuration.');
+@define('CATEGORY_HIDE_SUB', 'Hide postings made to sub-categories?');
+@define('CATEGORY_HIDE_SUB_DESC', 'By default, when you browse a category also entries of any subcategory are displayed. If this option is turned on, only postings of the currently selected category are displayed.');
+@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
+@define('PINGBACK_SENT', 'Pingback successful');
+@define('PINGBACK_FAILED', 'Pingback failed: %s');
+@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
+@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
+@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
