@@ -694,8 +694,6 @@
 @define('INSTALL_PERMALINK_PLUGINPATH', 'مسار بلوق ان معين');
 @define('INSTALL_PERMALINK_ADMINPATH', 'مسار لوحة التحكم');
 @define('INSTALL_PERMALINK_SEARCHPATH', 'مسار البحث');
-@define('USERCONF_CREATE', 'هذا الانشاء محرم؟');
-@define('USERCONF_CREATE_DESC', 'ان تم اختيارة سوف لن يستطيع المستخدم الدخول على كامل خصائص لوحة التحكم ');
 @define('INSTALL_CAL', 'نوع التقويم');
 @define('INSTALL_CAL_DESC', 'اختر هيئة التقوم التي تريد');
 @define('REPLY', 'رد');
@@ -806,3 +804,14 @@
 @define('PLUGIN_AUTHORS_MINCOUNT', 'Show only authors with at least X articles');
 @define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
 @define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
+@define('IMPORT_WP_PAGES', 'Also fetch attachments and staticpages as normal blog entries?');
+@define('USERCONF_CREATE', 'Disable user / forbid activity?');
+@define('USERCONF_CREATE_DESC', 'If selected, the user will not have any editing or creation possibilities on the blog anymore. When logging in to the backend, he cannot do anything else apart from logging out and viewing his personal configuration.');
+@define('CATEGORY_HIDE_SUB', 'Hide postings made to sub-categories?');
+@define('CATEGORY_HIDE_SUB_DESC', 'By default, when you browse a category also entries of any subcategory are displayed. If this option is turned on, only postings of the currently selected category are displayed.');
+@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
+@define('PINGBACK_SENT', 'Pingback successful');
+@define('PINGBACK_FAILED', 'Pingback failed: %s');
+@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
+@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
+@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
