@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_tw.inc.php 1515 2006-11-22 10:30:13Z garvinhicking $
+<?php # $Id: serendipity_lang_tw.inc.php 1970 2007-10-08 06:01:13Z capriskye $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translated by CapriSkye <admin@capriskye.com>
@@ -693,8 +693,6 @@ $i18n_unknown = 'tw';
 @define('INSTALL_PERMALINK_PLUGINPATH', '單外掛路徑');
 @define('INSTALL_PERMALINK_ADMINPATH', '管理路徑');
 @define('INSTALL_PERMALINK_SEARCHPATH', '搜尋路徑');
-@define('USERCONF_CREATE', '不允許新增文章？');
-@define('USERCONF_CREATE_DESC', '如果選擇，作者將不能發佈新文章。');
 @define('INSTALL_CAL', '日曆類型');
 @define('INSTALL_CAL_DESC', '請選擇您要的日曆類型');
 @define('REPLY', '回覆');
@@ -849,7 +847,7 @@ $i18n_unknown = 'tw';
 @define('PLUGIN_AVAILABLE_COUNT', '總共： %d 個外掛。');
 
 @define('SYNDICATION_RFC2616', '開啟依照嚴格的 RFC2616 RSS-Feed');
-@define('SYNDICATION_RFC2616_DESC', '不強制 RFC2616 表示全部有條件的 GETs 到 Serendipity 只會傳回最後修改的文章。如果設定為 "false" 表示訪客會接收全部的文章。不過，一些網誌的蒐集軟體像 Planet 會出現奇怪現象。如果出現奇怪現象表示它違反了 RFC2616 的標準。所以設定為 "TRUE" 表示你遵從 RFC 的標準，但是訪客可能會讀取不到全部的文章。整體來說，不管怎樣都無法顧到兩方。相關資訊：https://sourceforge.net/tracker/index.php?func=detail&aid=1461728&group_id=75065&atid=542822');
+@define('SYNDICATION_RFC2616_DESC', '不強制 RFC2616 表示全部有條件的 GETs 到 Serendipity 只會傳回最後修改的文章。如果設定為 "false" 表示訪客會接收全部的文章。不過，一些網誌的蒐集軟體像 Planet 會出現奇怪現象。如果出現奇怪現象表示它違反了 RFC2616 的標準。所以設定為 "TRUE" 表示你遵從 RFC 的標準，但是訪客可能會讀取不到全部的文章。整體來說，不管怎樣都無法顧到兩方。相關資訊：<a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
 @define('MEDIA_PROPERTY_DATE', '相關日期');
 @define('MEDIA_PROPERTY_RUN_LENGTH', '長度');
 @define('FILENAME_REASSIGNED', '自動指定新檔案的名稱： %s');
@@ -869,25 +867,37 @@ $i18n_unknown = 'tw';
 
 @define('MEDIA_DYN_RESIZE', '允許改變圖片大小？');
 @define('MEDIA_DYN_RESIZE_DESC', '如果開啟，媒體的選擇視窗裡會顯示依照 GET 變數所設定的圖片大小。圖片會儲存於快取的記憶體內，所以常使用會佔用主機的空間。');
-@define('MEDIA_DIRECTORY_MOVED', 'Directory and files were successfully moved to %s');
-@define('MEDIA_DIRECTORY_MOVE_ERROR', 'Directory and files could not be moved to %s!');
-@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'On Non-MySQL databases, iterating through every article to replace the old directory URLs with new directory URLs is not possible. You will need to manually edit your entries to fix new URLs. You can still move your old directory back to where it was, if that is too cumbersome for you.');
-@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Moved the URL of the moved directory in %s entries.');
-@define('PLUGIN_ACTIVE', 'Active');
-@define('PLUGIN_INACTIVE', 'Inactive');
-@define('PREFERENCE_USE_JS', 'Enable advanced JS usage?');
-@define('PREFERENCE_USE_JS_DESC', 'If enabled, advanced JavaScript sections will be enabled for better usability, like in the Plugin Configuration section you can use drag and drop for re-ordering plugins.');
 
-@define('PREFERENCE_USE_JS_WARNING', '(This page uses advanced JavaScripting. If you are having functionality issues, please disable the use of advanced JS usage in your personal preferences or disable your browser\'s JavaScript)');
+@define('MEDIA_DIRECTORY_MOVED', '目錄和檔案已成功移動到 %s');
+@define('MEDIA_DIRECTORY_MOVE_ERROR', '目錄和檔案無法移動到 %s！');
+@define('MEDIA_DIRECTORY_MOVE_ENTRY', '在非 MySQL 資料庫內，無法移動文章到新的目錄。您需要自己修改文章的網址。您還是可以將舊目錄回覆到原來的位址。');
+@define('MEDIA_DIRECTORY_MOVE_ENTRIES', '移動 %s 篇文章的網誌到新的目錄。');
+@define('PLUGIN_ACTIVE', '開啟');
+@define('PLUGIN_INACTIVE', '關閉');
+@define('PREFERENCE_USE_JS', '開啟進階的 JS 用法？');
+@define('PREFERENCE_USE_JS_DESC', '如果開啟，進階的 JavaScript 將會提供更好的用途，例如類似外掛設定內的牽曳和移動功能。');
+
+@define('PREFERENCE_USE_JS_WARNING', '(這個頁面使用了進階的 JavaScript。如果您遇到問題，請將進階的 JS 用法或瀏覽器的 JavaScript 關閉。)');
 
 
-@define('INSTALL_PERMALINK_COMMENTSPATH', 'Path to comments');
-@define('PERM_SET_CHILD', 'Set the same permissions on all child directories');
-@define('PERMISSION_FORBIDDEN_PLUGINS', 'Forbidden plugins');
-@define('PERMISSION_FORBIDDEN_HOOKS', 'Forbidden events');
-@define('PERMISSION_FORBIDDEN_ENABLE', 'Enable Plugin ACL for usergroups?');
-@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'If the option "Plugin ACL for usergroups" is enabled in the configuration, you can specify which usergroups are allowed to execute certain plugins/events.');
-@define('DELETE_SELECTED_ENTRIES', 'Delete selected entries');
-@define('PLUGIN_AUTHORS_MINCOUNT', 'Show only authors with at least X articles');
-@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
-@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
+@define('INSTALL_PERMALINK_COMMENTSPATH', '留言的路徑');
+@define('PERM_SET_CHILD', '將全部的子目錄設為相同權限');
+@define('PERMISSION_FORBIDDEN_PLUGINS', '禁用外掛');
+@define('PERMISSION_FORBIDDEN_HOOKS', '禁用事件');
+@define('PERMISSION_FORBIDDEN_ENABLE', '開啟外掛 ACL 給會員群組？');
+@define('PERMISSION_FORBIDDEN_ENABLE_DESC', '如果 "外掛 ACL 給會員群組" 是開啟的狀態，您可以指定某些群組來執行外掛和事件。');
+@define('DELETE_SELECTED_ENTRIES', '刪除選擇的文章');
+@define('PLUGIN_AUTHORS_MINCOUNT', '顯示多於 X 文章的作者');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET', '書籤');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', '將這個連結設為書籤可以讓您快速的進入網誌。');
+@define('IMPORT_WP_PAGES', '輸入附件檔案和靜態頁面於普通的網誌文章？');
+@define('USERCONF_CREATE', '禁止會員／禁止動作？');
+@define('USERCONF_CREATE_DESC', '如果勾選，此會員將被禁止任何編輯或新增網誌的動作。如果登入後端，他被允許的動作只有登入／登出和瀏覽自己的設定。');
+@define('CATEGORY_HIDE_SUB', '隱藏子類別的文章？');
+@define('CATEGORY_HIDE_SUB_DESC', '預設的狀態是當您瀏覽目錄時，子目錄的文章也會顯示。如果勾選此設定，只會顯示瀏覽的目錄內的文章。');
+@define('PINGBACK_SENDING', '傳送回測到網頁 %s...');
+@define('PINGBACK_SENT', '回測完成');
+@define('PINGBACK_FAILED', '回測失敗： %s');
+@define('PINGBACK_NOT_FOUND', '沒有回測的網頁。');
+@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', '隱藏歷史的連接如果時間內沒有文章 (需要計算文章數)');
+@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
