@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_zh.inc.php 1515 2006-11-22 10:30:13Z garvinhicking $
+<?php # $Id: serendipity_lang_zh.inc.php 1907 2007-09-10 10:42:31Z brockhaus $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translated by
@@ -220,7 +220,7 @@
 @define('NEW_COMMENT_TO_SUBSCRIBED_ENTRY', '新回复到订阅的文章 "%s"');
 @define('SUBSCRIPTION_MAIL', "你好 %s,\n\n你订阅的文章有了新的回复在 \"%s\", 标题是 \"%s\"\n回复的发表者是: %s\n\n你可以在这找到此文章: %s\n\n你可以点这个连接取消订阅: %s\n");
 @define('SUBSCRIPTION_TRACKBACK_MAIL', "你好 %s,\n\n你订阅的文章有了新的引用在 \"%s\", 标题是 \"%s\"\n引用的作者是: %s\n\n你可以在这找到此文章: %s\n\n你可以点这个连接取消订阅: %s\n");
-@define('SIGNATURE', "\n-- \n%s is powered by Serendipity.\n 最好的日志程序, 希望你喜欢它.\n 详情 <http://www.cexten.com> 得到更多支持...");
+@define('SIGNATURE', "\n-- \n%s is powered by Serendipity.\n <http://www.s9y.org>");
 @define('SYNDICATION_PLUGIN_091', 'RSS 0.91 feed');
 @define('SYNDICATION_PLUGIN_10', 'RSS 1.0 feed');
 @define('SYNDICATION_PLUGIN_20', 'RSS 2.0 feed');
@@ -693,8 +693,6 @@
 @define('INSTALL_PERMALINK_PLUGINPATH', '单外挂路径');
 @define('INSTALL_PERMALINK_ADMINPATH', '管理路径');
 @define('INSTALL_PERMALINK_SEARCHPATH', '搜索路径');
-@define('USERCONF_CREATE', '不允许新增新文章');
-@define('USERCONF_CREATE_DESC', '如果选择，作者将不能发布新文章。');
 @define('INSTALL_CAL', '日历类型');
 @define('INSTALL_CAL_DESC', '请选择你要的日历类型');
 @define('REPLY', '回复');
@@ -848,7 +846,7 @@
 @define('PLUGIN_AVAILABLE_COUNT', '总共： %d 个外挂');
 
 @define('SYNDICATION_RFC2616', '开启依照严格的 RFC2616 RSS-Feed');
-@define('SYNDICATION_RFC2616_DESC', '不强制 RFC2616 表示全部有条件的 GETs 到 Serendipity Blog 只会传回最后修改的文章。如果设定为 "false" 表示访客接受全部的文章。不过，一些日志的程序像 Planet 会出现奇怪现象。如果出现奇怪现象表示它违反了 RFC2616 的标准。所以设定为 "TRUE" 表示你遵从 RFC 的标准，但访客可能读取不到全部文章。整体来说，不管怎样都无法照顾到两方。详情请参阅：https://sourceforge.net/tracker/index.php?func=detail&aid=1461728&group_id=75065&atid=542822');
+@define('SYNDICATION_RFC2616_DESC', '不强制 RFC2616 表示全部有条件的 GETs 到 Serendipity Blog 只会传回最后修改的文章。如果设定为 "false" 表示访客接受全部的文章。不过，一些日志的程序像 Planet 会出现奇怪现象。如果出现奇怪现象表示它违反了 RFC2616 的标准。所以设定为 "TRUE" 表示你遵从 RFC 的标准，但访客可能读取不到全部文章。整体来说，不管怎样都无法照顾到两方。详情请参阅：<a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
 @define('MEDIA_PROPERTY_DATE', '相关日期');
 @define('MEDIA_PROPERTY_RUN_LENGTH', '长度');
 @define('FILENAME_REASSIGNED', '自动指定新文件名称： %s');
@@ -888,3 +886,14 @@
 @define('PLUGIN_AUTHORS_MINCOUNT', 'Show only authors with at least X articles');
 @define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
 @define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
+@define('IMPORT_WP_PAGES', 'Also fetch attachments and staticpages as normal blog entries?');
+@define('USERCONF_CREATE', 'Disable user / forbid activity?');
+@define('USERCONF_CREATE_DESC', 'If selected, the user will not have any editing or creation possibilities on the blog anymore. When logging in to the backend, he cannot do anything else apart from logging out and viewing his personal configuration.');
+@define('CATEGORY_HIDE_SUB', 'Hide postings made to sub-categories?');
+@define('CATEGORY_HIDE_SUB_DESC', 'By default, when you browse a category also entries of any subcategory are displayed. If this option is turned on, only postings of the currently selected category are displayed.');
+@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
+@define('PINGBACK_SENT', 'Pingback successful');
+@define('PINGBACK_FAILED', 'Pingback failed: %s');
+@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
+@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
+@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
