@@ -1,10 +1,10 @@
-<?php # $Id: serendipity_lang_bg.inc.php 1515 2006-11-22 10:30:13Z garvinhicking $
+<?php # $Id: serendipity_lang_bg.inc.php 2054 2007-12-06 09:26:35Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation (c) 2004 Bogomil Shopov <bogomil@spisanie.com>
 # http://www.purplerain.org/nb/
 # Ognyan Kulev <ogi@fmi.uni-sofia.bg>, 2005
-# Ivan Cenov <JWalker@hotmail.bg>, 2005-2006
+# Ivan Cenov <JWalker@hotmail.bg>, 2005-2007
 /* vim: set sts=4 ts=4 expandtab : */
 
 @define('LANG_CHARSET', 'windows-1251');
@@ -14,6 +14,8 @@
 @define('DATE_FORMAT_ENTRY', '%A, %e %B %Y');
 @define('WYSIWYG_LANG', 'en');
 @define('LANG_DIRECTION', 'ltr');
+$i18n_filename_from = array(' ', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '');
+$i18n_filename_to   = array('-', 'a', 'A', 'b', 'B', 'v', 'V', 'g', 'G', 'd', 'D', 'e', 'E', 'Zh', 'zh', 'z', 'Z', 'i', 'I', 'j', 'J', 'k', 'K', 'l', 'L', 'm', 'M', 'n', 'N', 'o', 'O', 'p', 'P', 'r', 'R', 's', 'S', 't', 'T', 'u', 'U', 'f', 'F', 'h', 'H', 'c', 'C', 'ch', 'Ch', 'sh', 'Sh', 'sht', 'Sht', 'a', 'A', 'y', 'Y', 'ju', 'Ju', 'ja', 'Ja');
 
 @define('SERENDIPITY_ADMIN_SUITE', '  Serendipity');
 @define('HAVE_TO_BE_LOGGED_ON', '  ,     :');
@@ -69,7 +71,7 @@
 @define('NO_COMMENTS', ' ');
 @define('POSTED_BY', ' ');
 @define('ON', '');
-@define('A_NEW_COMMENT_BLAHBLAH', '        "%s",  "%s".');
+@define('A_NEW_COMMENT_BLAHBLAH', '       "%s",   "%s".');
 @define('A_NEW_TRACKBACK_BLAHBLAH', '      "%s".');
 @define('NO_CATEGORY', ' ');
 @define('ENTRY_BODY', '  ');
@@ -229,7 +231,7 @@
 @define('TYPE', 'T');
 @define('DRAFT', '');
 @define('PUBLISH', '');
-@define('PREVIEW', ' ');
+@define('PREVIEW', '');
 @define('DATE', '');
 @define('DATE_FORMAT_2', 'Y-m-d H:i'); // Needs to be ISO 8601 compliant for date conversion!
 @define('DATE_INVALID', ':     .      : YYYY-MM-DD HH:MM ');
@@ -679,8 +681,6 @@
 @define('INSTALL_PERMALINK_PLUGINPATH', '   ');
 @define('INSTALL_PERMALINK_ADMINPATH', '  ');
 @define('INSTALL_PERMALINK_SEARCHPATH', '  ');
-@define('USERCONF_CREATE', '    ?');
-@define('USERCONF_CREATE_DESC', '  ,       ');
 @define('INSTALL_CAL', ' ');
 @define('INSTALL_CAL_DESC', '      ');
 @define('REPLY', '');
@@ -835,7 +835,7 @@
 @define('MEDIA_PROPERTY_DATE', ' ');
 @define('MEDIA_PROPERTY_RUN_LENGTH', ' (    )');
 @define('SYNDICATION_RFC2616', '     RFC2616 RSS-');
-@define('SYNDICATION_RFC2616_DESC', '  RFC2616 ,    GET   Serendipity   ,      .    \'\'          ,          .     Planet ,  .    ,      RFC2616.  ,      \'\',     RFC2616,     RSS           ().              Planet,          .       ,    .  : https://sourceforge.net/tracker/index.php?func=detail&aid=1461728&group_id=75065&atid=542822');
+@define('SYNDICATION_RFC2616_DESC', '  RFC2616 ,    GET   Serendipity   ,      .    \'\'          ,          .     Planet ,  .    ,      RFC2616.  ,      \'\',     RFC2616,     RSS           ().              Planet,          .       ,    .  : <a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
 @define('FILENAME_REASSIGNED', '     : %s');
 @define('MEDIA_UPLOAD_SIZE', '     ');
 @define('MEDIA_UPLOAD_SIZE_DESC', '       .         .  PHP.ini: upload_max_filesize, post_max_size, max_input_time     .           .');
@@ -875,4 +875,15 @@
 @define('DELETE_SELECTED_ENTRIES', '   ');
 @define('PLUGIN_AUTHORS_MINCOUNT', '     - X ');
 @define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
-@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', ' ()          ,               .');
+@define('IMPORT_WP_PAGES', '        ?');
+@define('USERCONF_CREATE', '   /   ?');
+@define('USERCONF_CREATE_DESC', '  ,                 .     ,        ,         .');
+@define('CATEGORY_HIDE_SUB', '  ,   ?');
+@define('CATEGORY_HIDE_SUB_DESC', '    ,      .     ,         .');
+@define('PINGBACK_SENDING', '  pingback  URI %s...');
+@define('PINGBACK_SENT', ' pingback');
+@define('PINGBACK_FAILED', ' pingback: %s');
+@define('PINGBACK_NOT_FOUND', '   pingback-URI.');
+@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', '    ,         (   )');
+@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
