@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_cz.inc.php 1533 2006-12-04 09:20:14Z garvinhicking $
+<?php # $Id: serendipity_lang_cz.inc.php 2054 2007-12-06 09:26:35Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation (c) 2004 Josef Klimosz <ok2wo@centrum.cz>
@@ -703,8 +703,6 @@ $i18n_filename_to = array (
 @define('INSTALL_PERMALINK_PLUGINPATH', 'Cesta k jednotlivmu pluginu');
 @define('INSTALL_PERMALINK_ADMINPATH', 'Cesta k adminu');
 @define('INSTALL_PERMALINK_SEARCHPATH', 'Cesta k vyhledvn');
-@define('USERCONF_CREATE', 'Zakzat vytven zznam?');
-@define('USERCONF_CREATE_DESC', 'Pokud bude vybrno, uivatel neme vytvet nov zznamy');
 @define('INSTALL_CAL', 'Typ kalende');
 @define('INSTALL_CAL_DESC', 'Vyberte formt kalende');
 @define('REPLY', 'Odpov');
@@ -858,7 +856,7 @@ $i18n_filename_to = array (
 @define('PLUGIN_AVAILABLE_COUNT', 'Celkem: %d plugin.');
 
 @define('SYNDICATION_RFC2616', 'Aktivovat strict RFC2616 RSS-Feed compliance');
-@define('SYNDICATION_RFC2616_DESC', 'Kdy neaktivujete  RFC2616, znamen to, e vechny podmnn GETy na Serendipity vrt pspvky, kter byly modifikovny od asu poslednho poadavku. Kdy tohle nastavte na  "false", vai nvtvnci dostanou vechny lnky od svho poslednho poadavku, co se povauje za dobrou vc. Avak nkte agenti jako  Planet funguj divn, kdy tohle nastane a taky to poruuje  RFC2616. Take kdy nastavte tuto volbu na  "TRUE", budete vyhovovat RFC ale nvtvnkm   mohou ve  tekch  bhem przdnin zmizet pspvky. V kadm ppad, bu to vad agregtorm jako je  Planet, nebo to vad nvtvnkm blogu. Kdy se vyskytnou stnosti z kterkoli strany, mete tuhle volbu pepnout.  Reference: https://sourceforge.net/tracker/index.php?func=detail&aid=1461728&group_id=75065&atid=542822');
+@define('SYNDICATION_RFC2616_DESC', 'Kdy neaktivujete  RFC2616, znamen to, e vechny podmnn GETy na Serendipity vrt pspvky, kter byly modifikovny od asu poslednho poadavku. Kdy tohle nastavte na  "false", vai nvtvnci dostanou vechny lnky od svho poslednho poadavku, co se povauje za dobrou vc. Avak nkte agenti jako  Planet funguj divn, kdy tohle nastane a taky to poruuje  RFC2616. Take kdy nastavte tuto volbu na  "TRUE", budete vyhovovat RFC ale nvtvnkm   mohou ve  tekch  bhem przdnin zmizet pspvky. V kadm ppad, bu to vad agregtorm jako je  Planet, nebo to vad nvtvnkm blogu. Kdy se vyskytnou stnosti z kterkoli strany, mete tuhle volbu pepnout.  Reference: <a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
 @define('MEDIA_PROPERTY_DATE', 'Asociovan datum');
 @define('MEDIA_PROPERTY_RUN_LENGTH', 'Run-Length');
 @define('FILENAME_REASSIGNED', 'Automaticky pidlen nov jmno souboru: %s');
@@ -897,3 +895,14 @@ $i18n_filename_to = array (
 @define('PERMISSION_FORBIDDEN_HOOKS', 'Zakzan udlosti');
 @define('PERMISSION_FORBIDDEN_ENABLE', 'Povolit Plugin ACL pro uivatelsk skupiny?');
 @define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'Jestlie je volba "Plugin ACL pro uivatelsk skupiny" v konfiguraci povolena, mete urit, kter skupiny uivatel mohou provdt urit pluginy/udlosti.');
+@define('IMPORT_WP_PAGES', 'Also fetch attachments and staticpages as normal blog entries?');
+@define('USERCONF_CREATE', 'Disable user / forbid activity?');
+@define('USERCONF_CREATE_DESC', 'If selected, the user will not have any editing or creation possibilities on the blog anymore. When logging in to the backend, he cannot do anything else apart from logging out and viewing his personal configuration.');
+@define('CATEGORY_HIDE_SUB', 'Hide postings made to sub-categories?');
+@define('CATEGORY_HIDE_SUB_DESC', 'By default, when you browse a category also entries of any subcategory are displayed. If this option is turned on, only postings of the currently selected category are displayed.');
+@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
+@define('PINGBACK_SENT', 'Pingback successful');
+@define('PINGBACK_FAILED', 'Pingback failed: %s');
+@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
+@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
+@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
