@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_de.inc.php 1515 2006-11-22 10:30:13Z garvinhicking $
+<?php # $Id: serendipity_lang_de.inc.php 2054 2007-12-06 09:26:35Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation (c) Jannis Hermanns, Garvin Hicking and others
@@ -30,7 +30,7 @@
 @define('NAME', 'Name');
 @define('NEW_TRACKBACK_TO', 'Neues Trackback fr');
 @define('NEW_COMMENT_TO', 'Neuer Kommentar fr');
-@define('RECENT', 'Das neueste ...');
+@define('RECENT', 'Das Neueste ...');
 @define('OLDER', 'lteres ...');
 @define('ANONYMOUS', 'Anonym');
 @define('CREATE_NEW_CAT', 'Neue Kategorie');
@@ -68,7 +68,7 @@
 @define('NO_COMMENTS', 'Noch keine Kommentare');
 @define('POSTED_BY', 'Geschrieben von');
 @define('ON', 'am');
-@define('A_NEW_COMMENT_BLAHBLAH', 'Im Blog %s wurde ein neuer Kommentar zu Eintrag #%s abgegeben!');
+@define('A_NEW_COMMENT_BLAHBLAH', 'Im Blog %s wurde ein neuer Kommentar zu Eintrag "%s" abgegeben!');
 @define('NO_CATEGORY', 'Keine Kategorie');
 @define('ENTRY_BODY', 'Eintrag');
 @define('EXTENDED_BODY', 'Erweiterter Eintrag');
@@ -692,8 +692,6 @@
 @define('INSTALL_PERMALINK_PLUGINPATH', 'Pfad zu einem externen Plugin');
 @define('INSTALL_PERMALINK_ADMINPATH', 'Pfad zur Administration');
 @define('INSTALL_PERMALINK_SEARCHPATH', 'Pfad zur Suche');
-@define('USERCONF_CREATE', 'Erstellung von Eintrgen verbieten?');
-@define('USERCONF_CREATE_DESC', 'Falls diese Option aktiviert ist, darf ein Benutzer keine neuen Eintrge erstellen.');
 @define('INSTALL_CAL', 'Kalendertyp');
 @define('INSTALL_CAL_DESC', 'Whlen Sie das gewnschte Kalenderformat');
 @define('REPLY', 'Antwort');
@@ -845,7 +843,7 @@
 @define('PLUGIN_AVAILABLE_COUNT', 'Gesamt: %d Plugins.');
 
 @define('SYNDICATION_RFC2616', 'Strikte RFC2616 RSS-Feed Kompatibilitt');
-@define('SYNDICATION_RFC2616_DESC', 'Falls RFC2616 NICHT strikt ausgelegt wird, knnen alle Conditional GET Anfragen zu Serendipity die letzten Eintrge seit dem letzten Client-Abruf zurckliefern - fr Benutzer, die auch nach ihrem Urlaub alle Artikel lesen wollen, ist dies eine tolle Sache. Jedoch knnen dadurch einige spezielle Clients wie z.B. Planet aus dem Tritt gebracht werden, und neue Artikel ihres RSS-Feeds falsch interpretieren. Wenn diese Option also auf JA gesetzt wird, wird zwar die RFC befolgt, aber ihre RSS-Leser knnten Eintrge verpassen wenn Sie lnger nicht auf ihrer Seite waren. Wie auch immer sie sich entscheiden, entweder rgern Sie damit Clients wie Planet oder Ihre Benutzer. Referenz: https://sourceforge.net/tracker/index.php?func=detail&aid=1461728&group_id=75065&atid=542822');
+@define('SYNDICATION_RFC2616_DESC', 'Falls RFC2616 NICHT strikt ausgelegt wird, knnen alle Conditional GET Anfragen zu Serendipity die letzten Eintrge seit dem letzten Client-Abruf zurckliefern - fr Benutzer, die auch nach ihrem Urlaub alle Artikel lesen wollen, ist dies eine tolle Sache. Jedoch knnen dadurch einige spezielle Clients wie z.B. Planet aus dem Tritt gebracht werden, und neue Artikel ihres RSS-Feeds falsch interpretieren. Wenn diese Option also auf JA gesetzt wird, wird zwar die RFC befolgt, aber ihre RSS-Leser knnten Eintrge verpassen wenn Sie lnger nicht auf ihrer Seite waren. Wie auch immer sie sich entscheiden, entweder rgern Sie damit Clients wie Planet oder Ihre Benutzer. Referenz: <a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
 @define('MEDIA_PROPERTY_DATE', 'Verknpftes Datum');
 @define('MEDIA_PROPERTY_RUN_LENGTH', 'Laufzeit');
 @define('FILENAME_REASSIGNED', 'Automagisch zugewiesener Dateiname: %s');
@@ -879,8 +877,19 @@
 @define('PERMISSION_FORBIDDEN_PLUGINS', 'Verbotene Plugins');
 @define('PERMISSION_FORBIDDEN_HOOKS', 'Verbotene Ereignisse');
 @define('PERMISSION_FORBIDDEN_ENABLE', 'Sollen persnliche Plugin-Rechte fr Benutzergruppen aktiviert werden?');
-@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'Falls diese Option aktiviert ist, knnen Sie bei jeder Benutzergruppe definieren, welche Plugins/Ereignisse diese Gruppe ausfhren darf.');
+@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'Falls die globale Konfigurations-Option "Sollen persnliche Plugin-Rechte fr Benutzergruppen aktiviert werden" aktiviert ist, knnen Sie bei jeder Benutzergruppe definieren, welche Plugins/Ereignisse diese Gruppe ausfhren darf.');
 @define('DELETE_SELECTED_ENTRIES', 'Markierte Eintrge lschen');
-@define('PLUGIN_AUTHORS_MINCOUNT', 'Show only authors with at least X articles');
+@define('PLUGIN_AUTHORS_MINCOUNT', 'Nur Autoren mit mindestens X Beitrgen anzeigen');
 @define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
 @define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Fgen Sie diesen Link als Lesezeichen/Favoriten hinzu. Dann knnen Sie dieses Lesezeichen auf jeder beliebigen Seite benutzen um so sofort in ihr Serendipity-Blog zu gelangen.');
+@define('IMPORT_WP_PAGES', 'Auch attachments und staticpages als normale Blog-Eintrge importieren?');
+@define('USERCONF_CREATE', 'Benutzer deaktivieren / Rechte entziehen?');
+@define('USERCONF_CREATE_DESC', 'Wenn diese Option aktiviert ist, wird dieser Benutzer keine Mglichkeit mehr haben Eintrge anzulegen oder sonstige Aktionen auszufhren. Wenn er in die Administrations-Oberflche kommt, wird er nichts anderes tun knnen als seine Persnlichen Einstellungen zu ndern und sich auszuloggen.');
+@define('CATEGORY_HIDE_SUB', 'Artikel von Unterkategorien verstecken?');
+@define('CATEGORY_HIDE_SUB_DESC', 'Standardmig werden bei der Ansicht einer Kategorie im Frontend alle Artikel der gewhlten Kategorie und aller Unterkategorien angezeigt. Wenn diese Option aktiviert wird, werden Artikel von Unterkategorien nicht angezeigt.');
+@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
+@define('PINGBACK_SENT', 'Pingback successful');
+@define('PINGBACK_FAILED', 'Pingback failed: %s');
+@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
+@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
+@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
