@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_es.inc.php 1515 2006-11-22 10:30:13Z garvinhicking $
+<?php # $Id: serendipity_lang_es.inc.php 2054 2007-12-06 09:26:35Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation (c) by Luis Cervantes <LuisCervantes@ono.com>,
@@ -673,7 +673,7 @@
 @define('USERCONF_REALNAME_DESC', 'El nombre completo del autor. Este es el nombre que vern los lectores.');
 @define('HOTLINK_DONE', 'Fichero como recurso externo enlazado.<br />Hecho.');
 @define('ENTER_MEDIA_URL_METHOD', 'Mtodo de obtencin:');
-@define('ADD_MEDIA_BLAHBLAH_NOTE', 'Nota: Enlazar recursos externos te permite usar imgenes externas sin almacenarlas localmente. Si escoges esto, asegrate de que tienes permiso para hacerlo en el servidor externo o bien el servidor es tuyo.');
+@define('ADD_MEDIA_BLAHBLAH_NOTE', 'Nota: Enlazar recursos externos te permite usar imgenes externas sin almacenarlas localmente. Si escoges esta opcin, asegrate de poseer los permisos para hacerlo en el servidor externo o bien el servidor es tuyo.');
 @define('MEDIA_HOTLINKED', 'enlazado externamente');
 @define('FETCH_METHOD_IMAGE', 'Descargar imagen a tu servidor');
 @define('FETCH_METHOD_HOTLINK', 'Enlazar externamente al servidor');
@@ -706,8 +706,6 @@
 @define('INSTALL_PERMALINK_PLUGINPATH', 'Ruta a extensin');
 @define('INSTALL_PERMALINK_ADMINPATH', 'Ruta a admin');
 @define('INSTALL_PERMALINK_SEARCHPATH', 'Ruta para buscar');
-@define('USERCONF_CREATE', 'Prohibir crear entradas?');
-@define('USERCONF_CREATE_DESC', 'Si lo seleccionas el usuario no podr crear nuevas entradas');
 @define('INSTALL_CAL', 'Tipo de calendario');
 @define('INSTALL_CAL_DESC', 'Elige tu formato de calendario');
 @define('REPLY', 'Responder');
@@ -862,7 +860,7 @@ Melvin TODO [20060128]: What spanish word do we use for "referrers" ??
 @define('STYLE_OPTIONS', 'Opciones de Tema/estilo');
 @define('PLUGIN_AVAILABLE_COUNT', 'Total: %d extensiones.');
 @define('SYNDICATION_RFC2616', 'Activar seguimiento estricto de la norma RFC2616 para sindicaciones RSS');
-@define('SYNDICATION_RFC2616_DESC', 'NO forzar el seguimiento de RFC2616 significa que todos los GETs condicionales a Serendipity regresarn entradas modificadas desde la fecha de la ltima solicitud. Con esa caracterstica definida a "false", tus visitantes obtendrn todos los artculos desde su ltima solicitud, lo cual es considerado algo bueno. Sin embargo, algunos agentes como Planet tienen un comportamiento extrao, dado viola la norma RFC2616. De esta manera, si defines esta opcin como "TRUE" estars cumpliendo con la norma, pero los lectores de tus sindicaciones RSS quizs pierdan algunas entradas en sus das de ausencia. De cualquier forma, o evitas un funcionamiento adecuado de agregadores como Planet, o daas a tus lectores reales. Si ests enfrentando quejas de cualquiera de los dos, puedes cambiar esta opcin. Rerefencia: https://sourceforge.net/tracker/index.php?func=detail&aid=1461728&group_id=75065&atid=542822');
+@define('SYNDICATION_RFC2616_DESC', 'NO forzar el seguimiento de RFC2616 significa que todos los GETs condicionales a Serendipity regresarn entradas modificadas desde la fecha de la ltima solicitud. Con esa caracterstica definida a "false", tus visitantes obtendrn todos los artculos desde su ltima solicitud, lo cual es considerado algo bueno. Sin embargo, algunos agentes como Planet tienen un comportamiento extrao, dado viola la norma RFC2616. De esta manera, si defines esta opcin como "TRUE" estars cumpliendo con la norma, pero los lectores de tus sindicaciones RSS quizs pierdan algunas entradas en sus das de ausencia. De cualquier forma, o evitas un funcionamiento adecuado de agregadores como Planet, o daas a tus lectores reales. Si ests enfrentando quejas de cualquiera de los dos, puedes cambiar esta opcin. Rerefencia: <a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
 @define('MEDIA_PROPERTY_DATE', 'Fecha Asociada');
 
 /*Translate*/
@@ -905,3 +903,14 @@ Melvin TODO [20060128]: What spanish word do we use for "referrers" ??
 @define('PLUGIN_AUTHORS_MINCOUNT', 'Slo mostrar aquellos autores con al menos X artculos');
 @define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
 @define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
+@define('IMPORT_WP_PAGES', 'Descargar archivos adjuntos y pginas estticas como entradas normales del blog?');
+@define('USERCONF_CREATE', 'Deshabilitar usuario / prohibir actividad?');
+@define('USERCONF_CREATE_DESC', 'Si activas esta opcin el usuario ya no podr crear o editar entradas en el blog. Cuando l vuelva a ingresar al sistema no podr hacer nada ms que desconectarse y ver su configuracin personal.');
+@define('CATEGORY_HIDE_SUB', 'Ocultar las entradas realizadas en sub-categoras?');
+@define('CATEGORY_HIDE_SUB_DESC', 'Por defecto, cuando se navega una categora tambin se muestran las entradas hechas en cualquiera de sus sub-categoras. Si activas esta opcin, se mostrn unicamente aquellas entradas que pertenezcan a la categora seleccionada.');
+@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
+@define('PINGBACK_SENT', 'Pingback successful');
+@define('PINGBACK_FAILED', 'Pingback failed: %s');
+@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
+@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
+@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
