@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_fa.inc.php 1251 2006-06-09 20:16:09Z garvinhicking $
+<?php # $Id: serendipity_lang_fa.inc.php 2054 2007-12-06 09:26:35Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved. See LICENSE file for licensing details
 # this translation, translated by Omid Mottaghi <http://oxygenws.com>
@@ -13,10 +13,10 @@
 @define('WYSIWYG_LANG', 'en');
 @define('NUMBER_FORMAT_DECIMALS', '2');
 @define('NUMBER_FORMAT_DECPOINT', '.');
-@define('NUMBER_FORMAT_THOUSANDS', ',');
+@define('NUMBER_FORMAT_THOUSANDS', '٫');
 @define('LANG_DIRECTION', 'rtl');
 
-@define('SERENDIPITY_ADMIN_SUITE', 'بخش مدیریت Serendipity');
+@define('SERENDIPITY_ADMIN_SUITE', 'بخش مدیریت سرندیپیتی');
 @define('HAVE_TO_BE_LOGGED_ON', 'برای مشاهده این صفحه باید وارد سیستم شوید');
 @define('WRONG_USERNAME_OR_PASSWORD', 'نام کاربری یا رمز عبور شما اشتباه می باشد');
 @define('APPEARANCE', 'ظاهر');
@@ -148,7 +148,7 @@
 @define('USERNAME', 'نام کاربری');
 @define('PASSWORD', 'رمز عبور');
 @define('AUTOMATIC_LOGIN', 'ذخیره اطلاعات');
-@define('SERENDIPITY_INSTALLATION', 'نصب Serendipity');
+@define('SERENDIPITY_INSTALLATION', 'نصب سرندیپیتی');
 @define('LEFT', 'چپ');
 @define('RIGHT', 'راست');
 @define('HIDDEN', 'مخفی');
@@ -192,9 +192,9 @@
 @define('WWW_USER', 'www را به کاربری که از آپاچی استفاده می کند تغییر دهید (مثلا nobody(.');
 @define('BROWSER_RELOAD', 'پس از تکمیل، صفحه مرورگر را refresh کنید.');
 @define('DIAGNOSTIC_ERROR', 'تعدادی خطا در اطلاعات ورودی شما یافت شد:');
-@define('SERENDIPITY_NOT_INSTALLED', 'Serendipity هنوز نصب نشده است. لطفا هم اکنون آن را <a href="%s">نصب کنید</a>.');
-@define('INCLUDE_ERROR', 'خطای serendipity: توانایی وارد کردن فایل %s وجود ندارد - برنامه متوقف شد.');
-@define('DATABASE_ERROR', 'خطای serendipity: امکان اتصال به پایگاه داده وجود ندارد - برنامه متوقف شد.');
+@define('SERENDIPITY_NOT_INSTALLED', 'سرندیپیتی هنوز نصب نشده است. لطفا هم اکنون آن را <a href="%s">نصب کنید</a>.');
+@define('INCLUDE_ERROR', 'خطای سرندیپیتی: توانایی وارد کردن فایل %s وجود ندارد - برنامه متوقف شد.');
+@define('DATABASE_ERROR', 'خطای سرندیپیتی: امکان اتصال به پایگاه داده وجود ندارد - برنامه متوقف شد.');
 @define('CREATE_DATABASE', 'در حال نصب پیش فرض های پایگاه داده...');
 @define('ATTEMPT_WRITE_FILE', 'تلاش برای نوشتن در فایل %s...');
 @define('WRITTEN_N_SAVED', 'تنظیمات نوشته و ذخیره شد');
@@ -220,7 +220,7 @@
 @define('NEW_COMMENT_TO_SUBSCRIBED_ENTRY', 'توضیح جدیدی برای مطلب "%s" ارسال شد');
 @define('SUBSCRIPTION_MAIL', "سلام %s،\n\nA نظر جدیدی برای مطلب \"%s\"، با تیتر \"%s\" ارسال شده است\nنام ارسال کننده: %s\n\nمی توانید مطلب را در لینک روبرو مشاهده کنید: %s\n\nمی توانید با کلیک روی لینک روبرو این نظر را قبول نکنید: %s\n");
 @define('SUBSCRIPTION_TRACKBACK_MAIL', "سلام %s،\n\nA دنبالک جدیدی برای مطلب \"%s\"، با تیتر \"%s\" ارسال شده است\nنام ارسال کننده: %s\n\nمی توانید مطلب را در لینک روبرو مشاهده کنید: %s\n\nمی توانید با کلیک روی لینک روبرو این دنبالک را قبول نکنید: %s\n");
-@define('SIGNATURE', "\n-- \n%s بر پایه Serendipity بنا شده است.\nبهترین سیستم وبلاگ موجود، شما هم می توانید از این سیستم استفاده کنید.\nسایت <http://s9y.org> را بری روش نصب و استفاده مرور کنید.");
+@define('SIGNATURE', "\n-- \n%s بر پایه سرندیپیتی بنا شده است.\nبهترین سیستم وبلاگ موجود، شما هم می توانید از این سیستم استفاده کنید.\nسایت <http://s9y.org> را بری روش نصب و استفاده مرور کنید.");
 @define('SYNDICATION_PLUGIN_091', 'RSS 0.91');
 @define('SYNDICATION_PLUGIN_10', 'RSS 1.0');
 @define('SYNDICATION_PLUGIN_20', 'RSS 2.0');
@@ -233,7 +233,7 @@
 @define('SYNDICATION_PLUGIN_BANNERHEIGHT', 'ارتفاع تصویر');
 @define('SYNDICATION_PLUGIN_WEBMASTER_DESC', 'ایمیل مدیر سایت، البته در صورت موجود بودن. (خالی=مخفی) [RSS 2.0]');
 @define('SYNDICATION_PLUGIN_MANAGINGEDITOR_DESC', 'در صورت وجود، آدرس ایمیل نویسنده (خالی=مخفی) [RSS 2.0]');
-@define('SYNDICATION_PLUGIN_BANNERURL_DESC', 'در صورت وجود، آدرس عکسی با توسعه GIF یا JPEG یا PNG. (خالی=لوگوی Serendipity)');
+@define('SYNDICATION_PLUGIN_BANNERURL_DESC', 'در صورت وجود، آدرس عکسی با توسعه GIF یا JPEG یا PNG. (خالی=لوگوی سرندیپیتی)');
 @define('SYNDICATION_PLUGIN_BANNERWIDTH_DESC', 'پیکسل، حداکثر 144');
 @define('SYNDICATION_PLUGIN_BANNERHEIGHT_DESC', 'پیکسل، حداکثر 400');
 @define('SYNDICATION_PLUGIN_TTL', 'فیلد "ttl" (زمان زندگی)');
@@ -259,10 +259,10 @@
 @define('DO_MARKUP', 'ایجاد تغییرات Markup');
 @define('GENERAL_PLUGIN_DATEFORMAT', 'تغییر تاریخ');
 @define('GENERAL_PLUGIN_DATEFORMAT_BLAHBLAH', 'طرز نمایش تاریخ در ارسال ها، از قوانین نگارش تابع strftime() در PHP پیروی کنید. (پیش فرض: "%s")');
-@define('ERROR_TEMPLATE_FILE', 'توانایی باز کردن فایل پوسته وجود ندارد، لطفا serendipity را به روز کنید!');
+@define('ERROR_TEMPLATE_FILE', 'توانایی باز کردن فایل پوسته وجود ندارد، لطفا سرندیپیتی را به روز کنید!');
 @define('ADVANCED_OPTIONS', 'گزینه های پیشرفته');
 @define('EDIT_ENTRY', 'تغییر ارسال');
-@define('HTACCESS_ERROR', 'برای چک کردن نصب وب سرور، serendipity احتیاج دارد که در فایل ".htaccess" مقادیری را بنویسد. این امر به دلیل محدودیت های دسترسی ممکن نمی باشد. لطفا سطح دسترسی را مشابه: <br />&nbsp;&nbsp;%s<br />تغییر داده و این صفحه را دوباره صدا بزنید.');
+@define('HTACCESS_ERROR', 'برای چک کردن نصب وب سرور، سرندیپیتی احتیاج دارد که در فایل ".htaccess" مقادیری را بنویسد. این امر به دلیل محدودیت های دسترسی ممکن نمی باشد. لطفا سطح دسترسی را مشابه: <br />&nbsp;&nbsp;%s<br />تغییر داده و این صفحه را دوباره صدا بزنید.');
 @define('SIDEBAR_PLUGINS', 'افزونه های نوار کناری');
 @define('EVENT_PLUGINS', 'افزونه های رویداد');
 @define('SORT_ORDER', 'ترتیب مرتب سازی');
@@ -278,10 +278,10 @@
 @define('ORIGINAL_SHORT', 'اصلی');
 @define('APPLY_MARKUP_TO', 'اعمال کردن markup به %s');
 @define('CALENDAR_BEGINNING_OF_WEEK', 'ابتدای هفته');
-@define('SERENDIPITY_NEEDS_UPGRADE', 'Serendipity فهمید که نسخه فایل تنظیمات شما %s می باشد، در حالی که خود برنامه Serendipity نسخه %s است، شما باید سیستم را به روز رسانی کنید! <a href="%s">اینجا کلیک کنید</a>');
-@define('SERENDIPITY_UPGRADER_WELCOME', 'سلام، به بخش به روز رسانی Serendipity خوش آمدید.');
-@define('SERENDIPITY_UPGRADER_PURPOSE', 'من اینجا هستم تا به شما در به روز رسانی Serendipity %s کمک کنم.');
-@define('SERENDIPITY_UPGRADER_WHY', 'به خاطر نصب Serendipity %s این پیام را مشاهده می کنید، اما پایگاه داده خود را هنوز به روز نکرده اید');
+@define('SERENDIPITY_NEEDS_UPGRADE', 'سرندیپیتی فهمید که نسخه فایل تنظیمات شما %s می باشد، در حالی که خود برنامه سرندیپیتی نسخه %s است، شما باید سیستم را به روز رسانی کنید! <a href="%s">اینجا کلیک کنید</a>');
+@define('SERENDIPITY_UPGRADER_WELCOME', 'سلام، به بخش به روز رسانی سرندیپیتی خوش آمدید.');
+@define('SERENDIPITY_UPGRADER_PURPOSE', 'من اینجا هستم تا به شما در به روز رسانی سرندیپیتی %s کمک کنم.');
+@define('SERENDIPITY_UPGRADER_WHY', 'به خاطر نصب سرندیپیتی %s این پیام را مشاهده می کنید، اما پایگاه داده خود را هنوز به روز نکرده اید');
 @define('SERENDIPITY_UPGRADER_DATABASE_UPDATES', 'پایگاه داده (%s) به روز شد');
 @define('SERENDIPITY_UPGRADER_FOUND_SQL_FILES', 'من فایلی با توسعه .sql پیدا کردم که قبل از ادامه کار باید اجرا شود');
 @define('SERENDIPITY_UPGRADER_VERSION_SPECIFIC', 'کارهای مخصوص این نسخه');
@@ -290,9 +290,9 @@
 @define('SERENDIPITY_UPGRADER_PROCEED_ABORT', 'خیر');
 @define('SERENDIPITY_UPGRADER_PROCEED_DOIT', 'بله');
 @define('SERENDIPITY_UPGRADER_NO_UPGRADES', 'در ظاهر نیازمند به روز رسانی نمی باشید');
-@define('SERENDIPITY_UPGRADER_CONSIDER_DONE', 'رسیدگی کردن به روز رسانی Serendipity');
-@define('SERENDIPITY_UPGRADER_YOU_HAVE_IGNORED', 'شما توانایی به روز رسانی Serendipity را ندارید، لطفا از درست ایجاد شدن پایگاه داده اطمینان پیدا کنید');
-@define('SERENDIPITY_UPGRADER_NOW_UPGRADED', 'Serendipity به نسخه %s به روز رسانی شد');
+@define('SERENDIPITY_UPGRADER_CONSIDER_DONE', 'رسیدگی کردن به روز رسانی سرندیپیتی');
+@define('SERENDIPITY_UPGRADER_YOU_HAVE_IGNORED', 'شما توانایی به روز رسانی سرندیپیتی را ندارید، لطفا از درست ایجاد شدن پایگاه داده اطمینان پیدا کنید');
+@define('SERENDIPITY_UPGRADER_NOW_UPGRADED', 'سرندیپیتی به نسخه %s به روز رسانی شد');
 @define('SERENDIPITY_UPGRADER_RETURN_HERE', '%sاینجا%s کلیک کنید تا به صفحه آغازین وبلاگتان برگردید');
 @define('MANAGE_USERS', 'مدیریت کاربران');
 @define('CREATE_NEW_USER', 'ایجاد یک کاربر جدید');
@@ -333,7 +333,7 @@
 
 /* DATABASE SETTINGS */
 @define('INSTALL_CAT_DB', 'تنظیمات پایگاه داده');
-@define('INSTALL_CAT_DB_DESC', 'شما می توانید اطلاعات کامل پایگاه داده را در اینجا وارد کنید. Serendipity برای فعالیت به این اطلاعات نیاز دارد');
+@define('INSTALL_CAT_DB_DESC', 'شما می توانید اطلاعات کامل پایگاه داده را در اینجا وارد کنید. سرندیپیتی برای فعالیت به این اطلاعات نیاز دارد');
 @define('INSTALL_DBTYPE', 'نوع پایگاه داده');
 @define('INSTALL_DBTYPE_DESC', 'نوع پایگاه داده');
 @define('INSTALL_DBHOST', 'آدرس پایگاه داده');
@@ -345,29 +345,29 @@
 @define('INSTALL_DBNAME', 'نام پایگاه داده');
 @define('INSTALL_DBNAME_DESC', 'نام پایگاه داده شما');
 @define('INSTALL_DBPREFIX', 'پیشوند جداول پایگاه داده');
-@define('INSTALL_DBPREFIX_DESC', 'پیشوند جدول های مربوط به Serendipity، به طور مثال. serendipity_');
+@define('INSTALL_DBPREFIX_DESC', 'پیشوند جدول های مربوط به سرندیپیتی، به طور مثال. serendipity_');
 
 /* PATHS */
 @define('INSTALL_CAT_PATHS', 'مسیر ها');
 @define('INSTALL_CAT_PATHS_DESC', 'مسیر های متفاوت برای شاخه های مهم. فراموش نکنید که برای شاخه ها در آخر یک خط مورب (/) بگذارید!');
 @define('INSTALL_FULLPATH', 'مسیر کامل');
-@define('INSTALL_FULLPATH_DESC', 'آدرس مستقیم و کامل به مکان نصب Serendipity');
+@define('INSTALL_FULLPATH_DESC', 'آدرس مستقیم و کامل به مکان نصب سرندیپیتی');
 @define('INSTALL_UPLOADPATH', 'مسیر بالاگذاری');
 @define('INSTALL_UPLOADPATH_DESC', 'تمامای بالاگذاری ها در این مسیر قرار خواهند گرفت، نسبت به مقدار \'مسیر کامل\' - مثل \'uploads/\'');
 @define('INSTALL_RELPATH', 'مسیر دریافت');
-@define('INSTALL_RELPATH_DESC', 'مسیر Serendipity برای مرورگر شما، مثل \'/serendipity/\'');
+@define('INSTALL_RELPATH_DESC', 'مسیر سرندیپیتی برای مرورگر شما، مثل \'/serendipity/\'');
 @define('INSTALL_RELTEMPLPATH', 'مسیر پوسته ها');
 @define('INSTALL_RELTEMPLPATH_DESC', 'مسیر شاخه ای که فایل های پوسته در آن قرار دارد - نسبت به مقدار \'مسیر دریافت\'');
 @define('INSTALL_RELUPLOADPATH', 'مسیر نسبی بالاگذاری');
 @define('INSTALL_RELUPLOADPATH_DESC', 'مسیر فایل های بالاگذاری شده برای مرورگر شما - نسبت به مقدار \'مسیر دریافت\'');
 @define('INSTALL_URL', 'آدرس وبلاگ');
-@define('INSTALL_URL_DESC', 'آدرس اصلی نصب Serendipity');
+@define('INSTALL_URL_DESC', 'آدرس اصلی نصب سرندیپیتی');
 @define('INSTALL_INDEXFILE', 'فایل فهرست');
 @define('INSTALL_INDEXFILE_DESC', 'نام فایل فهرست (index) شما');
 
 /* GENERAL SETTINGS */
 @define('INSTALL_CAT_SETTINGS', 'تنظیمات عمومی');
-@define('INSTALL_CAT_SETTINGS_DESC', 'تنظیم کردن نوع رفتار Serendipity');
+@define('INSTALL_CAT_SETTINGS_DESC', 'تنظیم کردن نوع رفتار سرندیپیتی');
 @define('INSTALL_USERNAME', 'نام کاربری مدیر');
 @define('INSTALL_USERNAME_DESC', 'نام کاربری مدیر برای ورود');
 @define('INSTALL_PASSWORD', 'رمز عبور مدیر');
@@ -387,25 +387,25 @@
 
 /* APPEARANCE AND OPTIONS */
 @define('INSTALL_CAT_DISPLAY', 'ظاهر و تنظیمات');
-@define('INSTALL_CAT_DISPLAY_DESC', 'تنظیم چگونگی نمایش Serendipity');
+@define('INSTALL_CAT_DISPLAY_DESC', 'تنظیم چگونگی نمایش سرندیپیتی');
 @define('INSTALL_WYSIWYG', 'استفاده از ویرایشگر WYSIWYG');
 @define('INSTALL_WYSIWYG_DESC', 'آیا می خواهید از ویراشگر WYSIWYG استفاده کنید؟ (در IE5+، و مقداری در Mozilla 1.3+ قابل مشاهده می باشد)');
 @define('INSTALL_XHTML11', 'قبول کردن اجباری XHTML 1.1');
 @define('INSTALL_XHTML11_DESC', 'آیا تمایل دارید XHTML 1.1 را به صورت اجباری اعمال کنید (احتمال وجود اشکال در برخی از مرورگر های قدیمی وجود دارد)');
-@define('INSTALL_POPUP', 'توانایی استفاده از پنجره های popup');
-@define('INSTALL_POPUP_DESC', 'آیا تمایل دارید که برای نظرات و دنبالک ها از پنجره های popup استفاده شود؟');
-@define('INSTALL_EMBED', 'آیا Serendipity جاسازی شده است؟');
-@define('INSTALL_EMBED_DESC', 'اگر می خواهید Serendipity را در صفحه ای دیگر جاسازی کنید، مقدار این گزینه را "بله" وارد کنید تا فقط محتویات صفحه چاپ شوند.!');
+@define('INSTALL_POPUP', 'توانایی استفاده از پنجره های بازشونده');
+@define('INSTALL_POPUP_DESC', 'آیا تمایل دارید که برای نظرات و دنبالک ها از پنجره های بازشونده استفاده شود؟');
+@define('INSTALL_EMBED', 'آیا سرندیپیتی جاسازی شده است؟');
+@define('INSTALL_EMBED_DESC', 'اگر می خواهید سرندیپیتی را در صفحه ای دیگر جاسازی کنید، مقدار این گزینه را "بله" وارد کنید تا فقط محتویات صفحه چاپ شوند.!');
 @define('INSTALL_TOP_AS_LINKS', 'نمایش بیشترین بینندگان و بیشترین خروج ها به صورت لینک؟');
 @define('INSTALL_TOP_AS_LINKS_DESC', '"خیر": خروج ها و بازدید ها به صورت متن عادی نمایش داده خواهند شد. "بله": خروج ها و بازدید ها به صورت لینک نمایش داده خواهند شد. "پیش فرض": استفاده از تنظیمات جهانی (این گزینه توصیه می شود).');
 @define('INSTALL_BLOCKREF', 'بازدید کنندگان بلاک شده');
 @define('INSTALL_BLOCKREF_DESC', 'آیا آدرس خاصی وجود دارد که نمی خواهید در لیست بازدید کنندگان نمایش داده شود؟ آدرس ها را با یک علامت \';\' از هم جدا کنید و توجه کنید که آدرس ها توسط روش زیر رشته (substring) حذف خواهند شد!');
 @define('INSTALL_REWRITE', 'دوباره نویسی آدرس ها');
-@define('INSTALL_REWRITE_DESC', 'روش پردازش آدرس ها را مشخص کنید. دادن امکان دوباره نویسی آدرس ها توانایی موتور های جستجو را در فهرست بندی وبلاگ شما بالا می برد. وب سرور شما باید اجازه دسترسی به mod_rewrite یا "AllowOverride All" را برای شاخه Serendipity داده باشد. مقدار پیش فرض "شناسایی خودکار" می باشد');
+@define('INSTALL_REWRITE_DESC', 'روش پردازش آدرس ها را مشخص کنید. دادن امکان دوباره نویسی آدرس ها توانایی موتور های جستجو را در فهرست بندی وبلاگ شما بالا می برد. وب سرور شما باید اجازه دسترسی به mod_rewrite یا "AllowOverride All" را برای شاخه سرندیپیتی داده باشد. مقدار پیش فرض "شناسایی خودکار" می باشد');
 
 /* IMAGECONVERSION SETTINGS */
 @define('INSTALL_CAT_IMAGECONV', 'تنظیمات تغییر عکس');
-@define('INSTALL_CAT_IMAGECONV_DESC', 'اطلاعات کلی برای Serendipity برای چگونگی پردازش تصاویر');
+@define('INSTALL_CAT_IMAGECONV_DESC', 'اطلاعات کلی برای سرندیپیتی برای چگونگی پردازش تصاویر');
 @define('INSTALL_IMAGEMAGICK', 'استفاده از ImageMagick');
 @define('INSTALL_IMAGEMAGICK_DESC', 'آیا شما ImageMagick را نصب کرده اید و آیا می خواهید از آن به عنوان پردازنده تصاویر استفاده کنید؟');
 @define('INSTALL_IMAGEMAGICKPATH', 'مسیر تغییر فایل های باینری');
@@ -434,7 +434,7 @@
 @define('POWERED_BY_SHOW_TEXT', 'نمایش متنی "Serendipity"');
 @define('POWERED_BY_SHOW_TEXT_DESC', 'عبارت "Serendipity Weblog" را به صورت متنی نمایش می دهد');
 @define('POWERED_BY_SHOW_IMAGE', 'نمایش "Serendipity" همراه با یک لوگو');
-@define('POWERED_BY_SHOW_IMAGE_DESC', 'لوگوی Serendipity را نمایش می دهد');
+@define('POWERED_BY_SHOW_IMAGE_DESC', 'لوگوی سرندیپیتی را نمایش می دهد');
 @define('PLUGIN_ITEM_DISPLAY', 'این گزینه کجا نمایش داده شود؟');
 @define('PLUGIN_ITEM_DISPLAY_EXTENDED', 'فقط ارسال های توسعه داده شده');
 @define('PLUGIN_ITEM_DISPLAY_OVERVIEW', 'فقط در صفحه خلاصه');
@@ -543,7 +543,7 @@
 @define('INSTALL_FETCHLIMIT_DESC', 'چه تعداد ارسال در صفحه اصلی نمایش داده شوند');
 @define('IMPORT_ENTRIES', 'وارد کردن داده ها');
 @define('EXPORT_ENTRIES', 'صادر کردن ارسال ها');
-@define('IMPORT_WELCOME', 'به ابزار واردات Serendipity خوش آمدید');
+@define('IMPORT_WELCOME', 'به ابزار واردات سرندیپیتی خوش آمدید');
 @define('IMPORT_WHAT_CAN', 'در این مکان شما می توانید ارسال های سیستم های وبلاگ دیگر را وارد کنید');
 @define('IMPORT_SELECT', 'لطفا نام برنامه ای که می خواهید ارسال هایش را وارد کنید، انتخاب کنید');
 @define('IMPORT_PLEASE_ENTER', 'لطفا داده های خواسته شده را وارد کنید');
@@ -557,9 +557,9 @@
 @define('STATUS', 'وضعیت بعد از واردات');
 @define('IMPORT_GENERIC_RSS', 'وارد کردن RSS های عمومی');
 @define('ACTIVATE_AUTODISCOVERY', 'ارسال دنبالک به لینک های یافت شده در مطلب');
-@define('WELCOME_TO_ADMIN', 'به بخش مدیریت Serendipity خوش آمدید.');
+@define('WELCOME_TO_ADMIN', 'به بخش مدیریت سرندیپیتی خوش آمدید.');
 @define('PLEASE_ENTER_CREDENTIALS', 'لطفا نام کاربری و رمز عبورتان را در فیلد های زیر وارد کنید.');
-@define('ADMIN_FOOTER_POWERED_BY', 'ساخته شده توسط Serendipity %s و PHP %s');
+@define('ADMIN_FOOTER_POWERED_BY', 'ساخته شده توسط سرندیپیتی %s و PHP %s');
 @define('INSTALL_USEGZIP', 'استفاده از صفحات فشرده gzip');
 @define('INSTALL_USEGZIP_DESC', 'برای افزایش سرعت باز شدن صفحات، ما می توانیم صفحات ارسالی به کاربران را فشرده کنیم، این این گزینه بستگی به پشتیبانی کردن مرورگر بیننده نیز دارد. انتخاب این گزینه توصیه می شود');
 @define('INSTALL_SHOWFUTURE', 'نمایش پست های آینده');
@@ -574,13 +574,13 @@
 @define('NOT_WRITABLE', 'نوشتنی نیست');
 @define('PROBLEM_DIAGNOSTIC', 'به دلیل تشخیص مشکل، تا مشکلات فوق را برطرف نسازید نمی توانید به ادامه نصب بپردازید');
 @define('SELECT_INSTALLATION_TYPE', 'انتخاب کنید که چه نوع نصبی را می خواهید انجام دهید');
-@define('WELCOME_TO_INSTALLATION', 'به مراحل نصب Serendipity خوش آمدید');
+@define('WELCOME_TO_INSTALLATION', 'به مراحل نصب سرندیپیتی خوش آمدید');
 @define('FIRST_WE_TAKE_A_LOOK', 'در ابتدا ما گزینه های فعلی را بررسی می کنیم و سعی می کنیم نا همگونی ها را رفع کنیم');
 @define('ERRORS_ARE_DISPLAYED_IN', 'خطا ها در %s نمایش داده شده اند، توصیه ها در %s و موفقیت ها در %s');
 @define('RED', 'قرمز');
 @define('YELLOW', 'زرد');
 @define('GREEN', 'سبز');
-@define('PRE_INSTALLATION_REPORT', 'گزارش قبل از نصب Serendipity نگارش %s');
+@define('PRE_INSTALLATION_REPORT', 'گزارش قبل از نصب سرندیپیتی نگارش %s');
 @define('RECOMMENDED', 'توصیه شده');
 @define('ACTUAL', 'واقعی');
 @define('PHPINI_CONFIGURATION', 'تنظیمات php.ini');
@@ -595,9 +595,9 @@
 @define('CREATING_PRIMARY_AUTHOR', 'ایجاد نویسنده اصلی \'%s\'');
 @define('SETTING_DEFAULT_TEMPLATE', 'تنظیم پوسته پیش فرض');
 @define('INSTALLING_DEFAULT_PLUGINS', 'نصب افزونه های پیش فرض');
-@define('SERENDIPITY_INSTALLED', 'Serendipity با موفقیت نصب شد');
+@define('SERENDIPITY_INSTALLED', 'سرندیپیتی با موفقیت نصب شد');
 @define('VISIT_BLOG_HERE', 'وبلاگ جدید خود را از اینجا ببینید');
-@define('THANK_YOU_FOR_CHOOSING', 'به خاطر نصب Serendipity سپاسگذاریم');
+@define('THANK_YOU_FOR_CHOOSING', 'به خاطر نصب سرندیپیتی سپاسگذاریم');
 @define('ERROR_DETECTED_IN_INSTALL', 'خطایی در زمان نصب تشخیص داده شد');
 @define('OPERATING_SYSTEM', 'سیستم عامل');
 @define('WEBSERVER_SAPI', 'SAPI وب سرور');
@@ -622,9 +622,9 @@
 @define('ADMIN', 'مدیر');
 @define('ADMIN_FRONTPAGE', 'صفحه آغازین');
 @define('QUOTE', 'نقل قول');
-@define('IFRAME_SAVE', 'اکنون Serendipity در حال ساخت پیش نمایش صفحات شما می باشد...');
-@define('IFRAME_SAVE_DRAFT', 'اکنون Serendipity در حال ساخت پیش نمایش صفحات شما می باشد...');
-@define('IFRAME_PREVIEW', 'اکنون Serendipity پیش نمایش ارسال شما را آماده می کند...');
+@define('IFRAME_SAVE', 'اکنون سرندیپیتی در حال ساخت پیش نمایش صفحات شما می باشد...');
+@define('IFRAME_SAVE_DRAFT', 'اکنون سرندیپیتی در حال ساخت پیش نمایش صفحات شما می باشد...');
+@define('IFRAME_PREVIEW', 'اکنون سرندیپیتی پیش نمایش ارسال شما را آماده می کند...');
 @define('IFRAME_WARNING', 'مرورگر شما از iframe پشتیبانی نمی کند. لطفا فایل serendipity_config.inc.php را باز کرده و مقدار $serendipity[\'use_iframe\'] را برابر FALSE قرار دهید.');
 @define('NONE', 'هیچ کدام');
 @define('USERCONF_CAT_DEFAULT_NEW_ENTRY', 'تنظیمات پیش فرض برای ارسال های جدید');
@@ -652,7 +652,7 @@
 @define('AUTOLANG', 'از زبان پیش فرض مرورگر بیننده استفاده شود');
 @define('AUTOLANG_DESC', 'اگر فعال باشد، از زبان مرورگر بیننده برای زبان پیش فرض ورودی ها و زبان پوسته وبلاگ استفاده می شود.');
 @define('INSTALL_AUTODETECT_URL', 'تشخیص خودکار استفاده از HTTP-Host');
-@define('INSTALL_AUTODETECT_URL_DESC', 'اگر روی "بله" تنظیم شود، Serendipity قرار داشتن آدرس BaseURL که در بخش تنظیمات وارد کرده اید را در درخواست ارسالی بررسی می کند. فعال کردن این گزینه، باعث می شود که شما بتوانید از چندین دامنه برای دیدن وبلاگ Serendipity و تمامی لینک های وابسته به آن استفاده کنید.');
+@define('INSTALL_AUTODETECT_URL_DESC', 'اگر روی "بله" تنظیم شود، سرندیپیتی قرار داشتن آدرس BaseURL که در بخش تنظیمات وارد کرده اید را در درخواست ارسالی بررسی می کند. فعال کردن این گزینه، باعث می شود که شما بتوانید از چندین دامنه برای دیدن وبلاگ سرندیپیتی و تمامی لینک های وابسته به آن استفاده کنید.');
 @define('CONVERT_HTMLENTITIES', 'سعی در تغییر مقادیر HTML داشته باشم؟');
 @define('EMPTY_SETTING', 'شما مقدار معتبری برای "%s" انتخاب نکرده اید!');
 @define('USERCONF_REALNAME', 'نام واقعی');
@@ -672,7 +672,7 @@
 @define('CATEGORIES_ALLOW_SELECT_DESC', 'اگر این گزینه فعال باشد، قسمتی برای انتخاب، در کنار هر موضوع در نوار افزونه های کناری اضافه خواهد شد. کاربران می توانند موضوعات مورد نظر را انتخاب کرده تا مطالب ارسالی در موضوعات مشخص شده را مشاهده کنند.');
 @define('PAGE_BROWSE_PLUGINS', 'صفحه %s از %s، در کل %s صفحه.');
 @define('INSTALL_CAT_PERMALINKS', 'لینک های همیشگی');
-@define('INSTALL_CAT_PERMALINKS_DESC', 'قالب های متفاوتی برای لینک های همیشگی تعیین کنید. پیشنهاد می کنیم که از لینک های پیش فرض استفاده کنید; در غیر این صورت، بهتر است از %id% استفاده نمایید، چون امکان دارد از ارسال پرس و جو به پایگاه داده توسط Serendipity برای یافتن آدرس هدف، جلوگیری کند.');
+@define('INSTALL_CAT_PERMALINKS_DESC', 'قالب های متفاوتی برای لینک های همیشگی تعیین کنید. پیشنهاد می کنیم که از لینک های پیش فرض استفاده کنید; در غیر این صورت، بهتر است از %id% استفاده نمایید، چون امکان دارد از ارسال پرس و جو به پایگاه داده توسط سرندیپیتی برای یافتن آدرس هدف، جلوگیری کند.');
 @define('INSTALL_PERMALINK', 'ساختار آدرس همیشگی ارسال ها');
 @define('INSTALL_PERMALINK_DESC', 'در اینجا می توانید ساختار آدرس نسبی، نسبت به آدرس پایه، برای ارسال ها را تعیین کنید. شما می توانید از متغیر های %id%، %title%، %day%، %month%، %year% و هر نوع حرف دیگر استفاده کنید.');
 @define('INSTALL_PERMALINK_AUTHOR', 'ساختار لینک های همیشگی نویسنده');
@@ -691,8 +691,6 @@
 @define('INSTALL_PERMALINK_PLUGINPATH', 'مسیر به صفحه افزونه');
 @define('INSTALL_PERMALINK_ADMINPATH', 'مسیر به صفحه مدیر');
 @define('INSTALL_PERMALINK_SEARCHPATH', 'مسیر به صفحه جستجو');
-@define('USERCONF_CREATE', 'ارسال مطلب ممنوع شود؟');
-@define('USERCONF_CREATE_DESC', 'اگر انتخاب شود، کاربر نمی تواند مطلب جدیدی ارسال کند');
 @define('INSTALL_CAL', 'تقویم');
 @define('INSTALL_CAL_DESC', 'نوع تقویم خود را انتخاب کنید');
 @define('REPLY', 'پاسخ');
@@ -773,7 +771,7 @@
 @define('INSTALL_CHARSET_DESC', 'در اینجا می توانید نوع حروف را بین UTF-8 یا کاراکتر های طبیعی (ISO, EUC, ...) تغییر دهید. بسیاری از زبان ها، فقط به UTF-8 ترجمه شده اند که کاراکتر های "طبیعی" تاثیری روی آنها نمی گذارد. ما به شما UTF-8 را پیشنهاد می کنیم. در صورتی که قبلا ارسالی داشته اید، این گزینه را تغییر ندهید - احتمال مخدوش شدن حروف وجود دارد. در لینک زیر می توانید اطلاعات بیشتری کسب کنید http://www.s9y.org/index.php?node=46 .');
 @define('CALENDAR_ENABLE_EXTERNAL_EVENTS', 'فعال کردن API افزونه چنگکی');
 @define('CALENDAR_EXTEVENT_DESC', 'در صورت فعال بودن، افزونه ها می توانند از تقویم برای نشان دادن وقایع استفاده کنند. این افزونه فقط در حالتی کار می کند که افزونه هایی که آن را لازم دارند، نصب شده باشند در غیر این صورت، فقط کمی قدرت سیستم پایین می آید.');
-@define('XMLRPC_NO_LONGER_BUNDLED', 'افزونه XML-RPC API برای Serendipity به دلیل مشکلات امنیتی، پشتیبانی نمی شود، ضمن اینکه کاربران کمی نیز از آن استفاده می کردند. به هر حال، برای استفاده از XML-RPC API باید افزونه XML-RPC را نصب کنید. آدرس استفاده شده در برنامه تغییر نخواهد کرد - تا زمانی که شما افزونه را نصب دارید، می توانید از API استفاده کنید.');
+@define('XMLRPC_NO_LONGER_BUNDLED', 'افزونه XML-RPC API برای سرندیپیتی به دلیل مشکلات امنیتی، پشتیبانی نمی شود، ضمن اینکه کاربران کمی نیز از آن استفاده می کردند. به هر حال، برای استفاده از XML-RPC API باید افزونه XML-RPC را نصب کنید. آدرس استفاده شده در برنامه تغییر نخواهد کرد - تا زمانی که شما افزونه را نصب دارید، می توانید از API استفاده کنید.');
 @define('PERM_READ', 'دسترسی خواندن');
 @define('PERM_WRITE', 'دسترسی نوشتن');
 
@@ -805,3 +803,98 @@
 @define('CATEGORIES_HIDE_PARENT', 'مخفی کردن موضوع پدری که انتخاب شده است؟');
 @define('CATEGORIES_HIDE_PARENT_DESC', 'اگر شما لیست موضوعات را به موضوع خاصی محدود کرده اید، به طور پیشفرض، آن موضوع را در لیست خروجی مشاهده خواهید کرد. در صورت غیر فعال کردن این گزینه، نام موضوع پدر را نخواهید دید.');
 @define('WARNING_NO_GROUPS_SELECTED', 'هشدار: شما عضو هیچ گروهی نشده اید. پس دیگر نمی توانید از امکانات مدیریت گروه ها استفاده نمایید.');
+@define('INSTALL_RSSFETCHLIMIT', 'مواردی که در بخش خوراک نمایش داده شود');
+@define('INSTALL_RSSFETCHLIMIT_DESC', 'تعداد ارسال هایی که در feed در هر صفحه نمایش داده شود.');
+@define('INSTAL_DB_UTF8', 'فعال کردن تبدیل انکودینگ پایگاه داده');
+@define('INSTAL_DB_UTF8_DESC', 'ارسال دستور "SET NAMES" به MySQL برای تشخیص انکودینگ مناسب برای پایگاه داده. در صورتی که در مشاهده حرف های وبلاگتان مشکل دارید، این گزینه را فعال یا غیر فعال کنید.');
+@define('ONTHEFLYSYNCH', 'فعال کردن سیستم هماهنگی خودکار رسانه ها');
+@define('ONTHEFLYSYNCH_DESC', 'در صورت فعال بودن، سرندیپیتی به صورت خودکار محتویات پایگاه داده و فایل های شما را با هم هماهنگ می کند.');
+@define('USERCONF_CHECK_USERNAME_ERROR', 'نام کاربری نمی تواند خالی باشد.');
+@define('FURTHER_LINKS', 'لینک های کمکی');
+@define('FURTHER_LINKS_S9Y', 'صفحه آغازین سرندیپیتی');
+@define('FURTHER_LINKS_S9Y_DOCS', 'راهنمای سرندیپیتی');
+@define('FURTHER_LINKS_S9Y_BLOG', 'وبلاگ رسمی');
+@define('FURTHER_LINKS_S9Y_FORUMS', 'انجمن ها');
+@define('FURTHER_LINKS_S9Y_SPARTACUS', 'اسپارتاکوس');
+@define('COMMENT_IS_DELETED', '(نظر حذف شد)');
+
+@define('CURRENT_AUTHOR', 'نویسنده فعلی');
+
+@define('WORD_NEW', 'جدید');
+@define('SHOW_MEDIA_TOOLBAR', 'نوار ابزار در صفحهء باز شوندهء رسانه ها نمایش داده شود؟');
+@define('MEDIA_KEYWORDS', 'کلمات کلیدی');
+@define('MEDIA_KEYWORDS_DESC', 'لیستی از کلمات را وارد کنید و در بین کلمات از علامت ";" استفاده کنید.');
+@define('MEDIA_EXIF', 'خواندن اطلاعات EXIF/JPEG تصویر');
+@define('MEDIA_EXIF_DESC', 'در صورت فعال بودن، لیست اطلاعات موجود در EXIF/JPEG تصاویر، برای نمایش داده شدن در بخش گالری، در پایگاه داده ذخیره می شود.');
+@define('MEDIA_PROP', 'اطلاعات رسانه');
+
+
+@define('GO_ADD_PROPERTIES', 'اطلاعات را وارد کن');
+@define('MEDIA_PROPERTY_DPI', 'DPI');
+@define('MEDIA_PROPERTY_COPYRIGHT', 'حق کپی');
+@define('MEDIA_PROPERTY_COMMENT1', 'نظر کوتاه');
+@define('MEDIA_PROPERTY_COMMENT2', 'نظر بلند');
+@define('MEDIA_PROPERTY_TITLE', 'تیتر');
+@define('MEDIA_PROP_DESC', 'لیستی از مشخصات را وارد کرده و هر مشخصه را با ";" جدا کنید');
+@define('MEDIA_PROP_MULTIDESC', '(شما می توانید با افزودن عبارت ":MULTI" بعد از هر گزینه مشخص کنید گه این گزینه شامل متنی طولانی می باشد)');
+
+@define('STYLE_OPTIONS_NONE', 'این پوسته تنظیماتی ندارد. برای تغییر تنظیمات این پوسته، راهنمای تکنیکی مربوط به این بخش رو در سایت www.s9y.org مطالعه کنید.');
+@define('STYLE_OPTIONS', 'انتخابات پوسته');
+
+@define('PLUGIN_AVAILABLE_COUNT', 'تعداد کل: %d افزونه.');
+
+@define('SYNDICATION_RFC2616', 'فعال کردن RSS-Feed طبق استاندارد RFC2616');
+@define('SYNDICATION_RFC2616_DESC', 'NOT Enforcing RFC2616 means that all Conditional GETs to Serendipity will return entries last modified since the time of the last request. With that setting to "false", your visitors will get all articles since their last request, which is considered a good thing. However, some Agents like Planet act weird, if that happens, at it also violates RFC2616. So if you set this option to "TRUE" you will comply with that RFC, but readers of your RSS feed might miss items in their holidays. So either way, either it hearts Aggregators like Planet, or it hurts actual readers of your blog. If you are facing complaints from either side, you can toggle this option. Reference: <a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
+@define('MEDIA_PROPERTY_DATE', 'تاریخ صعودی');
+@define('MEDIA_PROPERTY_RUN_LENGTH', 'طول اجرا');
+@define('FILENAME_REASSIGNED', 'نامگذاری خودکار: %s');
+@define('MEDIA_UPLOAD_SIZE', 'بیشترین حجم فایل ارسالی');
+@define('MEDIA_UPLOAD_SIZE_DESC', 'بیشترین حجم فایل ارسالی را به بایت وارد کنید. این گزینه می تواند توسط متغیر های موجود فایل php.ini بازنویسی شود، مثل: upload_max_filesize، post_max_size، max_input_time. مقدار تهی برای این گزینه به مفهوم تبعیت از انتخاب های موجود در php.ini می باشد.');
+@define('MEDIA_UPLOAD_SIZEERROR', 'خطا: شما نمی توانید فایلی با حجمی بیشتر از %s بایت ارسال کنید!');
+@define('MEDIA_UPLOAD_MAXWIDTH', 'بیشترین طول تصویر');
+@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'بیشترین طول تصویر برای بالاگذاری را بر اساس پیکسل وارد کنید.');
+@define('MEDIA_UPLOAD_MAXHEIGHT', 'بیشترین عرض تصویر');
+@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'بیشترین عرض تصویر برای بالاگذاری را بر اساس پیکسل وارد کنید.');
+@define('MEDIA_UPLOAD_DIMERROR', 'خطا: شما نمی توانید تصویری با  ابعاد بیشتر از %s x %s پیکسل ارسال کنید!');
+
+@define('MEDIA_TARGET', 'هدف این لینک (target)');
+@define('MEDIA_TARGET_JS', 'پنجره بازشونده (از طریق جاوا اسکریپت، با ابعاد مورد نیاز)');
+@define('MEDIA_ENTRY', 'ارسال مجزا شده');
+@define('MEDIA_TARGET_BLANK', 'پنجره بازشونده (از طریق target=_blank)');
+
+@define('MEDIA_DYN_RESIZE', 'اجازه تغییر خودکار تصویر؟');
+@define('MEDIA_DYN_RESIZE_DESC', 'در صورت فعال بودن، ابعاد ارسال شده را برای ابعاد تصویر در نظر گرفته می شود. نتیجهء کار نکهداری می شود، پس شما می توانید آرشیو کامل تری ایجاد کنید.');
+
+@define('MEDIA_DIRECTORY_MOVED', 'شاخه و فایل ها با موفقیت به %s جابجا شدند!');
+@define('MEDIA_DIRECTORY_MOVE_ERROR', 'شاخه و فایل ها نمی توانند به شاخه %s جابجا شوند!');
+@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'در پایگاه داده هایی غیر از MySQL مرور ارسال ها برای تغییر آدرس های قدیمی و تبدیلشون به آدرس های جدید ممکن نیست. و شما باید این عمل را خودتان انجام دهید. در عین حال می توانید آدرس شاخه را به نام قبلی تغییر دهید.');
+@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'آدرس تغییر یافته در %s مطلب های شما پیدا و جایگزین شد.');
+@define('PLUGIN_ACTIVE', 'فعال');
+@define('PLUGIN_INACTIVE', 'غیرفعال');
+@define('PREFERENCE_USE_JS', 'استفاده پیشرفته از جاوا اسکریپت؟');
+@define('PREFERENCE_USE_JS_DESC', 'در صورت فعال بودن قسمت هایی که از جاوا اسکریپت پیشرفته استفاده می کنند فعال می شود، مانند بخش مدیریت افزونه ها که می توانید از drag and drop برای مرتب سازی افزونه ها کمک بگیرید.');
+
+@define('PREFERENCE_USE_JS_WARNING', '(این صفحه از جاوا اسکریپت پیشرفته استفاده می کند. اگر با این صفحه مشکل پیدا کردید، از بخش تنظیمات شخصی، استفاده پیشرفته از جاوا اسکریپت را غیر فعال کنید یا اینکه فعالیت جاوا اسکریپت را داخل مرورگر خود غیر فعال کنید)');
+
+
+@define('INSTALL_PERMALINK_COMMENTSPATH', 'مسیر نظرات');
+@define('PERM_SET_CHILD', 'این سطح دسترسی برای تمامی زیر شاخه ها هم تنظیم شود');
+@define('PERMISSION_FORBIDDEN_PLUGINS', 'افزونه ها ممنوع شده');
+@define('PERMISSION_FORBIDDEN_HOOKS', 'واقعه های ممنوع شده');
+@define('PERMISSION_FORBIDDEN_ENABLE', 'فعال کردن افزونه مدیریت دسترسی ها برای گروه های کاربری؟');
+@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'اگر این گزینه فعال باشد، شما می توانید به گروه های کاربری امکان مشاهده و کار کردن با افزونه های مختلف را ارایه دهید.');
+@define('DELETE_SELECTED_ENTRIES', 'حذف مطالب انتخاب شده');
+@define('PLUGIN_AUTHORS_MINCOUNT', 'به نویسندگان حداقل X مطلب نشان داده شود');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
+@define('IMPORT_WP_PAGES', 'Also fetch attachments and staticpages as normal blog entries?');
+@define('USERCONF_CREATE', 'Disable user / forbid activity?');
+@define('USERCONF_CREATE_DESC', 'If selected, the user will not have any editing or creation possibilities on the blog anymore. When logging in to the backend, he cannot do anything else apart from logging out and viewing his personal configuration.');
+@define('CATEGORY_HIDE_SUB', 'Hide postings made to sub-categories?');
+@define('CATEGORY_HIDE_SUB_DESC', 'By default, when you browse a category also entries of any subcategory are displayed. If this option is turned on, only postings of the currently selected category are displayed.');
+@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
+@define('PINGBACK_SENT', 'Pingback successful');
+@define('PINGBACK_FAILED', 'Pingback failed: %s');
+@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
+@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
+@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
