@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_ja.inc.php 1515 2006-11-22 10:30:13Z garvinhicking $
+<?php # $Id: serendipity_lang_ja.inc.php 2054 2007-12-06 09:26:35Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation (c) Tadashi Jokagi <elf2000@users.sourceforge.net>, 2004-2005.
@@ -26,8 +26,8 @@
 @define('LOGIN', 'ログイン');
 @define('LOGOUT', 'ログアウト');
 @define('LOGGEDOUT', 'ログアウトしました。');
-@define('CREATE', '作成');
-@define('SAVE', '保存');
+@define('CREATE', '作成する');
+@define('SAVE', '保存する');
 @define('NAME', '名前');
 @define('CREATE_NEW_CAT', '新規カテゴリを作成する');
 @define('I_WANT_THUMB', 'エントリ中でサムネイルを使用したい');
@@ -249,7 +249,7 @@
 @define('DATE_INVALID', '警告: 指定した日付は無効です。「YYYY-MM-DD HH:MM」の書式を与えなければなりません。');
 @define('CATEGORY_PLUGIN_DESC', 'カテゴリの一覧を表示します。');
 @define('ALL_AUTHORS', 'すべての執筆者');
-@define('CATEGORIES_TO_FETCH', 'カテゴリを取得');
+@define('CATEGORIES_TO_FETCH', 'カテゴリを取得する');
 @define('CATEGORIES_TO_FETCH_DESC', 'どの執筆者のカテゴリを取得しますか?');
 @define('PAGE_BROWSE_ENTRIES', 'ページ %s/%s, 合計 %s エントリ');
 @define('PREVIOUS_PAGE', '前のページ');
@@ -691,8 +691,6 @@
 @define('INSTALL_PERMALINK_PLUGINPATH', '単一プラグインへのパス');
 @define('INSTALL_PERMALINK_ADMINPATH', '管理へのパス');
 @define('INSTALL_PERMALINK_SEARCHPATH', '検索へのパス');
-@define('USERCONF_CREATE', 'エントリの作成を禁止する');
-@define('USERCONF_CREATE_DESC', '選択した場合、ユーザーは新しいエントリを作成できなくなります。');
 @define('INSTALL_CAL', 'カレンダーの種類');
 @define('INSTALL_CAL_DESC', 'あなたの希望のカレンダーの形式を選びます。');
 @define('REPLY', '返信');
@@ -848,12 +846,12 @@
 @define('PLUGIN_AVAILABLE_COUNT', '合計: %d プラグインです。');
 
 @define('SYNDICATION_RFC2616', '厳密に RFC2616 に準拠した RSS フィードを動作させる');
-@define('SYNDICATION_RFC2616_DESC', 'NOT Enforcing RFC2616 means that all Conditional GETs to Serendipity will return entries last modified since the time of the last request. With that setting to "false", your visitors will get all articles since their last request, which is considered a good thing. However, some Agents like Planet act weird, if that happens, at it also vioaltes RFC2616. So if you set this option to "TRUE" you will compliy with that RFC, but readers of your RSS feed might miss items in their holidays. So either way, either it hearts Aggregators like Planet, or it hurts actual readers of your blog. If you are facing complaints from either side, you can toggle this option. リファレンス: https://sourceforge.net/tracker/index.php?func=detail&aid=1461728&group_id=75065&atid=542822');
+@define('SYNDICATION_RFC2616_DESC', 'NOT Enforcing RFC2616 means that all Conditional GETs to Serendipity will return entries last modified since the time of the last request. With that setting to "false", your visitors will get all articles since their last request, which is considered a good thing. However, some Agents like Planet act weird, if that happens, at it also violates RFC2616. So if you set this option to "TRUE" you will comply with that RFC, but readers of your RSS feed might miss items in their holidays. So either way, either it hearts Aggregators like Planet, or it hurts actual readers of your blog. If you are facing complaints from either side, you can toggle this option. リファレンス: <a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
 @define('MEDIA_PROPERTY_DATE', '関連した日付');
 @define('MEDIA_PROPERTY_RUN_LENGTH', 'Run-Length');
 @define('FILENAME_REASSIGNED', '次の新規ファイル名が自動割当されました: %s');
 @define('MEDIA_UPLOAD_SIZE', 'ファイルアップロードの最大容量');
-@define('MEDIA_UPLOAD_SIZE_DESC', 'Enter the maximum filesize for uploaded files in bytes. This setting can be overruled by server-side settings in PHP.ini: upload_max_filesize, post_max_size, max_input_time all take precedence over this option. An empty string means to only use the server-side limits.');
+@define('MEDIA_UPLOAD_SIZE_DESC', 'バイトでアップロードファイルの最大サイズを入力します。この設定は php.ini のサーバー側設定により上書きされます: upload_max_filesize, post_max_size, max_input_time のすべてはこのオプションを優先します。空文字列はサーバー側の制限のみを使うことを意味します。');
 @define('MEDIA_UPLOAD_SIZEERROR', 'エラー: %s バイトより大きなファイルはアップロードできません!');
 @define('MEDIA_UPLOAD_MAXWIDTH', 'アップロードされたファイルの最大幅');
 @define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'アップロードされた画像の最大幅をピクセル単位で入力します。');
@@ -863,7 +861,7 @@
 
 @define('MEDIA_TARGET', 'このリンクのターゲット');
 @define('MEDIA_TARGET_JS', 'ポップアップウィンドウ (via JavaScript, adaptive size)');
-@define('MEDIA_ENTRY', 'Isolated Entry');
+@define('MEDIA_ENTRY', '単独のエントリ');
 @define('MEDIA_TARGET_BLANK', 'ポップアップウィンドウ (「target=_blank」による)');
 
 @define('MEDIA_DYN_RESIZE', '動的な画像のサイズ変更を許可しますか?');
@@ -872,8 +870,9 @@
 @define('MEDIA_DIRECTORY_MOVED', 'ディレクトリとファイルを「%s」に移動することに成功しました。');
 @define('MEDIA_DIRECTORY_MOVE_ERROR', 'ディレクトリとファイルを「%s」に移動できませんでした!');
 @define('MEDIA_DIRECTORY_MOVE_ENTRY', 'On Non-MySQL databases, iterating through every article to replace the old directory URLs with new directory URLs is not possible. You will need to manually edit your entries to fix new URLs. You can still move your old directory back to where it was, if that is too cumbersome for you.');
-@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Moved the URL of the moved directory in %s entries.');@define('PLUGIN_ACTIVE', 'Active');
-@define('PLUGIN_INACTIVE', 'Inactive');
+@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Moved the URL of the moved directory in %s entries.');
+@define('PLUGIN_ACTIVE', 'アクティブ');
+@define('PLUGIN_INACTIVE', '非アクティブ');
 @define('PREFERENCE_USE_JS', '高度な JS の使用を有効にしますか?');
 @define('PREFERENCE_USE_JS_DESC', 'If enabled, advanced JavaScript sections will be enabled for better usability, like in the Plugin Configuration section you can use drag and drop for re-ordering plugins.');
 
@@ -881,12 +880,23 @@
 
 
 @define('INSTALL_PERMALINK_COMMENTSPATH', 'パスへのコマンド');
-@define('PERM_SET_CHILD', 'Set the same permissions on all child directories');
-@define('PERMISSION_FORBIDDEN_PLUGINS', 'Forbidden plugins');
-@define('PERMISSION_FORBIDDEN_HOOKS', 'Forbidden events');
-@define('PERMISSION_FORBIDDEN_ENABLE', 'Enable Plugin ACL for usergroups?');
+@define('PERM_SET_CHILD', 'すべての子ディレクトリに同じパーミッションを設定する');
+@define('PERMISSION_FORBIDDEN_PLUGINS', '禁止プラグイン');
+@define('PERMISSION_FORBIDDEN_HOOKS', '禁止イベント');
+@define('PERMISSION_FORBIDDEN_ENABLE', 'ユーザーグループ用の ACL プラグインを有効にしますか?');
 @define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'If the option "Plugin ACL for usergroups" is enabled in the configuration, you can specify which usergroups are allowed to execute certain plugins/events.');
-@define('DELETE_SELECTED_ENTRIES', 'Delete selected entries');
+@define('DELETE_SELECTED_ENTRIES', '選択したエントリを削除する');
 @define('PLUGIN_AUTHORS_MINCOUNT', 'Show only authors with at least X articles');
-@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'ブックマークレット');
 @define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
+@define('IMPORT_WP_PAGES', 'Also fetch attachments and staticpages as normal blog entries?');
+@define('USERCONF_CREATE', 'Disable user / forbid activity?');
+@define('USERCONF_CREATE_DESC', 'If selected, the user will not have any editing or creation possibilities on the blog anymore. When logging in to the backend, he cannot do anything else apart from logging out and viewing his personal configuration.');
+@define('CATEGORY_HIDE_SUB', 'Hide postings made to sub-categories?');
+@define('CATEGORY_HIDE_SUB_DESC', 'By default, when you browse a category also entries of any subcategory are displayed. If this option is turned on, only postings of the currently selected category are displayed.');
+@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
+@define('PINGBACK_SENT', 'Pingback successful');
+@define('PINGBACK_FAILED', 'Pingback failed: %s');
+@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
+@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
+@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
