@@ -9,7 +9,7 @@
 
 @define('LANG_CHARSET', 'ISO-8859-1');
 @define('SQL_CHARSET', 'latin1');
-@define('DATE_LOCALES', 'pt_PT-ISO-8859-1, pt_PT-ISO8859-1, pt, pt_PT, european portuguese');
+@define('DATE_LOCALES', 'pt_PT.ISO-8859-1, pt_PT.ISO8859-1, pt, pt_PT, european portuguese');
 @define('DATE_FORMAT_ENTRY', '%A, %e de %B de %Y');
 @define('DATE_FORMAT_SHORT', '%Y-%m-%d %H:%M');
 @define('WYSIWYG_LANG', 'pt_pt');
@@ -98,7 +98,7 @@
 @define('SEARCH_FOR_ENTRY', 'Procure um artigo');
 @define('ARCHIVES', 'Arquivos');
 @define('BROWSE_ARCHIVES', 'Navegar nos arquivos por ms');
-@define('TOP_REFERRER', 'Referidores mais importantes');
+@define('TOP_REFERRER', 'Referenciadores mais importantes');
 @define('SHOWS_TOP_SITES', 'Exibe os links de entrada mais utilizados para aceder no seu blogue');
 @define('TOP_EXITS', 'Sadas Maiores');
 @define('SHOWS_TOP_EXIT', 'Exibe os links de sada mais requisitados de seu blogue');
@@ -304,7 +304,7 @@
 @define('DIRECTORY_CREATED', 'Directoria <strong>%s</strong> foi criada.');
 @define('PARENT_DIRECTORY', 'Directoria superior');
 @define('CONFIRM_DELETE_DIRECTORY', 'Tem a certeza que quer apagar todo o contedo da directoria %s?');
-@define('ERROR_NO_DIRECTORY', 'Erro: A Directoria %s no existente');
+@define('ERROR_NO_DIRECTORY', 'Erro: A Directoria %s no existe');
 @define('CHECKING_DIRECTORY', 'Verificando arquivos na directoria %s');
 @define('DELETING_FILE', 'Apagando ficheiro %s...');
 @define('ERROR_DIRECTORY_NOT_EMPTY', 'No foi possvel remover uma directoria que no est vazia. Marque a opo "forar apagar" se tambm deseja remover os ficheiros nela contidos, e volte a dar o comando. Os ficheiros existentes so:');
@@ -700,8 +700,6 @@
 @define('INSTALL_PERMALINK_PLUGINPATH', 'Caminho para plugin nico'); //Verify
 @define('INSTALL_PERMALINK_ADMINPATH', 'Caminho para Administrao');
 @define('INSTALL_PERMALINK_SEARCHPATH', 'Caminho para a pesquisa'); //Verify
-@define('USERCONF_CREATE', 'Proibir criar entradas?');
-@define('USERCONF_CREATE_DESC', 'Se seleccionado, o utilizador no pode criar novas entradas');
 @define('INSTALL_CAL', 'Gnero de calendrio');
 @define('INSTALL_CAL_DESC', 'Escolha o formato de calendrio desejado');
 @define('REPLY', 'Responder');
@@ -856,7 +854,7 @@
 @define('PLUGIN_AVAILABLE_COUNT', 'Total: %d plugins.');
 
 @define('SYNDICATION_RFC2616', 'Activar obedincia estrita ao RFC2616 RSS-Feed');
-@define('SYNDICATION_RFC2616_DESC', 'NO forar o RFC2616 significa que todos os "Conditional GETs" pelo Serendipity iro devolver as ltimas entradas modificadas deste o seu ltimo pedido. Uma vez colocada a configurao como "false", os seus visitantes iro obter todos os artigos no seu ltimo pedido, o que  um bom resultado. No entanto, alguns Agentes tal como Planet iro agir de forma estranha, se tal acontecer, violando tambm o RFC2616. Se colocar esta opo como "TRUE", voc ir cumprir aquele RFC, mas os leitores do seu RSS Feed talvez percam alguns itens durante as frias. De qualquer forma, ou adora Agredadores como o Planet, ou fere os leitores actuais do seu Blogue. Se voc est a enfrentar queixas de ambos os lados, poder alterar esta opo. Referncia: https://sourceforge.net/tracker/index.php?func=detail&aid=1461728&group_id=75065&atid=542822');
+@define('SYNDICATION_RFC2616_DESC', 'NO forar o RFC2616 significa que todos os "Conditional GETs" pelo Serendipity iro devolver as ltimas entradas modificadas deste o seu ltimo pedido. Uma vez colocada a configurao como "false", os seus visitantes iro obter todos os artigos no seu ltimo pedido, o que  um bom resultado. No entanto, alguns Agentes tal como Planet iro agir de forma estranha, se tal acontecer, violando tambm o RFC2616. Se colocar esta opo como "TRUE", voc ir cumprir aquele RFC, mas os leitores do seu RSS Feed talvez percam alguns itens durante as frias. De qualquer forma, ou adora Agredadores como o Planet, ou fere os leitores actuais do seu Blogue. Se voc est a enfrentar queixas de ambos os lados, poder alterar esta opo. Referncia: <a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
 @define('MEDIA_PROPERTY_DATE', 'Data Associada');
 @define('MEDIA_PROPERTY_RUN_LENGTH', 'Comprimento');
 @define('FILENAME_REASSIGNED', 'Associa um novo ficheiro automaticamente: %s');
@@ -899,3 +897,14 @@
 @define('PLUGIN_AUTHORS_MINCOUNT', 'Mostar apenas Autores com um mnimo de X artigos');
 @define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
 @define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Marque esta ligao e use-a em qualquer pgina em que quiser blogar para aceder rapidamente ao seu blogue Serendipity.');
+@define('IMPORT_WP_PAGES', 'Ir tambm buscar ficheiros anexados e pginas estticas como entradas de blog normais?');
+@define('USERCONF_CREATE', 'Disable user / forbid activity?');
+@define('USERCONF_CREATE_DESC', 'If selected, the user will not have any editing or creation possibilities on the blog anymore. When logging in to the backend, he cannot do anything else apart from logging out and viewing his personal configuration.');
+@define('CATEGORY_HIDE_SUB', 'Hide postings made to sub-categories?');
+@define('CATEGORY_HIDE_SUB_DESC', 'By default, when you browse a category also entries of any subcategory are displayed. If this option is turned on, only postings of the currently selected category are displayed.');
+@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
+@define('PINGBACK_SENT', 'Pingback successful');
+@define('PINGBACK_FAILED', 'Pingback failed: %s');
+@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
+@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
+@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
