@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_tn.inc.php 1251 2006-06-09 20:16:09Z garvinhicking $
+<?php # $Id: serendipity_lang_tn.inc.php 2054 2007-12-06 09:26:35Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translated by CapriSkye <admin@capriskye.com>
@@ -693,8 +693,6 @@ $i18n_unknown = 'tw';
 @define('INSTALL_PERMALINK_PLUGINPATH', '單外掛路徑');
 @define('INSTALL_PERMALINK_ADMINPATH', '管理路徑');
 @define('INSTALL_PERMALINK_SEARCHPATH', '搜尋路徑');
-@define('USERCONF_CREATE', '不允許新增文章？');
-@define('USERCONF_CREATE_DESC', '如果選擇，作者將不能發佈新文章。');
 @define('INSTALL_CAL', '日曆類型');
 @define('INSTALL_CAL_DESC', '請選擇您要的日曆類型');
 @define('REPLY', '回覆');
@@ -806,4 +804,99 @@ $i18n_unknown = 'tw';
 @define('INSTALL_TRACKREF_DESC', '開啟記錄來源會顯示哪個網站引用了您的文章。您可以關閉這個功能如果收到太多垃圾廣告。');
 @define('CATEGORIES_HIDE_PARENT', '隱藏選擇的類別？');
 @define('CATEGORIES_HIDE_PARENT_DESC', '當您限制類別顯示的列表，預設是會顯示母類別的名稱。如果您關閉這個功能，母類別的名稱將不會顯示。');
-@define('WARNING_NO_GROUPS_SELECTED', '警告：您沒有選擇會員群組。這會將您登出群組的管理，會員的群組不會被改變。');
\ No newline at end of file
+@define('WARNING_NO_GROUPS_SELECTED', '警告：您沒有選擇會員群組。這會將您登出群組的管理，會員的群組不會被改變。');
+@define('INSTALL_RSSFETCHLIMIT', 'Entries to display in Feeds');
+@define('INSTALL_RSSFETCHLIMIT_DESC', 'RSS Feed 頁面裡顯示的文章數量。');
+@define('INSTAL_DB_UTF8', '開啟資料庫的編碼轉換');
+@define('INSTAL_DB_UTF8_DESC', '使用 MySQL 的 "SET NAMES" 查詢來設定編碼。如果文章出現亂碼可以將這個設定打開或關閉。');
+@define('ONTHEFLYSYNCH', '開啟即時的媒體同步');
+@define('ONTHEFLYSYNCH_DESC', '如果開啟，Serendipity 會比較資料庫和媒體目錄內的檔案，然後進行資料同步。');
+@define('USERCONF_CHECK_USERNAME_ERROR', '帳號不能空白。');
+@define('FURTHER_LINKS', '更多連結');
+@define('FURTHER_LINKS_S9Y', 'Serendipity 首頁');
+@define('FURTHER_LINKS_S9Y_DOCS', 'Serendipity 說明文件');
+@define('FURTHER_LINKS_S9Y_BLOG', '官方網誌');
+@define('FURTHER_LINKS_S9Y_FORUMS', '論壇');
+@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
+@define('COMMENT_IS_DELETED', '(迴響已被移除)');
+
+@define('CURRENT_AUTHOR', '目前的作者');
+
+@define('WORD_NEW', '新');
+@define('SHOW_MEDIA_TOOLBAR', '在選擇媒體的視窗裡顯示工具欄？');
+@define('MEDIA_KEYWORDS', '媒體的關鍵字');
+@define('MEDIA_KEYWORDS_DESC', '輸入預設的媒體關鍵字，用 ";" 來分開每個關鍵字。');
+@define('MEDIA_EXIF', '輸入 EXIF/JPEG 圖片資料');
+@define('MEDIA_EXIF_DESC', '如果開啟，EXIF/JPEG 圖檔裡的 metadata 會自動儲存到資料庫。');
+@define('MEDIA_PROP', '媒體內容');
+
+
+@define('GO_ADD_PROPERTIES', '輸入內容');
+@define('MEDIA_PROPERTY_DPI', 'DPI');
+@define('MEDIA_PROPERTY_COPYRIGHT', '版權');
+@define('MEDIA_PROPERTY_COMMENT1', '短介紹');
+@define('MEDIA_PROPERTY_COMMENT2', '長介紹');
+@define('MEDIA_PROPERTY_TITLE', '標題');
+@define('MEDIA_PROP_DESC', '輸入媒體使用的內容欄位，用 ";" 來分開每個欄位的名稱');
+@define('MEDIA_PROP_MULTIDESC', '(您可以在名稱後面加上 ":MULTI" 來設定加大它的文字限制)');
+
+@define('STYLE_OPTIONS_NONE', '這個佈景沒有特別的選項。如果要在您的佈景裡加上選項，請看 www.s9y.org 內的 Technical Documentation，然後 "Configuration of Theme options"。');
+@define('STYLE_OPTIONS', '佈景選項');
+
+@define('PLUGIN_AVAILABLE_COUNT', '總共： %d 個外掛。');
+
+@define('SYNDICATION_RFC2616', '開啟依照嚴格的 RFC2616 RSS-Feed');
+@define('SYNDICATION_RFC2616_DESC', '不強制 RFC2616 表示全部有條件的 GETs 到 Serendipity 只會傳回最後修改的文章。如果設定為 "false" 表示訪客會接收全部的文章。不過，一些網誌的蒐集軟體像 Planet 會出現奇怪現象。如果出現奇怪現象表示它違反了 RFC2616 的標準。所以設定為 "TRUE" 表示你遵從 RFC 的標準，但是訪客可能會讀取不到全部的文章。整體來說，不管怎樣都無法顧到兩方。相關資訊：<a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
+@define('MEDIA_PROPERTY_DATE', '相關日期');
+@define('MEDIA_PROPERTY_RUN_LENGTH', '長度');
+@define('FILENAME_REASSIGNED', '自動指定新檔案的名稱： %s');
+@define('MEDIA_UPLOAD_SIZE', '檔案大小的上限');
+@define('MEDIA_UPLOAD_SIZE_DESC', '輸入檔案的最大值。這個設定也可以從主機內的 PHP.ini 檔案改變： upload_max_filesize, post_max_size, max_input_time 全部都能讓這裡的設定無效。如果不輸入表示遵從主機的限制。');
+@define('MEDIA_UPLOAD_SIZEERROR', '錯誤：您不能上傳大於 %s 位元組的檔案！');
+@define('MEDIA_UPLOAD_MAXWIDTH', '圖片的最大寬度');
+@define('MEDIA_UPLOAD_MAXWIDTH_DESC', '輸入上傳的圖片的最大寬度。');
+@define('MEDIA_UPLOAD_MAXHEIGHT', '圖片的最大長度');
+@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', '輸入上傳的圖片的最大長度。');
+@define('MEDIA_UPLOAD_DIMERROR', '錯誤：您不能上傳大於 %s x %s 的圖片！');
+
+@define('MEDIA_TARGET', '連結的目標');
+@define('MEDIA_TARGET_JS', '彈出視窗 (使用 JavaScript)');
+@define('MEDIA_ENTRY', '隔離文章');
+@define('MEDIA_TARGET_BLANK', '彈出視窗 (使用 target=_blank)');
+
+@define('MEDIA_DYN_RESIZE', '允許改變圖片大小？');
+@define('MEDIA_DYN_RESIZE_DESC', '如果開啟，媒體的選擇視窗裡會顯示依照 GET 變數所設定的圖片大小。圖片會儲存於快取的記憶體內，所以常使用會佔用主機的空間。');
+
+@define('MEDIA_DIRECTORY_MOVED', '目錄和檔案已成功移動到 %s');
+@define('MEDIA_DIRECTORY_MOVE_ERROR', '目錄和檔案無法移動到 %s！');
+@define('MEDIA_DIRECTORY_MOVE_ENTRY', '在非 MySQL 資料庫內，無法移動文章到新的目錄。您需要自己修改文章的網址。您還是可以將舊目錄回覆到原來的位址。');
+@define('MEDIA_DIRECTORY_MOVE_ENTRIES', '移動 %s 篇文章的網誌到新的目錄。');
+@define('PLUGIN_ACTIVE', '開啟');
+@define('PLUGIN_INACTIVE', '關閉');
+@define('PREFERENCE_USE_JS', '開啟進階的 JS 用法？');
+@define('PREFERENCE_USE_JS_DESC', '如果開啟，進階的 JavaScript 將會提供更好的用途，例如類似外掛設定內的牽曳和移動功能。');
+
+@define('PREFERENCE_USE_JS_WARNING', '(這個頁面使用了進階的 JavaScript。如果您遇到問題，請將進階的 JS 用法或瀏覽器的 JavaScript 關閉。)');
+
+
+@define('INSTALL_PERMALINK_COMMENTSPATH', '留言的路徑');
+@define('PERM_SET_CHILD', '將全部的子目錄設為相同權限');
+@define('PERMISSION_FORBIDDEN_PLUGINS', '禁用外掛');
+@define('PERMISSION_FORBIDDEN_HOOKS', '禁用事件');
+@define('PERMISSION_FORBIDDEN_ENABLE', '開啟外掛 ACL 給會員群組？');
+@define('PERMISSION_FORBIDDEN_ENABLE_DESC', '如果 "外掛 ACL 給會員群組" 是開啟的狀態，您可以指定某些群組來執行外掛和事件。');
+@define('DELETE_SELECTED_ENTRIES', '刪除選擇的文章');
+@define('PLUGIN_AUTHORS_MINCOUNT', '顯示多於 X 文章的作者');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET', '書籤');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', '將這個連結設為書籤可以讓您快速的進入網誌。');
+@define('IMPORT_WP_PAGES', '輸入附件檔案和靜態頁面於普通的網誌文章？');
+@define('USERCONF_CREATE', '禁止會員／禁止動作？');
+@define('USERCONF_CREATE_DESC', '如果勾選，此會員將被禁止任何編輯或新增網誌的動作。如果登入後端，他被允許的動作只有登入／登出和瀏覽自己的設定。');
+@define('CATEGORY_HIDE_SUB', '隱藏子類別的文章？');
+@define('CATEGORY_HIDE_SUB_DESC', '預設的狀態是當您瀏覽目錄時，子目錄的文章也會顯示。如果勾選此設定，只會顯示瀏覽的目錄內的文章。');
+@define('PINGBACK_SENDING', '傳送回測到網頁 %s...');
+@define('PINGBACK_SENT', '回測完成');
+@define('PINGBACK_FAILED', '回測失敗： %s');
+@define('PINGBACK_NOT_FOUND', '沒有回測的網頁。');
+@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', '隱藏歷史的連接如果時間內沒有文章 (需要計算文章數)');
+@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
