@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_tw.inc.php 1515 2006-11-22 10:30:13Z garvinhicking $
+<?php # $Id: serendipity_lang_tw.inc.php 2054 2007-12-06 09:26:35Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translated by CapriSkye <admin@capriskye.com>
@@ -693,8 +693,6 @@ $i18n_unknown = 'tw';
 @define('INSTALL_PERMALINK_PLUGINPATH', '~|');
 @define('INSTALL_PERMALINK_ADMINPATH', '޲z|');
 @define('INSTALL_PERMALINK_SEARCHPATH', 'jM|');
-@define('USERCONF_CREATE', '\sW峹H');
-@define('USERCONF_CREATE_DESC', 'pGܡA@̱NoGs峹C');
 @define('INSTALL_CAL', '');
 @define('INSTALL_CAL_DESC', 'пܱzn');
 @define('REPLY', '^');
@@ -849,7 +847,7 @@ $i18n_unknown = 'tw';
 @define('PLUGIN_AVAILABLE_COUNT', '`@G %d ӥ~C');
 
 @define('SYNDICATION_RFC2616', '}Ҩ̷Y檺 RFC2616 RSS-Feed');
-@define('SYNDICATION_RFC2616_DESC', 'j RFC2616 ܥ GETs  Serendipity u|Ǧ^̫ק諸峹CpG]w "false" ܳXȷ|峹CLA@Ǻx`n鹳 Planet |X{_ǲ{HCpGX{_ǲ{HܥHϤF RFC2616 зǡCҥH]w "TRUE" ܧAq RFC зǡAOXȥi|Ū峹CӻAޫ˳LkUCTGhttps://sourceforge.net/tracker/index.php?func=detail&aid=1461728&group_id=75065&atid=542822');
+@define('SYNDICATION_RFC2616_DESC', 'j RFC2616 ܥ GETs  Serendipity u|Ǧ^̫ק諸峹CpG]w "false" ܳXȷ|峹CLA@Ǻx`n鹳 Planet |X{_ǲ{HCpGX{_ǲ{HܥHϤF RFC2616 зǡCҥH]w "TRUE" ܧAq RFC зǡAOXȥi|Ū峹CӻAޫ˳LkUCTG<a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
 @define('MEDIA_PROPERTY_DATE', '');
 @define('MEDIA_PROPERTY_RUN_LENGTH', '');
 @define('FILENAME_REASSIGNED', '۰ʫwsɮתW١G %s');
@@ -869,25 +867,37 @@ $i18n_unknown = 'tw';
 
 @define('MEDIA_DYN_RESIZE', '\ܹϤjpH');
 @define('MEDIA_DYN_RESIZE_DESC', 'pG}ҡAC骺̷ܵ|ܨ̷ GET ܼƩҳ]wϤjpCϤ|xs֨O餺AҥH`ϥη|ΥDŶC');
-@define('MEDIA_DIRECTORY_MOVED', 'Directory and files were successfully moved to %s');
-@define('MEDIA_DIRECTORY_MOVE_ERROR', 'Directory and files could not be moved to %s!');
-@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'On Non-MySQL databases, iterating through every article to replace the old directory URLs with new directory URLs is not possible. You will need to manually edit your entries to fix new URLs. You can still move your old directory back to where it was, if that is too cumbersome for you.');
-@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Moved the URL of the moved directory in %s entries.');
-@define('PLUGIN_ACTIVE', 'Active');
-@define('PLUGIN_INACTIVE', 'Inactive');
-@define('PREFERENCE_USE_JS', 'Enable advanced JS usage?');
-@define('PREFERENCE_USE_JS_DESC', 'If enabled, advanced JavaScript sections will be enabled for better usability, like in the Plugin Configuration section you can use drag and drop for re-ordering plugins.');
 
-@define('PREFERENCE_USE_JS_WARNING', '(This page uses advanced JavaScripting. If you are having functionality issues, please disable the use of advanced JS usage in your personal preferences or disable your browser\'s JavaScript)');
+@define('MEDIA_DIRECTORY_MOVED', 'ؿMɮפw\ʨ %s');
+@define('MEDIA_DIRECTORY_MOVE_ERROR', 'ؿMɮ׵Lkʨ %sI');
+@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'bD MySQL ƮwALkʤ峹sؿCzݭnۤvק峹}Cz٬OiHN¥ؿ^ШӪ}C');
+@define('MEDIA_DIRECTORY_MOVE_ENTRIES', ' %s g峹xsؿC');
+@define('PLUGIN_ACTIVE', '}');
+@define('PLUGIN_INACTIVE', '');
+@define('PREFERENCE_USE_JS', '}Ҷi JS ΪkH');
+@define('PREFERENCE_USE_JS_DESC', 'pG}ҡAi JavaScript N|ѧnγ~AҦp~]woMʥ\C');
+
+@define('PREFERENCE_USE_JS_WARNING', '(oӭϥΤFi JavaScriptCpGzJDAбNi JS Ϊks JavaScript C)');
 
 
-@define('INSTALL_PERMALINK_COMMENTSPATH', 'Path to comments');
-@define('PERM_SET_CHILD', 'Set the same permissions on all child directories');
-@define('PERMISSION_FORBIDDEN_PLUGINS', 'Forbidden plugins');
-@define('PERMISSION_FORBIDDEN_HOOKS', 'Forbidden events');
-@define('PERMISSION_FORBIDDEN_ENABLE', 'Enable Plugin ACL for usergroups?');
-@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'If the option "Plugin ACL for usergroups" is enabled in the configuration, you can specify which usergroups are allowed to execute certain plugins/events.');
-@define('DELETE_SELECTED_ENTRIES', 'Delete selected entries');
-@define('PLUGIN_AUTHORS_MINCOUNT', 'Show only authors with at least X articles');
-@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
-@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
+@define('INSTALL_PERMALINK_COMMENTSPATH', 'd|');
+@define('PERM_SET_CHILD', 'Nlؿ]ۦPv');
+@define('PERMISSION_FORBIDDEN_PLUGINS', 'TΥ~');
+@define('PERMISSION_FORBIDDEN_HOOKS', 'TΨƥ');
+@define('PERMISSION_FORBIDDEN_ENABLE', '}ҥ~ ACL |sաH');
+@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'pG "~ ACL |s" O}ҪAAziHwYǸsըӰ~MƥC');
+@define('DELETE_SELECTED_ENTRIES', 'Rܪ峹');
+@define('PLUGIN_AUTHORS_MINCOUNT', 'ܦh X 峹@');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET', '');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Noӳs]ҥiHzֳtiJxC');
+@define('IMPORT_WP_PAGES', 'JɮשMRA󴶳qx峹H');
+@define('USERCONF_CREATE', 'T|Tʧ@H');
+@define('USERCONF_CREATE_DESC', 'pGĿA|NQTsηsWxʧ@CpGnJݡALQ\ʧ@unJnXMsۤv]wC');
+@define('CATEGORY_HIDE_SUB', 'älO峹H');
+@define('CATEGORY_HIDE_SUB_DESC', 'w]AOzsؿɡAlؿ峹]|ܡCpGĿ惡]wAu|sؿ峹C');
+@define('PINGBACK_SENDING', 'ǰe^ %s...');
+@define('PINGBACK_SENT', '^');
+@define('PINGBACK_FAILED', '^ѡG %s');
+@define('PINGBACK_NOT_FOUND', 'S^C');
+@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'þvspGɶS峹 (ݭnp峹)');
+@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
