@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_zh.inc.php 1515 2006-11-22 10:30:13Z garvinhicking $
+<?php # $Id: serendipity_lang_zh.inc.php 2054 2007-12-06 09:26:35Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translated by
@@ -220,7 +220,7 @@
 @define('NEW_COMMENT_TO_SUBSCRIBED_ENTRY', '»ظĵ "%s"');
 @define('SUBSCRIPTION_MAIL', " %s,\n\n㶩ĵµĻظ \"%s\",  \"%s\"\nظķ: %s\n\nҵ: %s\n\nԵȡ: %s\n");
 @define('SUBSCRIPTION_TRACKBACK_MAIL', " %s,\n\n㶩ĵµ \"%s\",  \"%s\"\nõ: %s\n\nҵ: %s\n\nԵȡ: %s\n");
-@define('SIGNATURE', "\n-- \n%s is powered by Serendipity.\n õ־, ϣϲ.\n  <http://www.cexten.com> õ֧...");
+@define('SIGNATURE', "\n-- \n%s is powered by Serendipity.\n <http://www.s9y.org>");
 @define('SYNDICATION_PLUGIN_091', 'RSS 0.91 feed');
 @define('SYNDICATION_PLUGIN_10', 'RSS 1.0 feed');
 @define('SYNDICATION_PLUGIN_20', 'RSS 2.0 feed');
@@ -693,8 +693,6 @@
 @define('INSTALL_PERMALINK_PLUGINPATH', '·');
 @define('INSTALL_PERMALINK_ADMINPATH', '·');
 @define('INSTALL_PERMALINK_SEARCHPATH', '·');
-@define('USERCONF_CREATE', '');
-@define('USERCONF_CREATE_DESC', 'ѡ߽ܷ¡');
 @define('INSTALL_CAL', '');
 @define('INSTALL_CAL_DESC', 'ѡҪ');
 @define('REPLY', 'ظ');
@@ -848,7 +846,7 @@
 @define('PLUGIN_AVAILABLE_COUNT', 'ܹ %d ');
 
 @define('SYNDICATION_RFC2616', 'ϸ RFC2616 RSS-Feed');
-@define('SYNDICATION_RFC2616_DESC', 'ǿ RFC2616 ʾȫ GETs  Serendipity Blog ֻᴫ޸ĵ¡趨Ϊ "false" ʾÿͽȫ¡һЩ־ĳ Planet ʾΥ RFC2616 ı׼趨Ϊ "TRUE" ʾ RFC ı׼ÿͿܶȡȫ¡˵޷չ˵ģhttps://sourceforge.net/tracker/index.php?func=detail&aid=1461728&group_id=75065&atid=542822');
+@define('SYNDICATION_RFC2616_DESC', 'ǿ RFC2616 ʾȫ GETs  Serendipity Blog ֻᴫ޸ĵ¡趨Ϊ "false" ʾÿͽȫ¡һЩ־ĳ Planet ʾΥ RFC2616 ı׼趨Ϊ "TRUE" ʾ RFC ı׼ÿͿܶȡȫ¡˵޷չ˵ģ<a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
 @define('MEDIA_PROPERTY_DATE', '');
 @define('MEDIA_PROPERTY_RUN_LENGTH', '');
 @define('FILENAME_REASSIGNED', 'Զָļƣ %s');
@@ -888,3 +886,14 @@
 @define('PLUGIN_AUTHORS_MINCOUNT', 'Show only authors with at least X articles');
 @define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
 @define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
+@define('IMPORT_WP_PAGES', 'Also fetch attachments and staticpages as normal blog entries?');
+@define('USERCONF_CREATE', 'Disable user / forbid activity?');
+@define('USERCONF_CREATE_DESC', 'If selected, the user will not have any editing or creation possibilities on the blog anymore. When logging in to the backend, he cannot do anything else apart from logging out and viewing his personal configuration.');
+@define('CATEGORY_HIDE_SUB', 'Hide postings made to sub-categories?');
+@define('CATEGORY_HIDE_SUB_DESC', 'By default, when you browse a category also entries of any subcategory are displayed. If this option is turned on, only postings of the currently selected category are displayed.');
+@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
+@define('PINGBACK_SENT', 'Pingback successful');
+@define('PINGBACK_FAILED', 'Pingback failed: %s');
+@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
+@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
+@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
