@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_event_emoticate.php 1528 2006-12-01 08:58:47Z garvinhicking $
+<?php # $Id: serendipity_event_emoticate.php 1847 2007-08-14 11:57:51Z brockhaus $
 
 if (IN_serendipity !== true) {
     die ("Don't hack!");
@@ -25,7 +25,7 @@ class serendipity_event_emoticate extends serendipity_event
         $propbag->add('description',   PLUGIN_EVENT_EMOTICATE_DESC);
         $propbag->add('stackable',     false);
         $propbag->add('author',        'Serendipity Team');
-        $propbag->add('version',       '1.4');
+        $propbag->add('version',       '1.6');
         $propbag->add('requirements',  array(
             'serendipity' => '0.8',
             'smarty'      => '2.6.7',
@@ -98,23 +98,23 @@ class serendipity_event_emoticate extends serendipity_event
         if (!isset($this->smilies)) {
             $ext = $this->get_config('extension', 'png');
             $this->smilies = array(
-                "\:'\("    => serendipity_getTemplateFile('img/emoticons/cry.'.$ext),
+                "\:'\("     => serendipity_getTemplateFile('img/emoticons/cry.'.$ext),
 
-                '\:\-?\)'  => serendipity_getTemplateFile('img/emoticons/smile.'.$ext),
+                '\:\-?\)'   => serendipity_getTemplateFile('img/emoticons/smile.'.$ext),
 
-                '\:\|'     => serendipity_getTemplateFile('img/emoticons/normal.'.$ext),
+                '\:\-?\|'   => serendipity_getTemplateFile('img/emoticons/normal.'.$ext),
 
-                '\:\-?O'  => serendipity_getTemplateFile('img/emoticons/eek.'.$ext),
+                '\:\-?O'    => serendipity_getTemplateFile('img/emoticons/eek.'.$ext),
 
-                '\:\-?\('  => serendipity_getTemplateFile('img/emoticons/sad.'.$ext),
+                '\:\-?\('   => serendipity_getTemplateFile('img/emoticons/sad.'.$ext),
 
-                '8\-?\)'  => serendipity_getTemplateFile('img/emoticons/cool.'.$ext),
+                '8\-?\)'    => serendipity_getTemplateFile('img/emoticons/cool.'.$ext),
 
-                '\:\-?D'  => serendipity_getTemplateFile('img/emoticons/laugh.'.$ext),
+                '\:\-?D'    => serendipity_getTemplateFile('img/emoticons/laugh.'.$ext),
 
-                '\:\-?P'  => serendipity_getTemplateFile('img/emoticons/tongue.'.$ext),
+                '\:\-?P'    => serendipity_getTemplateFile('img/emoticons/tongue.'.$ext),
 
-                ';\-?\)'  => serendipity_getTemplateFile('img/emoticons/wink.'.$ext),
+                ';\-?\)'    => serendipity_getTemplateFile('img/emoticons/wink.'.$ext),
             );
         }
 
@@ -177,7 +177,7 @@ class serendipity_event_emoticate extends serendipity_event
                             $element = &$eventData[$temp['element']];
 
                             foreach ($this->getEmoticons() as $key => $value) {
-                                $element = preg_replace("/([\t\s\.\!>]+)" . $key . "([\t\s\!\.\)<]+|\$)/U",
+                                $element = preg_replace("/([\t\s\.\!>]+|^)" . $key . "([\t\s\!\.\)<]+|\$)/U",
                                     "$1<img src=\"$value\" alt=\"" . $this->humanReadableEmoticon($key) . "\" style=\"display: inline; vertical-align: bottom;\" class=\"emoticon\" />$2",
                                     $element);
                             }
