@@ -1,4 +1,4 @@
-<?php # $Id: lang_de.inc.php 1381 2006-08-15 10:14:56Z elf2000 $
+<?php # $Id: lang_de.inc.php 2054 2007-12-06 09:26:35Z garvinhicking $
 
         @define('PLUGIN_KARMA_VERSION', '1.3');
         @define('PLUGIN_KARMA_NAME', 'Karma');
@@ -41,3 +41,6 @@
         @define('PLUGIN_KARMA_STATISTICS_VISITS_NO', 'Besuche');
         @define('PLUGIN_KARMA_STATISTICS_VOTES_NO', 'Stimmen');
         @define('PLUGIN_KARMA_STATISTICS_POINTS_NO', 'Punkte');
+
+        @define('PLUGIN_KARMA_VISITS_LOGGEDIN_USERS', 'Aufrufstatistik auch für eingeloggte Benutzer?');
+        @define('PLUGIN_KARMA_VISITS_LOGGEDIN_USERS_BLAHBLAH', 'Wenn diese Option eingeschaltet ist, dann werden auch die Besuche von eingeloggten Benutzern protokolliert.');
