@@ -1,7 +1,7 @@
-<?php # $Id: lang_bg.inc.php 1479 2006-11-02 20:04:07Z jwalker $
+<?php # $Id: lang_bg.inc.php 2054 2007-12-06 09:26:35Z garvinhicking $
 
 /**
- *  @version $Revision: 1479 $
+ *  @version $Revision: 2054 $
  *  @author Ivan Cenov jwalker@hotmail.bg
  */
 
@@ -47,3 +47,6 @@
 @define('PLUGIN_KARMA_STATISTICS_POINTS_NO', '');
 
 @define('PLUGIN_KARMA_STARRATING', '      ?');
+
+@define('PLUGIN_KARMA_VISITS_LOGGEDIN_USERS', '     ?');
+@define('PLUGIN_KARMA_VISITS_LOGGEDIN_USERS_BLAHBLAH', '  \'\',     ()   .');
