@@ -1,7 +1,7 @@
-<?php # $Id: lang_en.inc.php 1475 2006-11-02 11:26:10Z garvinhicking $
+<?php # $Id: lang_en.inc.php 2054 2007-12-06 09:26:35Z garvinhicking $
 
 /**
- *  @version $Revision: 1475 $
+ *  @version $Revision: 2054 $
  *  @author Translator Name <yourmail@example.com>
  *  EN-Revision: Revision of lang_en.inc.php
  */
@@ -48,4 +48,6 @@
 @define('PLUGIN_KARMA_STATISTICS_POINTS_NO', 'points');
 
 @define('PLUGIN_KARMA_STARRATING', 'Enable individual rating on this entry?');
-?>
+
+@define('PLUGIN_KARMA_VISITS_LOGGEDIN_USERS', 'Track visits of logged in users?');
+@define('PLUGIN_KARMA_VISITS_LOGGEDIN_USERS_BLAHBLAH', 'If this option is enabled, page visits of users who are logged in are tracked, too.');
