@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_event_karma.php 1528 2006-12-01 08:58:47Z garvinhicking $
+<?php # $Id: serendipity_event_karma.php 1686 2007-04-25 10:00:36Z garvinhicking $
 
 
 if (IN_serendipity !== true) {
@@ -339,7 +339,7 @@ class serendipity_event_karma extends serendipity_event
                           $this->karmaId,
                           $this->karmaVoting,
                           serendipity_db_escape_string($_SERVER['REMOTE_ADDR']),
-                          serendipity_db_escape_string($_SERVER['HTTP_USER_AGENT']),
+                          substr(serendipity_db_escape_string($_SERVER['HTTP_USER_AGENT']), 0, 255),
                           $now
                         );
                         $sql = serendipity_db_query($q);
