@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_event_mailer.php 1528 2006-12-01 08:58:47Z garvinhicking $
+<?php # $Id: serendipity_event_mailer.php 2032 2007-11-25 01:09:06Z garvinhicking $
 
 if (IN_serendipity !== true) {
     die ("Don't hack!");
@@ -26,7 +26,7 @@ class serendipity_event_mailer extends serendipity_event
         $propbag->add('description',   PLUGIN_EVENT_MAILER_DESC);
         $propbag->add('stackable',     false);
         $propbag->add('author',        'Sebastian Nohn, Kristian Koehntopp, Garvin Hicking');
-        $propbag->add('version',       '1.47');
+        $propbag->add('version',       '1.48');
         $propbag->add('requirements',  array(
             'serendipity' => '0.8',
             'smarty'      => '2.6.7',
@@ -148,10 +148,10 @@ class serendipity_event_mailer extends serendipity_event
 ?>
                     <fieldset style="margin: 5px">
                         <legend><?php echo PLUGIN_EVENT_MAILER_NAME; ?></legend>
-                            <input type="checkbox" name="serendipity[properties][sendentry]" id="properties_sendentry" value="true" checked="checked" />
+                            <input class="input_checkbox" type="checkbox" name="serendipity[properties][sendentry]" id="properties_sendentry" value="true" checked="checked" />
                             <label title="<?php echo PLUGIN_EVENT_MAILER_SENDING; ?>" for="properties_sendentry">&nbsp;<?php echo PLUGIN_EVENT_MAILER_ISTOSENDIT; ?></label><br />
                             <label title="<?php echo PLUGIN_EVENT_MAILER_RECIPIENT; ?>" for="properties_mailto">&nbsp;<?php echo PLUGIN_EVENT_MAILER_RECIPIENTS; ?>&nbsp;&nbsp;</label>&nbsp;
-                            <input type="text" name="serendipity[properties][mailto]" id="properties_mailto" value="<?php echo htmlspecialchars($mailto); ?>" />
+                            <input class="input_textbox" type="text" name="serendipity[properties][mailto]" id="properties_mailto" value="<?php echo htmlspecialchars($mailto); ?>" />
                     </fieldset>
 <?php
                     break;
@@ -201,14 +201,17 @@ class serendipity_event_mailer extends serendipity_event
                         switch($this->get_config('what')) {
                             case 'all':
                                 $mail['body']     = $eventData['body'] . $eventData['extended'];
+                                break;
                             case 'body':
                                 $mail['body']     = $eventData['body'];
                                 break;
+                                break;
                             case 'extended':
                                 $mail['body']     = $eventData['extended'];
                                 break;
                             case 'none':
                                 $mail['body']     = '';
+                                break;
                         }
 
                         if (isset($serendipity['POST']['properties']['mailto'])) {
