@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_event_searchhighlight.php 1528 2006-12-01 08:58:47Z garvinhicking $
+<?php # $Id: serendipity_event_searchhighlight.php 1789 2007-07-20 09:14:33Z garvinhicking $
 
 /**********************************/
 /*  Authored by Tom Sommer, 2004  */
@@ -29,7 +29,7 @@ class serendipity_event_searchhighlight extends serendipity_event
         $propbag->add('description',   PLUGIN_EVENT_SEARCHHIGHLIGHT_DESC);
         $propbag->add('stackable',     false);
         $propbag->add('author',        'Tom Sommer');
-        $propbag->add('version',       '1.3');
+        $propbag->add('version',       '1.4');
         $propbag->add('requirements',  array(
             'serendipity' => '0.8',
             'smarty'      => '2.6.7',
@@ -116,7 +116,10 @@ class serendipity_event_searchhighlight extends serendipity_event
             return PLUGIN_EVENT_SEARCHHIGHLIGHT_AOL_COM;
         }
 
-
+        if (!empty($_SESSION['search_referer']) && $this->uri != $_SESSION['search_referer']) {
+            $this->uri = $_SESSION['search_referer'];
+            return $this->getSearchEngine();
+        }
 
         return false;
     }
@@ -192,6 +195,9 @@ class serendipity_event_searchhighlight extends serendipity_event
                 return;
             }
 
+            $_SESSION['is_searchengine_visitor'] = true;
+            $_SESSION['search_referer'] = $this->uri;
+
             foreach ($this->markup_elements as $temp) {
                 if ( ! (serendipity_db_bool($this->get_config($temp['name'])) && isset($eventData[$temp['element']])) ) {
                     continue;
