@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_event_spamblock.php 1528 2006-12-01 08:58:47Z garvinhicking $
+<?php # $Id: serendipity_event_spamblock.php 1845 2007-08-13 08:03:44Z garvinhicking $
 
 
 if (IN_serendipity !== true) {
@@ -39,7 +39,7 @@ var $filter_defaults;
             'smarty'      => '2.6.7',
             'php'         => '4.1.0'
         ));
-        $propbag->add('version',       '1.61');
+        $propbag->add('version',       '1.68');
         $propbag->add('event_hooks',    array(
             'frontend_saveComment' => true,
             'external_plugin'      => true,
@@ -70,18 +70,21 @@ var $filter_defaults;
             'contentfilter_urls',
             'contentfilter_authors',
             'contentfilter_words',
+            'contentfilter_emails',
             'bloggdeblacklist',
             'akismet',
             'akismet_filter',
             'hide_email',
             'checkmail',
             'required_fields',
+            'automagic_htaccess',
             'logtype',
             'logfile'));
         $propbag->add('groups', array('ANTISPAM'));
 
         $this->filter_defaults = array(
                                    'authors' => 'casino;phentermine;credit;loans;poker',
+                                   'emails'  => '',
                                    'urls'    => '8gold\.com;911easymoney\.com;canadianlabels\.net;condodream\.com;crepesuzette\.com;debt-help-bill-consolidation-elimination\.com;fidelityfunding\.net;flafeber\.com;gb\.com;houseofsevengables\.com;instant-quick-money-cash-advance-personal-loans-until-pay-day\.com;mediavisor\.com;newtruths\.com;oiline\.com;onlinegamingassociation\.com;online\-+poker\.com;popwow\.com;royalmailhotel\.com;spoodles\.com;sportsparent\.com;stmaryonline\.org;thatwhichis\.com;tmsathai\.org;uaeecommerce\.com;learnhowtoplay\.com',
                                    'words'   => 'very good site!;Real good stuff!'
         );
@@ -112,6 +115,13 @@ var $filter_defaults;
                 $propbag->add('default', false);
                 break;
 
+            case 'automagic_htaccess':
+                $propbag->add('type', 'boolean');
+                $propbag->add('name', PLUGIN_EVENT_SPAMBLOCK_HTACCESS);
+                $propbag->add('description', PLUGIN_EVENT_SPAMBLOCK_HTACCESS_DESC);
+                $propbag->add('default', false);
+                break;
+
             case 'hide_email':
                 $propbag->add('type', 'boolean');
                 $propbag->add('name', PLUGIN_EVENT_SPAMBLOCK_HIDE_EMAIL);
@@ -264,6 +274,13 @@ var $filter_defaults;
                 $propbag->add('default', $this->filter_defaults['words']);
                 break;
 
+            case 'contentfilter_emails':
+                $propbag->add('type', 'text');
+                $propbag->add('name', PLUGIN_EVENT_SPAMBLOCK_FILTER_EMAILS);
+                $propbag->add('description', PLUGIN_EVENT_SPAMBLOCK_FILTER_AUTHORS_DESC);
+                $propbag->add('default', $this->filter_defaults['emails']);
+                break;
+
             case 'logfile':
                 $propbag->add('type', 'string');
                 $propbag->add('name', PLUGIN_EVENT_SPAMBLOCK_LOGFILE);
@@ -365,6 +382,40 @@ var $filter_defaults;
         return true;
     }
 
+    function htaccess_update($new_ip) {
+        global $serendipity;
+
+        serendipity_db_query("INSERT INTO {$serendipity['dbPrefix']}spamblock_htaccess (ip, timestamp) VALUES ('" . serendipity_db_escape_string($new_ip) . "', '" . time() . "')");
+
+        $q = "SELECT ip FROM {$serendipity['dbPrefix']}spamblock_htaccess WHERE timestamp > " . (time() - 86400*2) . " GROUP BY ip";
+        $rows = serendipity_db_query($q, false, 'assoc');
+
+        $deny = array();
+        foreach($rows AS $row) {
+            $deny[] = $row['ip'];
+        }
+
+        $hta = $serendipity['serendipityPath'] . '.htaccess';
+        if (file_exists($hta) && is_writable($hta)) {
+            $htaccess = file_get_contents($hta);
+            $fp = @fopen($hta, 'w');
+            if (!$fp) {
+                return false;
+            } else {
+                // Check if an old htaccess file existed and try to preserve its contents. Otherwise completely wipe the file.
+                if ($htaccess != '' && preg_match('@^(.*)#SPAMDENY.*Deny From.+#/SPAMDENY(.*)$@imsU', $htaccess, $match)) {
+                    // Code outside from s9y-code was found.
+                    $content = trim($match[1]) . "\n#SPAMDENY\nDeny From " . implode(',', $deny) . "\n#/SPAMDENY\n" . trim($match[2]);
+                } else {
+                    $content = trim($htaccess) . "\n#SPAMDENY\nDeny From " . implode(',', $deny) . "\n#/SPAMDENY\n";
+                }
+                fwrite($fp, $content);
+                fclose($fp);
+                return true;
+            }
+        }
+    }
+
     function &getBlacklist($where, $api_key = '', &$eventData, &$addData) {
         global $serendipity;
 
@@ -374,6 +425,7 @@ var $filter_defaults;
 
         switch($where) {
             case 'akismet.com':
+                $this->log($this->logfile, $eventData['id'], 'AKISMET_SAFETY', 'Akismet verification takes place', $addData);
                 $ret  = array();
         		$data = array(
         		  'blog'                    => $serendipity['baseURL'],
@@ -392,7 +444,8 @@ var $filter_defaults;
                     'http'              => '1.1',
                     'timeout'           => 20,
                     'allowRedirects'    => true,
-                    'maxRedirects'      => 3
+                    'maxRedirects'      => 3,
+                    'readTimeout'       => array(5,0), 
                 );
 
                 $req    = &new HTTP_Request(
@@ -442,10 +495,11 @@ var $filter_defaults;
                 if (preg_match('@true@i', $reqdata)) {
                     $ret['is_spam'] = true;
                     $ret['message'] = $reqdata;
+                    $this->log($this->logfile, $eventData['id'], 'AKISMET_PASS', 'Passed Akismet verification', $addData);
                 } elseif (preg_match('@false@i', $reqdata)) {
                     $ret['is_spam'] = false;
                     $ret['message'] = $reqdata;
-                    $this->log($this->logfile, $eventData['id'], 'API_ERROR', 'Akismet API verification failed: ' . $reqdata, $addData);
+                    $this->log($this->logfile, $eventData['id'], 'AKISMET_SPAM', 'Akismet API returned spam', $addData);
                 } else {
                     $ret['is_spam'] = false;
                     $ret['message'] = 'Akismet API failure';
@@ -492,12 +546,12 @@ var $filter_defaults;
         return $ret;
     }
 
-    function checkScheme($maxVersion) {
+    function checkScheme() {
         global $serendipity;
 
-        $version = $this->get_config('version', '1.0');
-
-        if ($version != $maxVersion) {
+        $dbversion = $this->get_config('dbversion', '1');
+        
+        if ($dbversion == '1') {
             $q   = "CREATE TABLE {$serendipity['dbPrefix']}spamblocklog (
                           timestamp int(10) {UNSIGNED} default null,
                           type varchar(255),
@@ -521,7 +575,15 @@ var $filter_defaults;
             $q   = "CREATE INDEX kspamentryidx ON {$serendipity['dbPrefix']}spamblocklog (entry_id);";
             $sql = serendipity_db_schema_import($q);
 
-            $this->set_config('version', $maxVersion);
+            $q   = "CREATE TABLE {$serendipity['dbPrefix']}spamblock_htaccess (
+                          timestamp int(10) {UNSIGNED} default null,
+                          ip varchar(15))";
+            $sql = serendipity_db_schema_import($q);
+
+            $q   = "CREATE INDEX kshtaidx ON {$serendipity['dbPrefix']}spamblock_htaccess (timestamp);";
+            $sql = serendipity_db_schema_import($q);
+
+            $this->set_config('dbversion', '2');
         }
 
         return true;
@@ -531,6 +593,16 @@ var $filter_defaults;
         $title = $this->title;
     }
 
+    // This method will be called on "fatal" spam errors that are unlikely to occur accidentally by users.
+    // Their IPs will be constantly blocked.
+    function IsHardcoreSpammer() {
+        global $serendipity;
+
+        if (serendipity_db_bool($this->get_config('automagic_htaccess'))) {
+            $this->htaccess_update($_SERVER['REMOTE_ADDR']);
+        }
+    }
+
     // Checks whether the current author is contained in one of the gorups that need no spam checking
     function inGroup() {
         global $serendipity;
@@ -557,6 +629,44 @@ var $filter_defaults;
         return false;
     }
 
+    function example() {
+        echo '<div id="captchabox" style="margin: 10px; padding: 5px; border: 1px solid black">' . PLUGIN_EVENT_SPAMBLOCK_LOOK . '<br />';
+        $this->show_captcha();
+        echo '</div>';
+    }
+
+    function show_captcha($use_gd = false) {
+        global $serendipity;
+
+        if ($use_gd || (function_exists('imagettftext') && function_exists('imagejpeg'))) {
+            $max_char = 5;
+            $min_char = 3;
+            $use_gd   = true;
+        } else {
+            $max_char = $min_char = 5;
+            $use_gd   = false;
+        }
+
+        if ($use_gd) {
+            printf('<img src="%s" onclick="this.src=this.src + \'1\'" title="%s" alt="CAPTCHA" class="captcha" />',
+                $serendipity['baseURL'] . ($serendipity['rewrite'] == 'none' ? $serendipity['indexFile'] . '?/' : '') . 'plugin/captcha_' . md5(time()),
+                htmlspecialchars(PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_USERDESC2)
+            );
+        } else {
+            $bgcolors = explode(',', $this->get_config('captcha_color', '255,0,255'));
+            $hexval   = '#' . dechex(trim($bgcolors[0])) . dechex(trim($bgcolors[1])) . dechex(trim($bgcolors[2]));
+            $this->random_string($max_char, $min_char);
+            echo '<div class="serendipity_comment_captcha_image" style="background-color: ' . $hexval . '">';
+            for ($i = 1; $i <= $max_char; $i++) {
+                printf('<img src="%s" title="%s" alt="CAPTCHA ' . $i . '" class="captcha" />',
+                    $serendipity['baseURL'] . ($serendipity['rewrite'] == 'none' ? $serendipity['indexFile'] . '?/' : '') . 'plugin/captcha_' . $i . '_' . md5(time()),
+                    htmlspecialchars(PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_USERDESC2)
+                );
+            }
+            echo '</div>';
+        }
+    }
+
     function event_hook($event, &$bag, &$eventData, $addData = null) {
         global $serendipity;
 
@@ -570,6 +680,11 @@ var $filter_defaults;
             // Check if the entry is older than the allowed amount of time. Enforce kaptchas if that is true
             // of if kaptchas are activated for every entry
             $show_captcha = ($captchas && isset($eventData['timestamp']) && ($captchas_ttl < 1 || ($eventData['timestamp'] < (time() - ($captchas_ttl*60*60*24)))) ? true : false);
+            
+            // Plugins can override with custom captchas
+            if (isset($serendipity['plugins']['disable_internal_captcha'])) {
+                $show_captcha = false;
+            }
 
             $forcemoderation = $this->get_config('forcemoderation', 60);
             $forcemoderation_treat = $this->get_config('forcemoderation_treat', 'moderate');
@@ -601,9 +716,7 @@ var $filter_defaults;
 
                 case 'frontend_saveComment':
                     if (!is_array($eventData) || serendipity_db_bool($eventData['allow_comments'])) {
-                        if ($this->get_config('logtype', 'db') == 'db' && $this->get_config('version') != $bag->get('version')) {
-                            $this->checkScheme($bag->get('version'));
-                        }
+                        $this->checkScheme();
 
                         $serendipity['csuccess'] = 'true';
                         $logfile = $this->logfile = $this->get_config('logfile', $serendipity['serendipityPath'] . 'spamblock.log');
@@ -632,6 +745,14 @@ var $filter_defaults;
                             }
                         }
 
+                        /*
+                        if ($addData['type'] != 'NORMAL' && empty($addData['name'])) {
+                            $eventData = array('allow_coments' => false);
+                            $this->log($logfile, $eventData['id'], 'INVALIDGARV', 'INVALIDGARV', $addData);
+                            return false;
+                        }
+                        */
+
                         // Check whether to allow comments from registered authors
                         if (serendipity_userLoggedIn() && $this->inGroup()) {
                             return true;
@@ -646,7 +767,7 @@ var $filter_defaults;
                         }
 
                         // Check for global emergency moderation
-                        if ( $this->get_config('killswitch', false) === true ) {
+                        if ($this->get_config('killswitch', false) === true) {
                             $this->log($logfile, $eventData['id'], 'REJECTED', PLUGIN_EVENT_SPAMBLOCK_REASON_KILLSWITCH, $addData);
                             $eventData = array('allow_comments' => false);
                             $serendipity['messagestack']['comments'][] = PLUGIN_EVENT_SPAMBLOCK_ERROR_KILLSWITCH;
@@ -675,11 +796,12 @@ var $filter_defaults;
                         if (!empty($akismet_apikey) && ($akismet == 'moderate' || $akismet == 'reject')) {
                             $spam = $this->getBlacklist('akismet.com', $akismet_apikey, $eventData, $addData);
                             if ($spam['is_spam'] !== false) {
+                                $this->IsHardcoreSpammer();
                                 if ($akismet == 'moderate') {
                                     $this->log($logfile, $eventData['id'], 'MODERATE', PLUGIN_EVENT_SPAMBLOCK_REASON_AKISMET_SPAMLIST . ': ' . $spam['message'], $addData);
                                     $eventData['moderate_comments'] = true;
                                     $serendipity['csuccess']        = 'moderate';
-                                    $serendipity['moderate_reason'] = PLUGIN_EVENT_SPAMBLOCK_ERROR_BODY;
+                                    $serendipity['moderate_reason'] = PLUGIN_EVENT_SPAMBLOCK_ERROR_BODY . ' (Akismet)';
                                 } else {
                                     $this->log($logfile, $eventData['id'], 'REJECTED', PLUGIN_EVENT_SPAMBLOCK_REASON_AKISMET_SPAMLIST . ': ' . $spam['message'], $addData);
                                     $eventData = array('allow_comments' => false);
@@ -694,7 +816,7 @@ var $filter_defaults;
                             require_once S9Y_PEAR_PATH . 'HTTP/Request.php';
 
                             if (function_exists('serendipity_request_start')) serendipity_request_start();
-                            $req     = &new HTTP_Request($addData['url'], array('allowRedirects' => true, 'maxRedirects' => 5));
+                            $req     = &new HTTP_Request($addData['url'], array('allowRedirects' => true, 'maxRedirects' => 5, 'readTimeout' => array(5,0)));
                             $is_valid = false;
                             if (PEAR::isError($req->sendRequest()) || $req->getResponseCode() != '200') {
                                 $is_valid = false;
@@ -728,14 +850,14 @@ var $filter_defaults;
                                     if (empty($filter_author)) {
                                         continue;
                                     }
-                                    if (preg_match('@' . $filter_author . '@i', $addData['name'])) {
+                                    if (preg_match('@(' . $filter_author . ')@i', $addData['name'], $wordmatch)) {
                                         if ($filter_type == 'moderate') {
-                                            $this->log($logfile, $eventData['id'], 'MODERATE', PLUGIN_EVENT_SPAMBLOCK_FILTER_AUTHORS, $addData);
+                                            $this->log($logfile, $eventData['id'], 'MODERATE', PLUGIN_EVENT_SPAMBLOCK_FILTER_AUTHORS . ': ' . $wordmatch[1], $addData);
                                             $eventData['moderate_comments'] = true;
                                             $serendipity['csuccess']        = 'moderate';
-                                            $serendipity['moderate_reason'] = PLUGIN_EVENT_SPAMBLOCK_ERROR_BODY;
+                                            $serendipity['moderate_reason'] = PLUGIN_EVENT_SPAMBLOCK_ERROR_BODY . ' (' . PLUGIN_EVENT_SPAMBLOCK_FILTER_AUTHORS . ': ' . $wordmatch[1] . ')';
                                         } else {
-                                            $this->log($logfile, $eventData['id'], 'REJECTED', PLUGIN_EVENT_SPAMBLOCK_FILTER_AUTHORS, $addData);
+                                            $this->log($logfile, $eventData['id'], 'REJECTED', PLUGIN_EVENT_SPAMBLOCK_FILTER_AUTHORS . ': ' . $wordmatch[1], $addData);
                                             $eventData = array('allow_comments' => false);
                                             $serendipity['messagestack']['comments'][] = PLUGIN_EVENT_SPAMBLOCK_ERROR_BODY;
                                             return false;
@@ -751,14 +873,14 @@ var $filter_defaults;
                                     if (empty($filter_url)) {
                                         continue;
                                     }
-                                    if (preg_match('@' . $filter_url . '@i', $addData['url'])) {
+                                    if (preg_match('@(' . $filter_url . ')@i', $addData['url'], $wordmatch)) {
                                         if ($filter_type == 'moderate') {
-                                            $this->log($logfile, $eventData['id'], 'MODERATE', PLUGIN_EVENT_SPAMBLOCK_FILTER_URLS, $addData);
+                                            $this->log($logfile, $eventData['id'], 'MODERATE', PLUGIN_EVENT_SPAMBLOCK_FILTER_URLS . ': ' . $wordmatch[1], $addData);
                                             $eventData['moderate_comments'] = true;
                                             $serendipity['csuccess']        = 'moderate';
-                                            $serendipity['moderate_reason'] = PLUGIN_EVENT_SPAMBLOCK_ERROR_BODY;
+                                            $serendipity['moderate_reason'] = PLUGIN_EVENT_SPAMBLOCK_ERROR_BODY . ' (' . PLUGIN_EVENT_SPAMBLOCK_FILTER_URLS . ': ' . $wordmatch[1] . ')';
                                         } else {
-                                            $this->log($logfile, $eventData['id'], 'REJECTED', PLUGIN_EVENT_SPAMBLOCK_FILTER_URLS, $addData);
+                                            $this->log($logfile, $eventData['id'], 'REJECTED', PLUGIN_EVENT_SPAMBLOCK_FILTER_URLS . ': ' . $wordmatch[1], $addData);
                                             $eventData = array('allow_comments' => false);
                                             $serendipity['messagestack']['comments'][] = PLUGIN_EVENT_SPAMBLOCK_ERROR_BODY;
                                             return false;
@@ -774,14 +896,14 @@ var $filter_defaults;
                                     if (empty($filter_body)) {
                                         continue;
                                     }
-                                    if (preg_match('@' . $filter_body . '@i', $addData['comment'])) {
+                                    if (preg_match('@(' . $filter_body . ')@i', $addData['comment'], $wordmatch)) {
                                         if ($filter_type == 'moderate') {
-                                            $this->log($logfile, $eventData['id'], 'MODERATE', PLUGIN_EVENT_SPAMBLOCK_FILTER_WORDS, $addData);
+                                            $this->log($logfile, $eventData['id'], 'MODERATE', PLUGIN_EVENT_SPAMBLOCK_FILTER_WORDS . ': ' . $wordmatch[1], $addData);
                                             $eventData['moderate_comments'] = true;
                                             $serendipity['csuccess']        = 'moderate';
-                                            $serendipity['moderate_reason'] = PLUGIN_EVENT_SPAMBLOCK_ERROR_BODY;
+                                            $serendipity['moderate_reason'] = PLUGIN_EVENT_SPAMBLOCK_ERROR_BODY . ' (' . PLUGIN_EVENT_SPAMBLOCK_FILTER_WORDS . ': ' . $wordmatch[1] . ')';
                                         } else {
-                                            $this->log($logfile, $eventData['id'], 'REJECTED', PLUGIN_EVENT_SPAMBLOCK_FILTER_WORDS, $addData);
+                                            $this->log($logfile, $eventData['id'], 'REJECTED', PLUGIN_EVENT_SPAMBLOCK_FILTER_WORDS . ': ' . $wordmatch[1], $addData);
                                             $eventData = array('allow_comments' => false);
                                             $serendipity['messagestack']['comments'][] = PLUGIN_EVENT_SPAMBLOCK_ERROR_BODY;
                                             return false;
@@ -789,6 +911,30 @@ var $filter_defaults;
                                     }
                                 }
                             }
+
+                            // Filter Emails
+                            $filter_emails = explode(';', $this->get_config('contentfilter_emails', $this->filter_defaults['emails']));
+                            if (is_array($filter_emails)) {
+                                foreach($filter_emails AS $filter_email) {
+                                    if (empty($filter_email)) {
+                                        continue;
+                                    }
+                                    if (preg_match('@(' . $filter_email . ')@i', $addData['email'], $wordmatch)) {
+                                        $this->IsHardcoreSpammer();
+                                        if ($filter_type == 'moderate') {
+                                            $this->log($logfile, $eventData['id'], 'MODERATE', PLUGIN_EVENT_SPAMBLOCK_FILTER_EMAILS . ': ' . $wordmatch[1], $addData);
+                                            $eventData['moderate_comments'] = true;
+                                            $serendipity['csuccess']        = 'moderate';
+                                            $serendipity['moderate_reason'] = PLUGIN_EVENT_SPAMBLOCK_ERROR_BODY . ' (' . PLUGIN_EVENT_SPAMBLOCK_FILTER_EMAILS . ': ' . $wordmatch[1] . ')';
+                                        } else {
+                                            $this->log($logfile, $eventData['id'], 'REJECTED', PLUGIN_EVENT_SPAMBLOCK_FILTER_EMAILS . ': ' . $wordmatch[1], $addData);
+                                            $eventData = array('allow_comments' => false);
+                                            $serendipity['messagestack']['emails'][] = PLUGIN_EVENT_SPAMBLOCK_ERROR_BODY;
+                                            return false;
+                                        }
+                                    }
+                                }
+                            }
                         } // Content filtering end
 
                         // Filter Blogg.de Blacklist?
@@ -803,11 +949,12 @@ var $filter_defaults;
                                     }
 
                                     if (preg_match('@' . preg_quote($domain) . '@i', $addData['url'])) {
+                                        $this->IsHardcoreSpammer();
                                         if ($bloggdeblacklist == 'moderate') {
                                             $this->log($logfile, $eventData['id'], 'MODERATE', PLUGIN_EVENT_SPAMBLOCK_REASON_BLOGG_SPAMLIST . ': ' . $domain, $addData);
                                             $eventData['moderate_comments'] = true;
                                             $serendipity['csuccess']        = 'moderate';
-                                            $serendipity['moderate_reason'] = PLUGIN_EVENT_SPAMBLOCK_ERROR_BODY;
+                                            $serendipity['moderate_reason'] = PLUGIN_EVENT_SPAMBLOCK_ERROR_BODY . ' (' . PLUGIN_EVENT_SPAMBLOCK_REASON_BLOGG_SPAMLIST . ')';
                                         } else {
                                             $this->log($logfile, $eventData['id'], 'REJECTED', PLUGIN_EVENT_SPAMBLOCK_REASON_BLOGG_SPAMLIST . ': ' . $domain, $addData);
                                             $eventData = array('allow_comments' => false);
@@ -885,6 +1032,7 @@ var $filter_defaults;
                             $query = "SELECT count(id) AS counter FROM {$serendipity['dbPrefix']}comments WHERE body = '" . serendipity_db_escape_string($addData['comment']) . "'";
                             $row   = serendipity_db_query($query, true);
                             if (is_array($row) && $row['counter'] > 0) {
+                                $this->IsHardcoreSpammer();
                                 $this->log($logfile, $eventData['id'], 'REJECTED', PLUGIN_EVENT_SPAMBLOCK_REASON_BODYCLONE, $addData);
                                 $eventData = array('allow_comments' => false);
                                 $serendipity['messagestack']['comments'][] = PLUGIN_EVENT_SPAMBLOCK_ERROR_BODY;
@@ -940,26 +1088,9 @@ var $filter_defaults;
                         echo '<div class="serendipity_commentDirection serendipity_comment_captcha">';
                         if (!isset($serendipity['POST']['preview']) || strtolower($serendipity['POST']['captcha'] != strtolower($_SESSION['spamblock']['captcha']))) {
                             echo '<br />' . PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_USERDESC . '<br />';
-                            if ($use_gd) {
-                                printf('<img src="%s" title="%s" alt="CAPTCHA" class="captcha" />',
-                                    $serendipity['baseURL'] . ($serendipity['rewrite'] == 'none' ? $serendipity['indexFile'] . '?/' : '') . 'plugin/captcha_' . md5(time()),
-                                    htmlspecialchars(PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_USERDESC2)
-                                );
-                            } else {
-                                $bgcolors = explode(',', $this->get_config('captcha_color', '255,0,255'));
-                                $hexval   = '#' . dechex(trim($bgcolors[0])) . dechex(trim($bgcolors[1])) . dechex(trim($bgcolors[2]));
-                                $this->random_string($max_char, $min_char);
-                                echo '<div style="background-color: ' . $hexval . '">';
-                                for ($i = 1; $i <= $max_char; $i++) {
-                                    printf('<img src="%s" title="%s" alt="CAPTCHA ' . $i . '" class="captcha" />',
-                                        $serendipity['baseURL'] . ($serendipity['rewrite'] == 'none' ? $serendipity['indexFile'] . '?/' : '') . 'plugin/captcha_' . $i . '_' . md5(time()),
-                                        htmlspecialchars(PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_USERDESC2)
-                                    );
-                                }
-                                echo '</div>';
-                            }
+                            $this->show_captcha($use_gd);
                             echo '<br />';
-                            echo '<label for="captcha">'. PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_USERDESC3 . '</label><br /><input type="text" size="5" name="serendipity[captcha]" value="" id="captcha" />';
+                            echo '<label for="captcha">'. PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_USERDESC3 . '</label><br /><input class="input_textbox" type="text" size="5" name="serendipity[captcha]" value="" id="captcha" />';
                         } elseif (isset($serendipity['POST']['captcha'])) {
                             echo '<input type="hidden" name="serendipity[captcha]" value="' . htmlspecialchars($serendipity['POST']['captcha']) . '" />';
                         }
@@ -1078,6 +1209,13 @@ var $filter_defaults;
                         $this->set_config('contentfilter_urls', implode(';', $items));
                     }
 
+                    // Add E-mail to blacklist. If already filtered, it will be removed from the filter. (AKA "Toggle")
+                    if (isset($serendipity['GET']['spamBlockEmail'])) {
+                        $item    = $this->getComment('email', $serendipity['GET']['spamBlockEmail']);
+                        $items   = &$this->checkFilter('emails', $item, true);
+                        $this->set_config('contentfilter_emails', implode(';', $items));
+                    }
+
                     echo ' - ' . WORD_OR . ' - <a class="serendipityPrettyButton" href="serendipity_admin.php?serendipity[adminModule]=plugins&amp;serendipity[plugin_to_conf]=' . $this->instance . '">' . PLUGIN_EVENT_SPAMBLOCK_CONFIG . '</a>';
                     return true;
                     break;
@@ -1087,11 +1225,16 @@ var $filter_defaults;
                     $clink1 = 'clink1' . $eventData['id'];
                     $clink2 = 'clink2' . $eventData['id'];
 
-                    $eventData['action_author'] .= ' <a id="' . $clink1 . '" class="serendipityIconLink" title="' . ($author_is_filtered ? PLUGIN_EVENT_SPAMBLOCK_REMOVE_AUTHOR : PLUGIN_EVENT_SPAMBLOCK_ADD_AUTHOR) . '" href="serendipity_admin.php?serendipity[adminModule]=comments&amp;serendipity[spamBlockAuthor]=' . $eventData['id'] . $addData . '#' . $clink1 . '"><img src="' . serendipity_getTemplateFile('admin/img/' . ($author_is_filtered ? 'un' : '') . 'configure.png') . '" /></a>';
+                    $eventData['action_author'] .= ' <a id="' . $clink1 . '" class="serendipityIconLink" title="' . ($author_is_filtered ? PLUGIN_EVENT_SPAMBLOCK_REMOVE_AUTHOR : PLUGIN_EVENT_SPAMBLOCK_ADD_AUTHOR) . '" href="serendipity_admin.php?serendipity[adminModule]=comments&amp;serendipity[spamBlockAuthor]=' . $eventData['id'] . $addData . '#' . $clink1 . '"><img src="' . serendipity_getTemplateFile('admin/img/' . ($author_is_filtered ? 'un' : '') . 'configure.png') . '" alt="" /></a>';
 
                     if (!empty($eventData['url'])) {
                         $url_is_filtered    = $this->checkFilter('urls', $eventData['url']);
-                        $eventData['action_url']    .= ' <a id="' . $clink2 . '" class="serendipityIconLink" title="' . ($url_is_filtered ? PLUGIN_EVENT_SPAMBLOCK_REMOVE_URL : PLUGIN_EVENT_SPAMBLOCK_ADD_URL) . '" href="serendipity_admin.php?serendipity[adminModule]=comments&amp;serendipity[spamBlockURL]=' . $eventData['id'] . $addData . '#' . $clink2 . '"><img src="' . serendipity_getTemplateFile('admin/img/' . ($url_is_filtered ? 'un' : '') . 'configure.png') . '" /></a>';
+                        $eventData['action_url']    .= ' <a id="' . $clink2 . '" class="serendipityIconLink" title="' . ($url_is_filtered ? PLUGIN_EVENT_SPAMBLOCK_REMOVE_URL : PLUGIN_EVENT_SPAMBLOCK_ADD_URL) . '" href="serendipity_admin.php?serendipity[adminModule]=comments&amp;serendipity[spamBlockURL]=' . $eventData['id'] . $addData . '#' . $clink2 . '"><img src="' . serendipity_getTemplateFile('admin/img/' . ($url_is_filtered ? 'un' : '') . 'configure.png') . '" alt="" /></a>';
+                    }
+
+                    if (!empty($eventData['email'])) {
+                        $email_is_filtered    = $this->checkFilter('emails', $eventData['email']);
+                        $eventData['action_email']    .= ' <a id="' . $clink2 . '" class="serendipityIconLink" title="' . ($email_is_filtered ? PLUGIN_EVENT_SPAMBLOCK_REMOVE_EMAIL : PLUGIN_EVENT_SPAMBLOCK_ADD_EMAIL) . '" href="serendipity_admin.php?serendipity[adminModule]=comments&amp;serendipity[spamBlockEmail]=' . $eventData['id'] . $addData . '#' . $clink2 . '"><img src="' . serendipity_getTemplateFile('admin/img/' . ($email_is_filtered ? 'un' : '') . 'configure.png') . '" alt="" /></a>';
                     }
 
                     return true;
@@ -1214,9 +1357,9 @@ var $filter_defaults;
                            serendipity_db_escape_string($comment['name']),
                            serendipity_db_escape_string($comment['email']),
                            serendipity_db_escape_string($comment['url']),
-                           serendipity_db_escape_string($_SERVER['HTTP_USER_AGENT']),
+                           substr(serendipity_db_escape_string($_SERVER['HTTP_USER_AGENT']), 0, 255),
                            serendipity_db_escape_string($_SERVER['REMOTE_ADDR']),
-                           serendipity_db_escape_string(isset($_SESSION['HTTP_REFERER']) ? $_SESSION['HTTP_REFERER'] : $_SERVER['HTTP_REFERER']),
+                           substr(serendipity_db_escape_string(isset($_SESSION['HTTP_REFERER']) ? $_SESSION['HTTP_REFERER'] : $_SERVER['HTTP_REFERER']), 0, 255),
                            serendipity_db_escape_string($comment['comment'])
                 );
 
