@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_event_spartacus.php 1528 2006-12-01 08:58:47Z garvinhicking $
+<?php # $Id: serendipity_event_spartacus.php 2038 2007-11-26 13:20:34Z garvinhicking $
 
 /************
   TODO:
@@ -39,7 +39,7 @@ class serendipity_event_spartacus extends serendipity_event
         $propbag->add('description',   PLUGIN_EVENT_SPARTACUS_DESC);
         $propbag->add('stackable',     false);
         $propbag->add('author',        'Garvin Hicking');
-        $propbag->add('version',       '2.9');
+        $propbag->add('version',       '2.14');
         $propbag->add('requirements',  array(
             'serendipity' => '0.9',
             'smarty'      => '2.6.7',
@@ -56,7 +56,7 @@ class serendipity_event_spartacus extends serendipity_event
             'backend_pluginlisting_header_upgrade' => true
         ));
         $propbag->add('groups', array('BACKEND_FEATURES'));
-        $propbag->add('configuration', array('mirror_xml', 'mirror_files', 'chown', 'chmod_files', 'chmod_dir'));
+        $propbag->add('configuration', array('enable_plugins', 'enable_themes', 'mirror_xml', 'mirror_files', 'chown', 'chmod_files', 'chmod_dir'));
     }
 
     function generate_content(&$title) {
@@ -78,7 +78,7 @@ class serendipity_event_spartacus extends serendipity_event
         }
 
         foreach ($files as $file) {
-            printf(DELETING_FILE . '<br />', $file['name']);
+            $this->outputMSG('notice', sprintf(DELETING_FILE . '<br />', $file['name']));
             @unlink($serendipity['serendipityPath'] . PATH_SMARTY_COMPILE . '/' . $file['name']);
         }
     }
@@ -109,6 +109,13 @@ class serendipity_event_spartacus extends serendipity_event
                 'http://php-blog.cvs.sourceforge.net/*checkout*/php-blog/',
                 'http://s9y.org/mirror/',
                 'http://svn.berlios.de/viewcvs/serendipity/'
+            ),
+
+            'files_health' => array(
+                'http://netmirror.org/'                 => 'http://netmirror.org/mirror/serendipity/last.txt',
+                'http://php-blog.cvs.sourceforge.net/'  => 'http://php-blog.cvs.sourceforge.net/*checkout*/php-blog/serendipity/docs/LICENSE',
+                'http://s9y.org/'                       => 'http://s9y.org/',
+                'http://svn.berlios.de/'                => 'http://svn.berlios.de/viewcvs/serendipity/'
             )
         );
 
@@ -123,6 +130,20 @@ class serendipity_event_spartacus extends serendipity_event
         global $serendipity;
 
         switch($name) {
+            case 'enable_plugins':
+                $propbag->add('type',        'boolean');
+                $propbag->add('name',        PLUGIN_EVENT_SPARTACUS_ENABLE_PLUGINS);
+                $propbag->add('description', '');
+                $propbag->add('default',     'true');
+                break;
+
+            case 'enable_themes':
+                $propbag->add('type',        'boolean');
+                $propbag->add('name',        PLUGIN_EVENT_SPARTACUS_ENABLE_THEMES);
+                $propbag->add('description', '');
+                $propbag->add('default',     'true');
+                break;
+
             case 'chmod_files':
                 $propbag->add('type',        'string');
                 $propbag->add('name',        PLUGIN_EVENT_SPARTACUS_CHMOD);
@@ -250,51 +271,133 @@ class serendipity_event_spartacus extends serendipity_event
         return true;
     }
 
+    function outputMSG($status, $msg) {
+        switch($status) {
+            case 'notice':
+                echo '<div class="serendipityAdminMsgNotice"><img style="width: 22px; height: 22px; border: 0px; padding-right: 4px; vertical-align: middle" src="' . serendipity_getTemplateFile('admin/img/admin_msg_note.png') . '" alt="" />' . $msg . '</div>' . "\n";
+                break;
+
+            case 'error':
+                echo '<div class="serendipityAdminMsgError"><img style="width: 22px; height: 22px; border: 0px; padding-right: 4px; vertical-align: middle" src="' . serendipity_getTemplateFile('admin/img/admin_msg_error.png') . '" alt="" />' . $msg . '</div>' . "\n";
+                break;
+
+            default:
+            case 'success':
+                echo '<div class="serendipityAdminMsgSuccess"><img style="height: 22px; width: 22px; border: 0px; padding-right: 4px; vertical-align: middle" src="' . serendipity_getTemplateFile('admin/img/admin_msg_success.png') . '" alt="" />' . $msg . '</div>' . "\n";
+                break;
+        }
+    }
+
     function &fetchfile($url, $target, $cacheTimeout = 0, $decode_utf8 = false, $sub = 'plugins') {
         static $error = false;
 
         // Fix double URL strings.
         $url = str_replace('http:/', 'http://', str_replace('//', '/', $url));
 
-        printf(PLUGIN_EVENT_SPARTACUS_FETCHING, '<a href="' . $url . '">' . basename($url) . '</a>');
-        echo '<br />';
+        // --JAM: Get the URL's IP in the most error-free way possible
+        $url_parts = @parse_url($url);
+        $url_hostname = 'localhost';
+        if (is_array($url_parts)) {
+            $url_hostname = $url_parts['host'];
+        }
+        $url_ip = gethostbyname($url_hostname);
+
+        $this->outputMSG('notice', sprintf(PLUGIN_EVENT_SPARTACUS_FETCHING, '<a href="' . $url . '">' . basename($url) . '</a>'));
 
         if (file_exists($target) && filesize($target) > 0 && filemtime($target) >= (time()-$cacheTimeout)) {
             $data = file_get_contents($target);
-            printf(PLUGIN_EVENT_SPARTACUS_FETCHED_BYTES_CACHE, strlen($data), $target);
-            echo '<br />';
+            $this->outputMSG('success', sprintf(PLUGIN_EVENT_SPARTACUS_FETCHED_BYTES_CACHE, strlen($data), $target));
         } else {
             require_once S9Y_PEAR_PATH . 'HTTP/Request.php';
             $options = array();
             serendipity_plugin_api::hook_event('backend_http_request', $options, 'spartacus');
             serendipity_request_start();
+
             $req = &new HTTP_Request($url, $options);
 
             if (PEAR::isError($req->sendRequest()) || $req->getResponseCode() != '200') {
-                printf(PLUGIN_EVENT_SPARTACUS_FETCHERROR, $url);
-                echo '<br />';
+                $resolved_url = $url . ' (IP ' . $url_ip . ')';
+                $this->outputMSG('error', sprintf(PLUGIN_EVENT_SPARTACUS_FETCHERROR, $resolved_url));
+                //--JAM: START FIREWALL DETECTION
+                if ($req->getResponseCode()) {
+                    $this->outputMSG('error', sprintf(PLUGIN_EVENT_SPARTACUS_REPOSITORY_ERROR, $req->getResponseCode()));
+                }
+                $check_health = true;
+                if (function_exists('curl_init')) {
+                    $this->outputMSG('notice', PLUGIN_EVENT_SPARTACUS_TRYCURL);
+                    $curl_handle=curl_init();
+                    curl_setopt($curl_handle, CURLOPT_URL, $url);
+                    curl_setopt($curl_handle, CURLOPT_HEADER, 0);
+                    $data = curl_exec($curl_handle);
+                    curl_close($curl_handle);
+                    if ($curl_result) {
+                        $check_health = false;
+                    } else {
+                        $this->outputMSG('error', PLUGIN_EVENT_SPARTACUS_CURLFAIL . "\n");
+                    }
+                }
+            }
+            if ($check_health) {
+                /*--JAM: Useful for later, when we have a health monitor for SPARTACUS
+                $propbag = new serendipity_property_bag;
+                $this->introspect($propbag);
+                $health_url = 'http://spartacus.s9y.org/spartacus_health.php?version=' . $propbag->get('version');
+                */
+                // Garvin: Temporary health. Better than nothing, eh?
+                $health_url = $url;
+                $matches = array();
+                preg_match('#http://[^/]*/#', $url, $matches);
+                if ($matches[0]) {
+                    $health_url = $matches[0];
+                }
+
+                $mirrors = $this->getMirrors('files_health', true);
+                $health_url = $mirrors[$health_url];
+                $this->outputMSG('notice', sprintf(PLUGIN_EVENT_SPARTACUS_HEALTHCHECK, $health_url));
+
+                $health_options = $options;
+                serendipity_plugin_api::hook_event('backend_http_request', $health_options, 'spartacus_health');
+                $health_req = &new HTTP_Request($health_url, $health_options);
+                $health_result = $health_req->sendRequest();
+                if (PEAR::isError($health_result)) {
+                    $fp = @fsockopen('www.google.com', 80, $errno, $errstr);
+                    if (!$fp) {
+                        $this->outputMSG('error', sprintf(PLUGIN_EVENT_SPARTACUS_HEALTHBLOCKED, $errno, $errstr));
+                    } else {
+                        $this->outputMSG('error', PLUGIN_EVENT_SPARTACUS_HEALTHDOWN);
+                        $this->outputMSG('notice', sprintf(PLUGIN_EVENT_SPARTACUS_HEALTHLINK, $health_url));
+                        fclose($fp);
+                    }
+                } else if ($health_req->getResponseCode() != '200') {
+                    $this->outputMSG('error', sprintf(PLUGIN_EVENT_SPARTACUS_HEALTHERROR, $health_req->getResponseCode()));
+                    $this->outputMSG('notice', sprintf(PLUGIN_EVENT_SPARTACUS_HEALTHLINK, $health_url));
+                } else {
+                    $this->outputMSG('error', PLUGIN_EVENT_SPARTACUS_HEALTFIREWALLED);
+                    //--JAM: Parse response and display it.
+                }
+                //--JAM: END FIREWALL DETECTION
                 if (file_exists($target) && filesize($target) > 0) {
                     $data = file_get_contents($target);
-                    printf(PLUGIN_EVENT_SPARTACUS_FETCHED_BYTES_CACHE, strlen($data), $target);
-                    echo '<br />';
+                    $this->outputMSG('success', sprintf(PLUGIN_EVENT_SPARTACUS_FETCHED_BYTES_CACHE, strlen($data), $target));
+                    echo "<br />\n";
                 }
             } else {
                 // Fetch file
-                $data = $req->getResponseBody();
-                printf(PLUGIN_EVENT_SPARTACUS_FETCHED_BYTES_URL, strlen($data), $target);
-                echo '<br />';
+                if (!$data) {
+                    $data = $req->getResponseBody();
+                }
+                $this->outputMSG('success', sprintf(PLUGIN_EVENT_SPARTACUS_FETCHED_BYTES_URL, strlen($data), $target));
+
                 $tdir = dirname($target);
                 if (!is_dir($tdir) && !$this->rmkdir($tdir, $sub)) {
-                    printf(FILE_WRITE_ERROR, $tdir);
-                    echo '<br />';
+                    $this->outputMSG('error', sprintf(FILE_WRITE_ERROR, $tdir));
                     return $error;
                 }
 
                 $fp = @fopen($target, 'w');
 
                 if (!$fp) {
-                    printf(FILE_WRITE_ERROR, $target);
-                    echo '<br />';
+                    $this->outputMSG('error', sprintf(FILE_WRITE_ERROR, $target));
                     return $error;
                 }
 
@@ -308,8 +411,7 @@ class serendipity_event_spartacus extends serendipity_event
 
                 $this->fileperm($target, false);
 
-                echo PLUGIN_EVENT_SPARTACUS_FETCHED_DONE;
-                echo '<br />';
+                $this->outputMSG('success', PLUGIN_EVENT_SPARTACUS_FETCHED_DONE);
                 $this->purgeCache = true;
             }
             serendipity_request_end();
@@ -649,6 +751,7 @@ class serendipity_event_spartacus extends serendipity_event
 
                 $plugname = $pluginstack[$i]['template'];
                 $pluginstack[$i]['previewURL'] = $mirror . '/additional_themes/' . $plugname . '/preview.png?rev=1.9999';
+                $pluginstack[$i]['preview_fullsizeURL'] = $mirror . '/additional_themes/' . $plugname . '/preview_fullsize.jpg?rev=1.9999';
                 $pluginstack[$i]['customURI']  = '&amp;serendipity[spartacus_fetch]=' . $plugname;
                 $pluginstack[$i]['customIcon'] = '_spartacus';
 
@@ -677,8 +780,7 @@ class serendipity_event_spartacus extends serendipity_event
 
         $pdir = $serendipity['serendipityPath'] . '/' . $sub . '/';
         if (!is_writable($pdir)) {
-            printf(DIRECTORY_WRITE_ERROR, $pdir);
-            echo '<br />';
+            $this->outputMSG('error', sprintf(DIRECTORY_WRITE_ERROR, $pdir));
             return false;
         }
 
@@ -752,10 +854,12 @@ class serendipity_event_spartacus extends serendipity_event
         if (isset($hooks[$event])) {
             switch($event) {
                 case 'backend_pluginlisting_header':
-                    echo '<br /><div id="upgrade_notice" class="serendipityAdminMsgSuccess">';
-                    echo '<a href="?serendipity[adminModule]=plugins&amp;serendipity[adminAction]=addnew&amp;serendipity[only_group]=UPGRADE" class="serendipityIconLink upgrade_sidebar"><img src="' . serendipity_getTemplateFile('admin/img/upgrade_now.png') . '" style="border: 0px none ; vertical-align: middle; display: inline;" alt="" />' . PLUGIN_EVENT_SPARTACUS_CHECK_SIDEBAR . '</a> &nbsp; ';
-                    echo '<a href="?serendipity[adminModule]=plugins&amp;serendipity[adminAction]=addnew&amp;serendipity[only_group]=UPGRADE&amp;serendipity[type]=event" class="serendipityIconLink upgrade_event"><img src="' . serendipity_getTemplateFile('admin/img/upgrade_now.png') . '" style="border: 0px none ; vertical-align: middle; display: inline;" alt="" />' . PLUGIN_EVENT_SPARTACUS_CHECK_EVENT . '</a> ';
-                    echo '</div>';
+                    if (serendipity_db_bool($this->get_config('enable_plugins'))) {
+                        echo '<br /><div id="upgrade_notice" class="serendipityAdminMsgSuccess">';
+                        echo '<a href="?serendipity[adminModule]=plugins&amp;serendipity[adminAction]=addnew&amp;serendipity[only_group]=UPGRADE" class="serendipityIconLink upgrade_sidebar"><img src="' . serendipity_getTemplateFile('admin/img/upgrade_now.png') . '" style="border: 0px none ; vertical-align: middle; display: inline;" alt="" />' . PLUGIN_EVENT_SPARTACUS_CHECK_SIDEBAR . '</a> &nbsp; ';
+                        echo '<a href="?serendipity[adminModule]=plugins&amp;serendipity[adminAction]=addnew&amp;serendipity[only_group]=UPGRADE&amp;serendipity[type]=event" class="serendipityIconLink upgrade_event"><img src="' . serendipity_getTemplateFile('admin/img/upgrade_now.png') . '" style="border: 0px none ; vertical-align: middle; display: inline;" alt="" />' . PLUGIN_EVENT_SPARTACUS_CHECK_EVENT . '</a> ';
+                        echo '</div>';
+                    }
 
                     return true;
                     break;
@@ -767,50 +871,58 @@ class serendipity_event_spartacus extends serendipity_event
                     break;
 
                 case 'backend_templates_fetchlist':
-                    $eventData = $this->buildTemplateList($this->fetchOnline('template', true), 'template');
+                    if (serendipity_db_bool($this->get_config('enable_themes'))) {
+                        $eventData = $this->buildTemplateList($this->fetchOnline('template', true), 'template');
+                    }
 
                     return true;
                     break;
 
                 case 'backend_templates_fetchtemplate':
-                    if (!empty($eventData['GET']['spartacus_fetch'])) {
-                        $this->download(
-                            $this->fetchOnline('template', true),
-                            $eventData['GET']['theme'],
-                            'templates'
-                        );
+                    if (serendipity_db_bool($this->get_config('enable_themes'))) {
+                        if (!empty($eventData['GET']['spartacus_fetch'])) {
+                            $this->download(
+                                $this->fetchOnline('template', true),
+                                $eventData['GET']['theme'],
+                                'templates'
+                            );
+                        }
                     }
 
                     return false;
                     break;
 
                 case 'backend_plugins_fetchlist':
-                    $type = (isset($serendipity['GET']['type']) ? $serendipity['GET']['type'] : 'sidebar');
+                    if (serendipity_db_bool($this->get_config('enable_plugins'))) {
+                        $type = (isset($serendipity['GET']['type']) && !empty($serendipity['GET']['type']) ? $serendipity['GET']['type'] : 'sidebar');
 
-                    $eventData = array(
-                       'pluginstack' => $this->buildList($this->fetchOnline($type), $type),
-                       'errorstack'  => array(),
-                       'upgradeURI'  => '&amp;serendipity[spartacus_upgrade]=true',
-                       'baseURI'     => '&amp;serendipity[spartacus_fetch]=' . $type
-                    );
+                        $eventData = array(
+                           'pluginstack' => $this->buildList($this->fetchOnline($type), $type),
+                           'errorstack'  => array(),
+                           'upgradeURI'  => '&amp;serendipity[spartacus_upgrade]=true',
+                           'baseURI'     => '&amp;serendipity[spartacus_fetch]=' . $type
+                        );
+                    }
 
                     return true;
                     break;
 
                 case 'backend_plugins_fetchplugin':
-                    if (!empty($eventData['GET']['spartacus_fetch'])) {
-                        $baseDir = $this->download($this->fetchOnline($eventData['GET']['spartacus_fetch'], true), $eventData['GET']['install_plugin']);
+                    if (serendipity_db_bool($this->get_config('enable_plugins'))) {
+                        if (!empty($eventData['GET']['spartacus_fetch'])) {
+                            $baseDir = $this->download($this->fetchOnline($eventData['GET']['spartacus_fetch'], true), $eventData['GET']['install_plugin']);
 
-                        if ($baseDir === false) {
-                            $eventData['install'] = false;
-                        } elseif (!empty($baseDir)) {
-                            $eventData['GET']['pluginPath'] = $baseDir;
-                        } else {
-                            $eventData['GET']['pluginPath'] = $eventData['GET']['install_plugin'];
-                        }
+                            if ($baseDir === false) {
+                                $eventData['install'] = false;
+                            } elseif (!empty($baseDir)) {
+                                $eventData['GET']['pluginPath'] = $baseDir;
+                            } else {
+                                $eventData['GET']['pluginPath'] = $eventData['GET']['install_plugin'];
+                            }
 
-                        if ($eventData['GET']['spartacus_upgrade']) {
-                            $eventData['install'] = false;
+                            if ($eventData['GET']['spartacus_upgrade']) {
+                                $eventData['install'] = false;
+                            }
                         }
                     }
 
