@@ -1,4 +1,4 @@
-<?php # $Id: lang_de.inc.php 1384 2006-08-15 12:32:21Z garvinhicking $
+<?php # $Id: lang_de.inc.php 1797 2007-07-24 12:59:01Z garvinhicking $
 
         @define('PLUGIN_EVENT_STATISTICS_NAME', 'Statistiken');
         @define('PLUGIN_EVENT_STATISTICS_DESC', 'Zeigt einen Link zu informativen Statistiken (inkl. Besucherzhler) in der Administrationsoberflche an.');
@@ -56,17 +56,27 @@
         @define('PLUGIN_EVENT_STATISTICS_EXT_OPT1', 'Nein!');
         @define('PLUGIN_EVENT_STATISTICS_EXT_OPT2', 'Ja, am unteren Ende der Seite.');
         @define('PLUGIN_EVENT_STATISTICS_EXT_OPT3', 'Ja, oben auf der Seite.');
+        @define('PLUGIN_EVENT_STATISTICS_EXT_ALL', 'Alles zeigen? (Standard: nein)');
+        @define('PLUGIN_EVENT_STATISTICS_EXT_ALL_DESC', 'Bei \'nein\' werden nur Besucherstatistiken angezeigt');
+        @define('PLUGIN_EVENT_STATISTICS_EXT_ALL1', 'Nein, alles auer dem Zhler verbergen.');
+        @define('PLUGIN_EVENT_STATISTICS_EXT_ALL2', 'Ja, alle Statistiken anzeigen!');
         @define('PLUGIN_EVENT_STATISTICS_EXT_VISITORS', 'Anzahl der Besucher');
-        @define('PLUGIN_EVENT_STATISTICS_EXT_VISTODAY', 'Anzahl der Besucher heute');
+        @define('PLUGIN_EVENT_STATISTICS_EXT_HITSTODAY', 'Aufrufe heute');
+        @define('PLUGIN_EVENT_STATISTICS_EXT_HITSTOTAL', 'Aufrufe gesamt');
+        @define('PLUGIN_EVENT_STATISTICS_EXT_VISTODAY', 'Besucher heute');
         @define('PLUGIN_EVENT_STATISTICS_EXT_VISTOTAL', 'Besucher gesamt');
         @define('PLUGIN_EVENT_STATISTICS_EXT_VISSINCE', 'Die erweiterte Besucherstatistik hat seit folgendem Zeitpunkt Daten gesammelt:');
+        @define('PLUGIN_EVENT_STATISTICS_EXT_COUNTDESC','Die Zahl der Aufrufe kann sehr gro werden, liefert jedoch einen Wert bezglich der einzelnen Seitenanfragen. Diese Zahl erhht sich deshalb mit JEDEM Seitenaufruf sowie jeder Aktualisierung der Seite und kann damit NICHT als Besucherzhler verstanden werden.');
         @define('PLUGIN_EVENT_STATISTICS_EXT_VISLATEST', 'Letzte Besucher');
         @define('PLUGIN_EVENT_STATISTICS_EXT_TOPREFS', 'Top-Referrer');
         @define('PLUGIN_EVENT_STATISTICS_EXT_TOPREFS_NONE', 'Bisher wurden keine Referrer registriert.');
+        @define('PLUGIN_EVENT_STATISTICS_EXT_DAYGRAPH', 'Aufrufe, auf den Tag bezogen');
+        @define('PLUGIN_EVENT_STATISTICS_EXT_MONTHGRAPH', 'Aufrufe, auf den Monat bezogen');
         @define('PLUGIN_EVENT_STATISTICS_OUT_EXT_STATISTICS', 'Erweiterte Besucherstatistik');
-        @define('PLUGIN_EVENT_STATISTICS_BANNED_HOSTS', 'Browser von der Zhlung ausschlieen');
-        @define('PLUGIN_EVENT_STATISTICS_BANNED_HOSTS_DESC', 'Fgen Sie hier Browser ein, die von der Zhlung ausgeschlossen werden sollen, getrennt durch "|".');
-
+        @define('PLUGIN_EVENT_STATISTICS_BANNED_HOSTS1', 'Aktivieren, keine Robots zhlen');
+        @define('PLUGIN_EVENT_STATISTICS_BANNED_HOSTS2', 'Nein, Robots bitte mitzhlen');
+        @define('PLUGIN_EVENT_STATISTICS_BANNED_HOSTS', 'Robot-Zhlung verhindern');
+        @define('PLUGIN_EVENT_STATISTICS_BANNED_HOSTS_DESC', 'Bei \'ja\' werden keine Robots gezhlt. Bei \'nein\' werden Robots mitgezhlt. Bislang knnen ber 25 Bots von der Zhlung ausgeschlossen werden.');
         @define('PLUGIN_EVENT_STATISTICS_SHOW_LASTENTRY', 'Datum des letzten Artikels anzeigen');
         @define('PLUGIN_EVENT_STATISTICS_SHOW_ENTRYCOUNT', 'Anzahl der Artikel anzeigen');
         @define('PLUGIN_EVENT_STATISTICS_SHOW_COMMENTCOUNT', 'Anzahl der Kommentare anzeigen');
