@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_event_templatechooser.php 1528 2006-12-01 08:58:47Z garvinhicking $
+<?php # $Id: serendipity_event_templatechooser.php 1612 2007-02-08 12:08:43Z garvinhicking $
 
 
 if (IN_serendipity !== true) {
@@ -60,7 +60,7 @@ class serendipity_event_templatechooser extends serendipity_event
 
                 if (isset($_REQUEST['user_template']) && (in_array($_REQUEST['user_template'], serendipity_fetchTemplates())) ) {
                     $_SESSION['serendipityUseTemplate'] = $_REQUEST['user_template'];
-                    serendipity_setCookie('user_template', $_REQUEST['user_template']);
+                    serendipity_setCookie('user_template', $_REQUEST['user_template'], false);
                 }
 
                 if (isset($_SESSION['serendipityUseTemplate']) ) {
