@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_event_textwiki.php 1529 2006-12-01 09:07:52Z garvinhicking $
+<?php # $Id: serendipity_event_textwiki.php 1528 2006-12-01 08:58:47Z garvinhicking $
 
 
 if (IN_serendipity !== true) {
@@ -466,7 +466,7 @@ class serendipity_event_textwiki extends serendipity_event
         $propbag->add('description',   PLUGIN_EVENT_TEXTWIKI_DESC);
         $propbag->add('stackable',     false);
         $propbag->add('author',        'Tobias Schlitt');
-        $propbag->add('version',       '1.3');
+        $propbag->add('version',       '1.4');
         $propbag->add('requirements',  array(
             'serendipity' => '0.8',
             'smarty'      => '2.6.7',
@@ -590,7 +590,9 @@ class serendipity_event_textwiki extends serendipity_event
             switch($event) {
                 case 'frontend_display':
                     foreach ($this->markup_elements as $temp) {
-                        if (serendipity_db_bool($this->get_config($temp['name'], true)) && isset($eventData[$temp['element']])) {
+                        if (serendipity_db_bool($this->get_config($temp['name'], true)) && isset($eventData[$temp['element']]) &&
+                            !$eventData['properties']['ep_disable_markup_' . $this->instance] &&
+                            !isset($serendipity['POST']['properties']['disable_markup_' . $this->instance])) {
                             $element = $temp['element'];
                             $eventData[$element] = $this->wiki->transform($eventData[$element]);
                         }
