@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_plugin_comments.php 1355 2006-08-05 20:47:49Z garvinhicking $
+<?php # $Id: serendipity_plugin_comments.php 1803 2007-07-27 11:22:30Z brockhaus $
 
 // Probe for a language include with constants. Still include defines later on, if some constants were missing
 $probelang = dirname(__FILE__) . '/' . $serendipity['charset'] . 'lang_' . $serendipity['lang'] . '.inc.php';
@@ -21,8 +21,8 @@ class serendipity_plugin_comments extends serendipity_plugin
         $propbag->add('name',          COMMENTS);
         $propbag->add('description',   PLUGIN_COMMENTS_BLAHBLAH);
         $propbag->add('stackable',     true);
-        $propbag->add('author',        'Garvin Hicking/Tadashi Jokagi/Judebert');
-        $propbag->add('version',       '1.10');
+        $propbag->add('author',        'Garvin Hicking, Tadashi Jokagi, Judebert, G. Brockhaus');
+        $propbag->add('version',       '1.11');
         $propbag->add('requirements',  array(
             'serendipity' => '0.8',
             'smarty'      => '2.6.7',
@@ -188,14 +188,17 @@ class serendipity_plugin_comments extends serendipity_plugin
                     $comment = wordwrap($comment, $wordwrap, "\n", 1);
                 }
                 $entry = array('comment' => $comment,
-                               'email'   => $row['comment_email']);
+                               'email'   => $row['comment_email'],
+                               'url'     => $row['comment_url'],
+                               'author'  => $row['user']);
                                
                 // Let's help the BBCOde plugin a bit:
                 if (class_exists('serendipity_event_bbcode')) {
                     $entry['comment'] = preg_replace('@((\[.*)[\n\r]+(.*\]))+@imsU', '\2\3', $entry['comment']);
                     $entry['comment'] = preg_replace('@((\[.+\].*)[\r\n]+(.*\[/.+\]))+@imsU', '\2\3', $entry['comment']);
                 }
-                serendipity_plugin_api::hook_event('frontend_display', $entry);
+                $addData = array('from' => 'serendipity_plugin_comments:generate_content');
+                serendipity_plugin_api::hook_event('frontend_display', $entry, $addData);
 
                 printf(
                   '<div class="plugin_comment_wrap">' . PLUGIN_COMMENTS_ABOUT . '</div>',
