@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_plugin_history.php 1249 2006-06-09 10:25:07Z garvinhicking $
+<?php # $Id: serendipity_plugin_history.php 1934 2007-09-17 09:06:03Z garvinhicking $
 
 // Probe for a language include with constants. Still include defines later on, if some constants were missing
 $probelang = dirname(__FILE__) . '/' . $serendipity['charset'] . 'lang_' . $serendipity['lang'] . '.inc.php';
@@ -22,7 +22,7 @@ class serendipity_plugin_history extends serendipity_plugin
         $propbag->add('description',   PLUGIN_HISTORY_DESC);
         $propbag->add('stackable',     true);
         $propbag->add('author',        'Jannis Hermanns');
-        $propbag->add('version',       '1.2');
+        $propbag->add('version',       '1.4');
         $propbag->add('requirements',  array(
             'serendipity' => '0.8',
             'smarty'      => '2.6.7',
@@ -164,11 +164,13 @@ class serendipity_plugin_history extends serendipity_plugin
             $dateformat = '%a, %d.%m.%Y %H:%M';
         }
 
+        $oldLim = $serendipity['fetchLimit'];
         $nowts = serendipity_serverOffsetHour();
         $maxts = mktime(23, 59, 59,  date('m', $nowts), date('d', $nowts), date('Y', $nowts));
         $mints = mktime(0, 0, 0, date('m', $nowts), date('d', $nowts), date('Y', $nowts));
         $e     = serendipity_fetchEntries(array(($mints-$max_age*86400),
                                             ($maxts-$min_age*86400)), $full, $max_entries);
+        $serendipity['fetchLimit'] = $oldLim;
         echo (empty($intro)) ? '' : "$intro<br />";
 
         if (!is_array($e)) {
@@ -191,7 +193,7 @@ class serendipity_plugin_history extends serendipity_plugin
             $t = ($maxlength==0 || strlen($e[$x]['title'])<=$maxlength) ?
                     $e[$x]['title'] :
                     (trim(serendipity_mb('substr', $e[$x]['title'], 0, $maxlength-3)).' [...]');
-            echo $author . $date . "<a href='$url' title='".str_replace("'", '`', $e[$x][title])."'>".$t."</a> " .
+            echo $author . $date . "<a href='$url' title='".str_replace("'", '`', htmlspecialchars($e[$x]['title']))."'>". htmlspecialchars($t) ."</a> " .
                  strip_tags($e[$x]['body']) . '<br />';
         }
         echo $outro;
@@ -199,4 +201,3 @@ class serendipity_plugin_history extends serendipity_plugin
 }
 
 /* vim: set sts=4 ts=4 expandtab : */
-?>
