@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_plugin_remoterss.php 1427 2006-09-14 08:45:13Z garvinhicking $
+<?php # $Id: serendipity_plugin_remoterss.php 2041 2007-11-27 16:02:06Z garvinhicking $
 
 // Contributed by Udo Gerhards <udo@babyblaue-seiten.de>
 // OPML Contributed by Richard Thomas Harrison <rich@mibnet.plus.com>
@@ -257,7 +257,7 @@ class serendipity_plugin_remoterss extends serendipity_plugin {
         $propbag->add('description',   PLUGIN_REMOTERSS_BLAHBLAH);
         $propbag->add('stackable',     true);
         $propbag->add('author',        'Udo Gerhards, Richard Thomas Harrison');
-        $propbag->add('version',       '1.7');
+        $propbag->add('version',       '1.11');
         $propbag->add('requirements',  array(
             'serendipity' => '0.8',
             'smarty'      => '2.6.7',
@@ -274,7 +274,7 @@ class serendipity_plugin_remoterss extends serendipity_plugin {
                 $propbag->add('type', 'boolean');
                 $propbag->add('name', PLUGIN_REMOTERSS_RSSLINK);
                 $propbag->add('description', PLUGIN_REMOTERSS_RSSLINK_DESC);
-                $propbag->add('default', 'false');
+                $propbag->add('default', 'true');
                 break;
 
             case 'escape_rss':
@@ -454,7 +454,7 @@ class serendipity_plugin_remoterss extends serendipity_plugin {
         }
 
         if (trim($rssuri)) {
-            $feedcache = $serendipity['serendipityPath'] . 'templates_c/remoterss_cache_' . preg_replace('@[^a-z0-9]*@i', '', $rssuri) . '.dat';
+            $feedcache = $serendipity['serendipityPath'] . 'templates_c/remoterss_cache_' . md5(preg_replace('@[^a-z0-9]*@i', '', $rssuri)) . '.dat';
             if (!file_exists($feedcache) || filesize($feedcache) == 0 || filemtime($feedcache) < (time() - $cachetime)) {
                 $this->debug('Cachefile does not existing.');
                 if (!$this->urlcheck($rssuri)) {
@@ -471,7 +471,7 @@ class serendipity_plugin_remoterss extends serendipity_plugin {
                     $this->encoding = $c->rss['encoding'];
 
                     $use_rss_link = serendipity_db_bool($this->get_config('use_rss_link'));
-                    $rss_element  = $this->get_config('show_rss_element');
+                    $rss_elements = explode(',', $this->get_config('show_rss_element'));
                     $escape_rss   = serendipity_db_bool($this->get_config('escape_rss'));
                     $i = 0;
                     $content = '';
@@ -481,17 +481,20 @@ class serendipity_plugin_remoterss extends serendipity_plugin {
                         }
 
                         if ($use_rss_link) {
-                            $content .= '<a href="' . $this->decode($item['link']) . '" ' . (!empty($target) ? 'target="'.$target.'"' : '') . '>';
+                            $content .= '<a href="' . htmlspecialchars($this->decode($item['link'])) . '" ' . (!empty($target) ? 'target="'.$target.'"' : '') . '>';
                         }
 
                         if (!empty($bulletimg)) {
                             $content .= '<img src="' . $bulletimg . '" border="0" alt="*" /> ';
                         }
 
-                        if ($escape_rss) {
-                            $content .= $this->decode($item[$rss_element]);
-                        } else {
-                            $content .= htmlspecialchars($this->decode($item[$rss_element]));
+                        foreach($rss_elements AS $rss_element) {
+                            $rss_element = trim($rss_element);
+                            if ($escape_rss) {
+                                $content .= $this->decode($item[$rss_element]);
+                            } else {
+                                $content .= htmlspecialchars($this->decode($item[$rss_element]));
+                            }
                         }
 
                         if ($use_rss_link) {
@@ -568,13 +571,13 @@ class serendipity_plugin_remoterss extends serendipity_plugin {
                             }
 
                             if ($blogrolling === true && (!empty($text) || !empty($url))) {
-                                $content .= '&bull; <a href="' . $url . '" ' . (!empty($target) ? 'target="'.$target.'"' : '') . ' title="' . $text . '">' . htmlspecialchars($text) . "</a>";
+                                $content .= '&bull; <a href="' . htmlspecialchars($url) . '" ' . (!empty($target) ? 'target="'.$target.'"' : '') . ' title="' . $text . '">' . htmlspecialchars($text) . "</a>";
                                 if (isset($item['isRecent'])) {
                                     $content .= ' <span style="color: Red; ">*</span>';
                                 }
                                 $content .= "<br />";
                             } elseif ((isset($item['type']) && $item['type'] == 'url') || !empty($url)) {
-                                $content .= '&bull; <a href="' .$url . '" ' . (!empty($target) ? 'target="'.$target.'"' : '') . ' title="' . $text . '">' . $text . "</a>";
+                                $content .= '&bull; <a href="' . htmlspecialchars($url) . '" ' . (!empty($target) ? 'target="'.$target.'"' : '') . ' title="' . $text . '">' . $text . "</a>";
                                 $content .= "<br />";
                             }
                             ++$i;
