@@ -1,10 +1,11 @@
-<?php # $Id: rss.php 1474 2006-11-02 11:20:35Z garvinhicking $
+<?php # $Id: rss.php 1693 2007-05-16 10:12:47Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
 header('Content-Type: text/xml; charset=utf-8');
 session_cache_limiter('public');
 
+@define('IN_RSS', true);
 include('serendipity_config.inc.php');
 include(S9Y_INCLUDE_PATH . 'include/functions_rss.inc.php');
 
@@ -30,7 +31,7 @@ if (!isset($_GET['type'])) {
 }
 
 if (!empty($_SERVER['HTTP_USER_AGENT']) && stristr($_SERVER['HTTP_USER_AGENT'], 'feedburner')) {
-    $_GET['nocache'] = true;    
+    $_GET['nocache'] = true;
 }
 
 $serendipity['view'] = 'feed';
@@ -156,18 +157,18 @@ if (is_array($plugins)) {
                 }
             }
             $metadata['fullFeed']          = $plugin->get_config('fullfeed', false);
-            if ($metaData['fullFeed'] === 'client') {
+            if ($metadata['fullFeed'] === 'client') {
                 if ($_GET['fullFeed'] || $serendipity['GET']['fullFeed']) {
-                    $metaData['fullFeed'] = true;
+                    $metadata['fullFeed'] = true;
                 } else {
-                    $metaData['fullFeed'] = false;
+                    $metadata['fullFeed'] = false;
                 }
             }
 
-            if ($_GET['type']  == 'content' && 
-                !isset($_GET['category']) && 
-                !isset($serendipity['GET']['tag']) && 
-                $plugin->get_config('show_feedburner') === 'force' && 
+            if ($_GET['type']  == 'content' &&
+                !isset($_GET['category']) &&
+                !isset($serendipity['GET']['tag']) &&
+                $plugin->get_config('show_feedburner') === 'force' &&
                 !preg_match('@FeedBurn@i', $_SERVER['HTTP_USER_AGENT']) &&
                 !(serendipity_userLoggedIn() && isset($_GET['forceLocal']))
                ) {
@@ -181,9 +182,16 @@ if (is_array($plugins)) {
     }
 }
 
+$file_version  = preg_replace('@[^0-9a-z\.-_]@i', '', $version);
+$metadata['template_file'] = serendipity_getTemplateFile('feed_' . $file_version . '.tpl', 'serendipityPath');
+
 serendipity_smarty_init();
 serendipity_plugin_api::hook_event('frontend_rss', $metadata);
 
+if (!$metadata['template_file'] || $metadata['template_file'] == 'feed_' . $file_version . '.tpl') {
+    die("Invalid RSS version specified or RSS-template file not found\n");
+}
+
 $self_url = 'http://' . $_SERVER['HTTP_HOST'] . htmlspecialchars($_SERVER['REQUEST_URI']);
 if (!is_array($entries)) {
     $entries = array();
@@ -195,12 +203,6 @@ if ($entries[0]['last_modified']) {
     $gm_modified = gmdate('Y-m-d\TH:i:s\Z', serendipity_serverOffsetHour());
 }
 
-$file_version  = preg_replace('@[^0-9a-z\.-_]@i', '', $version);
-$template_file = serendipity_getTemplateFile('feed_' . $file_version . '.tpl', 'serendipityPath');
-if (!$template_file) {
-    die("Invalid RSS version specified\n");
-}
-
 serendipity_printEntries_rss($entries, $version, $comments, $metadata['fullFeed'], $metadata['showMail']);
 
 $namespace_hook   = 'frontend_display:unknown:namespace';
@@ -231,7 +233,7 @@ switch($version) {
 
     case 'atom1.0':
         // For people wanting extra RFC compliance
-        // header('Content-Type: application/atom+xml; charset=utf8');
+        // header('Content-Type: application/atom+xml; charset=utf-8');
         $namespace_hook = 'frontend_display:atom-1.0:namespace';
         break;
 }
@@ -252,6 +254,6 @@ $serendipity['smarty']->assign(
         'self_url'              => $self_url,
     )
 );
-$serendipity['smarty']->display($template_file);
+$serendipity['smarty']->display($metadata['template_file']);
 
 /* vim: set sts=4 ts=4 expandtab : */
