@@ -1,4 +1,4 @@
-<?php # $Id: serendipity.css.php 1231 2006-06-02 09:27:05Z garvinhicking $
+<?php # $Id: serendipity.css.php 1673 2007-04-12 09:22:44Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -57,7 +57,7 @@ if (strpos($_SERVER['HTTP_USER_AGENT'], 'MSIE') !== false) {
     header('Pragma:');
     header('Expires: ' . gmdate('D, d M Y H:i:s \G\M\T', time()+3600));
 }
-header('Content-type: text/css');
+header('Content-type: text/css; charset=' . LANG_CHARSET);
 
 if (IS_installed === false) {
     if (file_exists(S9Y_INCLUDE_PATH . 'templates/' . $serendipity['defaultTemplate'] . '/' . $css_file)) {
