@@ -13,7 +13,7 @@
 
 create table {PREFIX}authors (
   realname varchar(255) NOT NULL default '',
-  username varchar(20) default null,
+  username varchar(32) default null,
   password varchar(32) default null,
   authorid {AUTOINCREMENT} {PRIMARY},
   mail_comments int(1) default '1',
@@ -71,7 +71,7 @@ create table {PREFIX}comments (
   author varchar(80) default null,
   email varchar(200) default null,
   url varchar(200) default null,
-  ip varchar(15) default null,
+  ip varchar(64) default null,
   body text,
   type varchar(100) default 'regular',
   subscribed {BOOLEAN},
@@ -184,7 +184,7 @@ create table {PREFIX}options (
 CREATE INDEX options_idx ON {PREFIX}options (okey);
 
 CREATE TABLE {PREFIX}suppress (
-  ip varchar(15) default NULL,
+  ip varchar(64) default NULL,
   scheme varchar(5),
   host varchar(128),
   port varchar(5),
@@ -217,12 +217,15 @@ CREATE TABLE {PREFIX}category (
   authorid int(11) default NULL,
   category_left int(11) default '0',
   category_right int(11) default '0',
-  parentid int(11) DEFAULT '0' NOT NULL
+  parentid int(11) DEFAULT '0' NOT NULL,
+  sort_order int(11),
+  hide_sub int(1)
 ) {UTF_8};
 
 CREATE INDEX categorya_idx ON {PREFIX}category (authorid);
 CREATE INDEX categoryp_idx ON {PREFIX}category (parentid);
 CREATE INDEX categorylr_idx ON {PREFIX}category (category_left, category_right);
+CREATE INDEX categoryso_idx ON {PREFIX}category (sort_order);
 
 CREATE TABLE {PREFIX}images (
   id {AUTOINCREMENT} {PRIMARY},
